@@ -33,6 +33,7 @@
 #include "detail_chemical.h"
 #include "detail_energy.h"
 #include "prefs.h"
+#include "isotopewidget.h"
 
 DetailedInfoDlg::DetailedInfoDlg( Element *el , QWidget *parent, const char *name)
     : KDialogBase(KDialogBase::IconList, "",  Close, Close, parent,name)
@@ -55,7 +56,7 @@ DetailedInfoDlg::DetailedInfoDlg( Element *el , QWidget *parent, const char *nam
 	/////////////////////////////////
     m_pMiscTab = addPage(i18n("Miscellaneous"), i18n("Miscellaneous"), BarIcon( "misc" ));
 	QVBoxLayout *miscLayout = new QVBoxLayout( m_pMiscTab );
-	QLabel *discovered_label = new QLabel( i18n("Discovered: %1").arg( Element::adjustUnits(  e->date() , 5 ) ) , m_pMiscTab );
+	QLabel *discovered_label = new QLabel( i18n("Discovered: %1").arg( e->adjustUnits( Element::DATE ) ) , m_pMiscTab );
 	QLabel *meanweight_label = new QLabel( i18n("Mean weight: %1 u").arg(e->meanweight() ) , m_pMiscTab );
 	QWhatsThis::add( meanweight_label , i18n( "The mean weight is the atomic weight divided by the number of protons" ) );
 	QWhatsThis::add( discovered_label, i18n( "Here you can see when the element was discovered." ) );
@@ -88,10 +89,10 @@ DetailedInfoDlg::DetailedInfoDlg( Element *el , QWidget *parent, const char *nam
 	QVBoxLayout *energyLayout = new QVBoxLayout( m_pEnergyTab );
 	detail_energy *wEnergy = new detail_energy( m_pEnergyTab );
 
-	wEnergy->mp_label->setText( Element::adjustUnits( e->melting(), 0 ) );
-	wEnergy->bp_label->setText( Element::adjustUnits( e->boiling(), 0 ) );
-	wEnergy->sion_label->setText( Element::adjustUnits(  e->ie2(), 1 ) );
-	wEnergy->ion_label->setText( Element::adjustUnits( e->ie(), 1 ) );
+	wEnergy->mp_label->setText( e->adjustUnits( Element::MELTINGPOINT ) );
+	wEnergy->bp_label->setText( e->adjustUnits( Element::BOILINGPOINT ) );
+	wEnergy->sion_label->setText( e->adjustUnits( Element::IE2 ) );
+	wEnergy->ion_label->setText( e->adjustUnits( Element::IE ) );
 	wEnergy->en_label->setText(  QString::number( e->electroneg() ) );
 	energyLayout->addWidget( wEnergy );
 	
@@ -103,10 +104,14 @@ DetailedInfoDlg::DetailedInfoDlg( Element *el , QWidget *parent, const char *nam
 
 	wChemical->orbits_label->setText( e->parsedOrbits() );
 	wChemical->symbol_label->setText( e->symbol() );
-	wChemical->density_label->setText( Element::adjustUnits( e->density(), 4 ) );
+	wChemical->density_label->setText( e->adjustUnits( Element::DENSITY ) );
 	wChemical->block_label->setText( e->block() );
-	wChemical->radius_label->setText( Element::adjustUnits( e->radius(), 2 ) );
-	wChemical->weight_label->setText( Element::adjustUnits( e->weight(), 3 ) );
+	wChemical->radius_label->setText( e->adjustUnits( Element::RADIUS ) );
+	wChemical->weight_label->setText( e->adjustUnits( Element::WEIGHT  ) );
+	if ( el->Isotopes() != "0"  )
+		wChemical->isotopeWidget->setIsotopes( el->Isotopes() );
+	else
+		wChemical->isotopeLabel->hide();
 	chemicalLayout->addWidget( wChemical );
     
     /////////////////////////////////
@@ -131,8 +136,8 @@ DetailedTab::DetailedTab( Element *el, QWidget *parent, const char *name ) : QWi
 
 void DetailedTab::paintEvent( QPaintEvent* )
 {
-	int h = this->height();
-	int w = this->width();
+	int h = height();
+	int w = width();
 
 	QPixmap pm( w, h );
 
@@ -154,28 +159,58 @@ void DetailedTab::paintEvent( QPaintEvent* )
 	p.setBrush( Qt::black );
 	p.setBrush(Qt::NoBrush);
 
-	/**
-	 *	TODO: Fix the fonts
-	 **/
-	QFont f1 = KGlobalSettings::generalFont();
-	QFont f2 = KGlobalSettings::generalFont();
-	QFont f3 = KGlobalSettings::generalFont();
-
-	p.setFont( f1 );
-	int h_ = y2/10*3; //a third of the whole widget
-	p.drawText( x2/10 * 4, h_ , e->symbol() ); //Symbol
-
-	p.setFont( f2 );
- 	p.drawText( x1+4, y2-h_t , x2/2 , h_t , Qt::AlignLeft , i18n( e->elname().utf8() )); //Name
+  QFont fA = KGlobalSettings::generalFont();
+  QFont fB = KGlobalSettings::generalFont();
+  QFont fC = KGlobalSettings::generalFont();
+  fA.setPointSize( fA.pointSize() + 20 ); //Huge font
+  fA.setBold( true );
+  fB.setPointSize( fB.pointSize() + 6 ); //Big font
+  fC.setPointSize( fC.pointSize() + 4 ); //Big font
+  fC.setBold( true );
+  QFontMetrics fmA = QFontMetrics( fA );
+  QFontMetrics fmB = QFontMetrics( fB );
+  QFontMetrics fmC = QFontMetrics( fC );
+    
+  //coordinates for element symbol: near the center
+  int xA = 4 * w / 10;
+  int yA = h / 2;
 	
-	p.drawText( x1+4+h_t , y2-2*h_t , x2-x1-4-h_t , h_t , Qt::AlignRight , e->oxstage() );    //Oxidationszahlen
-	p.drawText( x2/2 , y2-h_t , x2/2-4 , h_t , Qt::AlignRight , QString::number( e->weight() )); //Weight
+  //coordinates for the atomic number: offset from element symbol to the upper left
+  int xB = xA - fmB.width( QString::number( e->number() ) );
+  int yB = yA - fmA.height() + fmB.height();
+  
+  //coordinates for element name: lower left
+  int xC1 = 8;
+  int yC1 = h - 8;
+  
+  //coordinates for oxidation: right side, above atomic weight
+  int xC2 = w - fmC.width( e->oxstage() ) - 8;
+  int yC2 = h - fmC.height() - 8;
+  
+  //coordinates for weight: lower right corner
+  int xC3 = w - fmC.width( QString::number( e->weight() ) ) - 8;
+  int yC3 = h - 8;
+  
+  //Element Symbol
+  p.setFont( fA );
+	p.drawText( xA, yA , e->symbol() ); 
 
-	p.setFont( f3 );
-	p.drawText( x2/10*3 , h_-h_t , x2/10, h_t , Qt::AlignRight , QString::number( e->number() ));
-	drawBiologicalSymbol( &p );
+  //Atomic number
+  p.setFont( fB );
+  p.drawText( xB, yB, QString::number( e->number() ));
 
-	p.end();
+  //Name and other data
+  p.setFont( fC );
+ 	//Name
+  p.drawText( xC1, yC1, i18n( e->elname().utf8() )); 
+  //Oxidationszahlen
+  p.drawText( xC2, yC2, e->oxstage() ); 
+  //Weight
+  p.drawText( xC3, yC3, QString::number( e->weight() )); 
+
+  drawBiologicalSymbol( &p );
+  
+  p.end();
 
 	bitBlt( this, 0, 0, &pm );
 }
@@ -187,8 +222,10 @@ void DetailedTab::drawBiologicalSymbol( QPainter *p )
 
 	int d_ds = ( db/2 )-( ds/2 ); //the delta-x/y of the inner circle
 
-	int pos_x = x1+4;
-	int pos_y = y2 - 5 - 2*h_t;
+//	int pos_x = x1+4;
+//	int pos_y = y2 - 5 - 2*h_t;
+	int pos_x = 8;
+	int pos_y = 8;
 
 	switch ( e->biological() )
 	  {
