@@ -24,6 +24,7 @@
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <kjanuswidget.h>
+#include <kconfigdialog.h>
 #include <klocale.h>
 
 #include <qsplitter.h>
@@ -38,10 +39,10 @@
 #include "exerciseconvert.h"
 #include "exercisefactorize.h"
 #include "taskview.h"
+#include "taskvieweroptionsbase.h"
 #include "statisticsview.h"
 
 #include "settingsclass.h"
-#include "settingsdialog.h"
 
 /* ------ public member functions ------ */
 
@@ -106,8 +107,10 @@ MainQtWidget::MainQtWidget()
 	QObject::connect(m_exerciseFactorize, SIGNAL(signalExerciseSolvedCorrect()), m_statview, SLOT(addCorrect()));
 	QObject::connect(m_exerciseFactorize, SIGNAL(signalExerciseSolvedWrong()), m_statview, SLOT(addWrong()));
 
+#if (KDE_VERSION_MINOR>=3) && (KDE_VERSION_MAJOR>=3)
+#else
 	resize(QSize(QMAX(toolBar()->sizeHint().width(), sizeHint().width()), sizeHint().height()));
-
+#endif
 	// now show the last exercise
 	m_exercises->showPage(SettingsClass::activeExercise());
 	slotAboutToShowPage(m_exercises->pageWidget(m_exercises->activePageIndex()));
@@ -159,11 +162,11 @@ void MainQtWidget::setupActions()
 	KStdAction::quit(kapp, SLOT(quit()), actionCollection());
 
 	//
-	KStdAction::preferences(this,  SLOT( slotPrefs() ), actionCollection(), "preferences");
+	KStdAction::preferences(this,  SLOT( slotPrefs() ), actionCollection());
 
 	// a label just describing the Number of terms ComboBox
 	m_NrOfTermsLabel = new QLabel(i18n("Terms:"), 0, "kde toolbar widget");
-	m_NrOfTermsLabelAction = new KWidgetAction(m_NrOfTermsLabel, i18n("Terms:"), ALT+Key_T,
+	m_NrOfTermsLabelAction = new KWidgetAction(m_NrOfTermsLabel, i18n("Terms:"), ALT+Key_E,
 						   this, SLOT(NrOfTermsBoxSlot()),
 						   actionCollection(), "NrOfTermsLabelAction");
 
@@ -176,14 +179,14 @@ void MainQtWidget::setupActions()
 	m_NrOfTermsBox->setCurrentItem(m_nrRatios - 2);
 	QToolTip::add( m_NrOfTermsBox, i18n( "The number of terms you want" ) );
 	QWhatsThis::add( m_NrOfTermsBox, i18n( "Choose the number of terms (2, 3, 4 or 5) you want for calculating fractions." ) );
-	m_NrOfTermsBoxAction = new KWidgetAction(m_NrOfTermsBox, i18n("Number of Terms"), ALT+Key_T, this, SLOT(NrOfTermsBoxSlot()), actionCollection(), "NrOfTermsBoxAction");
+	m_NrOfTermsBoxAction = new KWidgetAction(m_NrOfTermsBox, i18n("Number of Terms"), ALT+Key_E, this, SLOT(NrOfTermsBoxSlot()), actionCollection(), "NrOfTermsBoxAction");
 
 	// now connect the ComboBox's signal textChanged() to the slot function
 	QObject::connect(m_NrOfTermsBox, SIGNAL(activated(int)), this, SLOT(NrOfTermsBoxSlot()));
 
 	// a label just describing the max. main denominator ComboBox
 	m_MaxMainDenominatorLabel = new QLabel(i18n("Max. main denominator:"), 0, "kde toolbar widget");
-	m_MaxMainDenominatorLabelAction = new KWidgetAction(m_MaxMainDenominatorLabel, i18n("Max. main denominator:"), ALT+Key_T,
+	m_MaxMainDenominatorLabelAction = new KWidgetAction(m_MaxMainDenominatorLabel, i18n("Max. main denominator:"), ALT+Key_D,
 							    this, SLOT(MaxMainDenominatorBoxSlot()),
 							    actionCollection(), "MaxMainDenominatorLabelAction");
 
@@ -206,7 +209,7 @@ void MainQtWidget::setupActions()
 		case 50 : m_MaxMainDenominatorBox->setCurrentItem(3);
 					 break;
 	}
-	m_MaxMainDenominatorBoxAction = new KWidgetAction(m_MaxMainDenominatorBox, i18n("Maximal Main Denominator"), ALT+Key_T, this, SLOT(MaxMainDenominatorBoxSlot()), actionCollection(), "MaxMainDenominatorBoxAction");
+	m_MaxMainDenominatorBoxAction = new KWidgetAction(m_MaxMainDenominatorBox, i18n("Maximal Main Denominator"), ALT+Key_D, this, SLOT(MaxMainDenominatorBoxSlot()), actionCollection(), "MaxMainDenominatorBoxAction");
 
 	// now connect the ComboBox's signal textChanged() to the slot function
 	QObject::connect(m_MaxMainDenominatorBox, SIGNAL(activated(int)),
@@ -239,7 +242,10 @@ void MainQtWidget::setupActions()
 	QObject::connect(m_OperationBox, SIGNAL(activated(int)), this, SLOT(OperationBoxSlot()));
 	
 #if (KDE_VERSION_MINOR>=3) && (KDE_VERSION_MAJOR>=3)
-	setupGUI();
+	if (!initialGeometrySet())
+		resize( QSize(725, 330).expandedTo(minimumSizeHint()));
+	setupGUI(ToolBar | Keys | StatusBar | Create);
+	setAutoSaveSettings();
 #endif
 }
 
@@ -409,6 +415,26 @@ void MainQtWidget::OperationBoxSlot()
 
 void MainQtWidget::slotPrefs()
 {
+	// do not show dialog twice
+	if (KConfigDialog::showDialog("settings"))
+		return;
+
+	//KConfigDialog didn't find an instance of this dialog, so lets create it : 
+	KConfigDialog* configDialog = new KConfigDialog( this, "settings",
+																		SettingsClass::self() );
+
+	
+	TaskViewerOptionsBase * taskViewerOptions = new TaskViewerOptionsBase(0,
+																		"TaskViewerOptionsBase");
+	configDialog->addPage(taskViewerOptions, i18n("Task Viewer Settings"),
+																		"TaskViewerOptionsBase");
+
+	// User edited the configuration - update your local copies of the 
+	// configuration data 
+	connect(configDialog, SIGNAL(settingsChanged()), this, SLOT(slotApplySettings()) ); 
+ 
+	configDialog->show();
+/*
 	SettingsDialog * dlg = new SettingsDialog(this);
 	connect(dlg, SIGNAL(configChanged()), this, SLOT(slotApplySettings()));
 
@@ -417,6 +443,7 @@ void MainQtWidget::slotPrefs()
 	delete dlg;
 	dlg = NULL;
 	
+*/
 	return;
 }
 
