@@ -30,9 +30,10 @@
 #include <kdebug.h>
 #include <kio/netaccess.h>
 #include <kmessagebox.h>
+#include <kprinter.h>
 
 #include <qlayout.h>
-#include <kprinter.h>
+#include <qcheckbox.h>
 #include <qpaintdevicemetrics.h>
 #include <qpainter.h>
 
@@ -67,7 +68,7 @@ KEducaBuilder::KEducaBuilder(QWidget* parent, const char *name, WFlags f )
     initMenuBar();
     init();
     configRead();
-    this->setIcon( KGlobal::iconLoader()->loadIcon("control.png",
+    setIcon( KGlobal::iconLoader()->loadIcon("control.png",
                                                    KIcon::Small) );
     _isOpenFile = false;
 }
@@ -100,8 +101,11 @@ void KEducaBuilder::init()
 
     form2Layout->addWidget( _split );
 
-    this->setCentralWidget( mainView );
-    setupGUI( ToolBar | Keys | StatusBar | Save | Create, "keducabuilderui.rc" );
+    setCentralWidget( mainView );
+    if (!initialGeometrySet())
+       resize( QSize(500, 400).expandedTo(minimumSizeHint()));
+    setupGUI( ToolBar | Keys | StatusBar | Create, "keducabuilderui.rc" );
+    setAutoSaveSettings();
 }
 
 /** Init menu bar settings */
@@ -109,7 +113,7 @@ void KEducaBuilder::initMenuBar()
 {
     KStdAction::openNew(this, SLOT( slotFileOpenNew() ), actionCollection());
     KStdAction::open   (this, SLOT( slotFileOpen() ), actionCollection());
-    (void)new KAction(i18n("Open Gallery..."), 0, 0, this, SLOT( slotGallery() ), actionCollection(), "open_gallery");
+    (void)new KAction(i18n("Open &Gallery..."), 0, 0, this, SLOT( slotGallery() ), actionCollection(), "open_gallery");
     _recentFiles = KStdAction::openRecent(this, SLOT ( slotFileOpenURL(const KURL &)), actionCollection());
     KStdAction::save   (this, SLOT( slotFileSave() ), actionCollection());
     KStdAction::saveAs (this, SLOT( slotFileSaveAs() ), actionCollection());
@@ -256,7 +260,7 @@ void KEducaBuilder::configRead()
     KConfig *config = KGlobal::config();
 
     config->setGroup( "keducacontrol" );
-    this->applyMainWindowSettings( config, "keducacontrol" );
+    applyMainWindowSettings( config, "keducacontrol" );
     _split->setSizes( config->readIntListEntry("Splitter_size") );
     _recentFiles->loadEntries(config);
 }
@@ -267,7 +271,7 @@ void KEducaBuilder::configWrite()
     KConfig *config = KGlobal::config();
 
     config->setGroup( "keducacontrol" );
-    this->saveMainWindowSettings( config, "keducacontrol" );
+    saveMainWindowSettings( config, "keducacontrol" );
     config->writeEntry("Splitter_size", _split->sizes() );
     _recentFiles->saveEntries(config);
     config->sync();
@@ -307,7 +311,7 @@ bool KEducaBuilder::queryClose ()
         if (!currentFileMayBeReplaced())
             return false;
     }
-    this->configWrite();
+    configWrite();
     return( TRUE );
 }
 
@@ -402,7 +406,10 @@ bool KEducaBuilder::fileSaveAs()
 {
     if( !checkSave() ) return false;
 
-    KFileDialog *dialog=new KFileDialog(QString::null, QString::null, this, "file dialog", true);
+    QCheckBox *saveCompressedCheckBox = new QCheckBox( i18n( "Compress the file" ), 0 );
+    saveCompressedCheckBox->setChecked( true );
+
+    KFileDialog *dialog=new KFileDialog(QString::null, QString::null, this, "file dialog", true, saveCompressedCheckBox);
     dialog->setCaption( i18n("Save Document As") );
     dialog->setKeepLocation( true );
     dialog->setOperationMode( KFileDialog::Saving );
@@ -446,14 +453,16 @@ bool KEducaBuilder::fileSaveAs()
         }
     } while ( !bOk );
 
+    bool saveCompressed = saveCompressedCheckBox->isChecked();
 
     delete dialog;
+
     if (bOk) {
         bool copyImages = KMessageBox::questionYesNo( this,
                             i18n("If you want to share this document, it is better to copy the images to the same folder as the document.\n"\
                             "Do you want to copy images?"),
                             i18n("Warning") ) == KMessageBox::Yes;
-        if (_keducaFile->saveFile( newURL, copyImages) ) {
+        if (_keducaFile->saveFile( newURL, copyImages, saveCompressed ) ) {
             _recentFiles->addURL(newURL);
             // we saved the file, so the internal representation is now present as a file
             _isOpenFile=true;
@@ -524,7 +533,7 @@ bool KEducaBuilder::checkSave()
         _keducaFile->getHeader("level").isEmpty()		||
         _keducaFile->getHeader("language").isEmpty() )
     {
-        if (KMessageBox::warningContinueCancel(this, i18n("Unable to save file.\n\nYou must complete the Document Info\n(Only the description is necessary)"), QString::null, i18n("Complete Document Info"))
+        if (KMessageBox::warningContinueCancel(this, i18n("Unable to save file.\n\nYou must complete the Document Info\n(Only the description is necessary)"), QString::null, i18n("Complete Document Info..."))
             == KMessageBox::Continue) {
             if (slotHeader()!=KControlHeader::Accepted)
                 return false;
@@ -587,5 +596,5 @@ void KEducaBuilder::slotGallery()
 void KEducaBuilder::slotEditbyList(QListBoxItem *item)
 {
   if( item )
-    this->slotEdit();
+    slotEdit();
 }
