@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2003 Anne-Marie Mahfouf <annma@kde.org>
+ * Copyright (C) 2001-2005 Anne-Marie Mahfouf <annma@kde.org>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of version 2 of the GNU General Public
@@ -15,8 +15,8 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#ifndef _KHANGMANVIEW_H_
-#define _KHANGMANVIEW_H_
+#ifndef KHANGMANVIEW_H
+#define KHANGMANVIEW_H
 
 #include <qpixmap.h>
 
@@ -44,12 +44,10 @@ public:
 
     virtual ~KHangManView();
 
-        //levelFile is the text file containing the data
+    	///parent instance
+    	KHangMan *khangman;
+        ///levelFile is the text file containing the data
 	QString levelFile;
-	///transparent=true indicates that pictures should be transparent
-	bool transparent;
-	///softer=true indicates that pictures should be childish ones
-	bool softer;
 	///language is the current language for data file
 	QString language;
 	////word is the random word to be guessed
@@ -74,6 +72,7 @@ public:
 	QString tip;
 	
 	QString stripWord, sword;
+	
 	int c, d, f, g;
 	///true if Type accents is enabled for the languages that support it
 	bool accent_b;
@@ -83,14 +82,11 @@ public:
 	bool hintBool;
 	///if the data file is a kvtml file thus has hints
 	bool kvtmlBool;
-	///for tip to be seen
-	KPassivePopup * myPopup;
 	///tmp is to check if not twice the same random number
 	int tmp;
-	KHangMan *khangman;
-	//true if only one instance of each letter is displayed
+	///true if only one instance of each letter is displayed
 	bool b_oneLetter;
-	//If true, the uppercase and lower case are disctincts (world capitals)
+	///If true, the uppercase and lower case are disctincts (world capitals)
 	bool upperBool;
 	
 signals:
@@ -110,8 +106,8 @@ private:
         ///the background image
 	QPixmap bgPixmap;
 	///If true, the word contains the QString
- 	bool containsChar(QString &);
-	void replaceLetters(QString);
+ 	bool containsChar(const QString &);
+	void replaceLetters(const QString &);
 
   
 protected:
@@ -127,10 +123,8 @@ public slots:
 	void slotSetPixmap(QPixmap& );
 	///called when the Combobox changes to No Background
 	void slotNoBkgd();
-	///called when Settings ->Transparent Pictures is checked
-	void slotTransparent();
 	///called when Settings->Softer HangMan Pictures is checked
-	void slotSofter();
+	void slotMilder();
 	///is called if the data file is kvtml hence has tips. read the word and its corrercponding tip from the kvtml file
 	void readFile();
 
@@ -139,6 +133,8 @@ private slots:
     	void slotValidate(const QString &);
     	void game();
     	void wipeout();
+	void timerDone();
+	void timerDoneWord();
 };
 
-#endif // _KHANGMANVIEW_H_
+#endif // KHANGMANVIEW_H
