@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2003 Anne-Marie Mahfouf <annma@kde.org>
+ * Copyright (C) 2001-2005 Anne-Marie Mahfouf <annma@kde.org>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of version 2 of the GNU General Public
@@ -75,7 +75,17 @@ int main(int argc, char **argv)
                             I18N_NOOP("Slovenian data files"), "jlp@holodeck1.com");
     aboutData.addCredit("Pedro Morais",
                             I18N_NOOP("Portuguese data files"), "Morais@kde.org");
-    aboutData.addCredit("Matt Howe",
+    aboutData.addCredit("Gaute Hvoslef Kvalnes",
+                            I18N_NOOP("Norwegian (Nynorsk) data files"), "gaute@verdsveven.com");
+    aboutData.addCredit("Mehmet Özel",
+                            I18N_NOOP("Turkish data files"), "mehmet_ozel2003@hotmail.com");
+     aboutData.addCredit("Черепанов Андрей",
+                            I18N_NOOP("Russian data files"), "sibskull@mail.ru"); 
+     aboutData.addCredit("Radostin Radnev",
+			 I18N_NOOP("Bulgarian data files"), "radnev@yahoo.com");
+     aboutData.addCredit("Kevin Patrick Scannell",
+			 I18N_NOOP("Irish (Gaelic) data files"), "scannell@slu.edu");
+     aboutData.addCredit("Matt Howe",
                             I18N_NOOP("Softer Hangman Pictures"), "mdhowe@bigfoot.com");
     aboutData.addCredit("Benjamin Meyer",
                             I18N_NOOP("Coding help"), "ben@meyerhome.net");
@@ -85,8 +95,8 @@ int main(int argc, char **argv)
                             I18N_NOOP("Coding help"), "l.lunak@kde.org");
     aboutData.addCredit("Albert Astals Cid",
                             I18N_NOOP("Coding help"), "tsdgeos@terra.es");
-   aboutData.addCredit("Chris Luetchford",
-                             I18N_NOOP("svg icon"), "chris@os11.com");
+   aboutData.addCredit("Danny Allen",
+                             I18N_NOOP("svg icon"), "danny@dannyallen.co.uk");
    aboutData.addCredit("Peter Hedlund",
                              I18N_NOOP("Code for generating icons for the characters toolbar"), "peter@peterandlinda.com");
 
