@@ -1,4 +1,3 @@
-// exporter.cc
 // Copyright (C)  2003  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -19,6 +18,8 @@
 #include "exporter.h"
 
 #include "exporttoimagedialog.h"
+#include "latexexporter.h"
+#include "svgexporter.h"
 
 #include "../kig/kig_document.h"
 #include "../kig/kig_part.h"
@@ -120,6 +121,8 @@ KigExportManager::KigExportManager()
   mexporters.push_back( new ImageExporter );
   // working on this one ;)
   mexporters.push_back( new XFigExporter );
+  mexporters.push_back( new LatexExporter );
+  mexporters.push_back( new SVGExporter );
 }
 
 KigExportManager::~KigExportManager()
