@@ -40,8 +40,6 @@
 #include "../objects/object_drawer.h"
 #include "../objects/point_imp.h"
 
-#include <stdio.h>
-
 #include <algorithm>
 #include <functional>
 
@@ -75,6 +73,8 @@
 
 using namespace std;
 
+static const QString typesFile = "macros.kigt";
+
 // export this library...
 typedef KParts::GenericFactory<KigPart> KigPartFactory;
 K_EXPORT_COMPONENT_FACTORY ( libkigpart, KigPartFactory )
@@ -229,15 +229,13 @@ void KigPart::setupActions()
   KIconLoader* l = instance()->iconLoader();
   QPixmap tmp;
 
-  tmp = l->loadIcon( "editdelete", KIcon::Toolbar);
   aDeleteObjects = new KAction(
       i18n("&Delete Objects"), "editdelete", Key_Delete, this,
       SLOT(deleteObjects()), actionCollection(), "delete_objects");
   aDeleteObjects->setToolTip(i18n("Delete the selected objects"));
 
-  tmp = l->loadIcon( "stop", KIcon::Toolbar);
   aCancelConstruction = new KAction(
-      i18n("Cancel Construction"), tmp, Key_Escape, this,
+      i18n("Cancel Construction"), "stop", Key_Escape, this,
       SLOT(cancelConstruction()), actionCollection(), "cancel_construction");
   aCancelConstruction->setToolTip(
       i18n("Cancel the construction of the object being constructed"));
@@ -249,9 +247,8 @@ void KigPart::setupActions()
   aShowHidden->setToolTip(i18n("Show all hidden objects"));
   aShowHidden->setEnabled( true );
 
-  tmp = l->loadIcon("gear", KIcon::Toolbar);
   aNewMacro = new KAction(
-    i18n("&New Macro..."), tmp, 0, this, SLOT(newMacro()),
+    i18n("&New Macro..."), "gear", 0, this, SLOT(newMacro()),
     actionCollection(), "macro_action");
   aNewMacro->setToolTip(i18n("Define a new macro"));
 
@@ -286,7 +283,7 @@ void KigPart::setupActions()
 #endif
 #endif
 #ifdef KIG_PART_CPP_STD_FULLSCREEN_ACTION
-  a = KStdAction::fullScreen( m_widget, SLOT( toggleFullScreen() ), actionCollection(), 0 );
+  a = KStdAction::fullScreen( m_widget, SLOT( toggleFullScreen() ), actionCollection(), (QWidget*)(widget()->parent()),"fullscreen" );
 #else
   tmp = l->loadIcon( "window_fullscreen", KIcon::Toolbar );
   a = new KAction(
@@ -298,15 +295,14 @@ void KigPart::setupActions()
   a->setWhatsThis( i18n( "View this document full-screen." ) );
 
   // TODO: an icon for this..
-  tmp = l->loadIcon( "viewmagfit", KIcon::Toolbar );
   a = new KAction(
-    i18n( "&Select Shown Area" ), tmp, 0, m_widget, SLOT( zoomRect() ),
+    i18n( "&Select Shown Area" ), "viewmagfit", 0, m_widget, SLOT( zoomRect() ),
     actionCollection(), "view_select_shown_rect" );
   a->setToolTip( i18n( "Select the area that you want to be shown in the window." ) );
   a->setWhatsThis( i18n( "Select the area that you want to be shown in the window." ) );
 
   a = new KAction(
-    i18n( "S&elect Zoom Area" ), 0, m_widget, SLOT( zoomArea() ),
+    i18n( "S&elect Zoom Area" ), "viewmag", 0, m_widget, SLOT( zoomArea() ),
     actionCollection(), "view_zoom_area" );
 //  a->setToolTip( i18n( "Select the area that you want to be shown in the window." ) );
 //  a->setWhatsThis( i18n( "Select the area that you want to be shown in the window." ) );
@@ -323,6 +319,12 @@ void KigPart::setupActions()
   aToggleAxes->setToolTip( i18n( "Show or hide the axes." ) );
   aToggleAxes->setChecked( true );
 
+  aToggleNightVision = new KToggleAction(
+    i18n( "Wear Infrared Glasses" ), 0, this, SLOT( toggleNightVision() ),
+    actionCollection(), "settings_toggle_nightvision" );
+  aToggleNightVision->setToolTip( i18n( "Enable/Disable hidden objects visibility." ) );
+  aToggleNightVision->setChecked( false );
+
   // select coordinate system KActionMenu..
   aCoordSystem = new SetCoordinateSystemAction( *this, actionCollection() );
 }
@@ -347,10 +349,7 @@ KigPart::~KigPart()
   GUIActionList::instance()->unregDoc( this );
 
   // save our types...
-  QString typesDir = KGlobal::dirs()->saveLocation("appdata", "kig-types");
-  if (typesDir[typesDir.length() - 1] != '/') typesDir += '/';
-  MacroList* macrolist = MacroList::instance();
-  macrolist->save( macrolist->macros(), typesDir + "macros.kigt" );
+  saveTypes();
 
   // objects get deleted automatically, when mobjsref gets
   // destructed..
@@ -406,11 +405,12 @@ bool KigPart::openFile()
   coordSystemChanged( mdocument->coordinateSystem().id() );
   aToggleGrid->setChecked( mdocument->grid() );
   aToggleAxes->setChecked( mdocument->axes() );
+  aToggleNightVision->setChecked( mdocument->getNightVision() );
 
   setModified(false);
   mhistory->clear();
 
-  std::vector<ObjectCalcer*> tmp = calcPath( getAllParents( getCalcers( document().objects() ) ) );
+  std::vector<ObjectCalcer*> tmp = calcPath( getAllParents( getAllCalcers( document().objects() ) ) );
   for ( std::vector<ObjectCalcer*>::iterator i = tmp.begin(); i != tmp.end(); ++i )
     ( *i )->calc( document() );
   emit recenterScreen();
@@ -422,7 +422,7 @@ bool KigPart::openFile()
 
 bool KigPart::saveFile()
 {
-  if ( m_file.isEmpty() ) return internalSaveAs();
+  if ( m_file.isEmpty() || m_bTemp ) return internalSaveAs();
   // mimetype:
   KMimeType::Ptr mimeType = KMimeType::findByPath ( m_file );
   if ( mimeType->name() != "application/x-kig" )
@@ -534,7 +534,7 @@ void KigPart::delObjects( const std::vector<ObjectHolder*>& os )
   if ( os.size() < 1 ) return;
   std::set<ObjectHolder*> delobjs;
 
-  std::set<ObjectCalcer*> delcalcers = getAllChildren( getCalcers( os ) );
+  std::set<ObjectCalcer*> delcalcers = getAllChildren( getAllCalcers( os ) );
   std::map<ObjectCalcer*, ObjectHolder*> holdermap;
 
   std::set<ObjectHolder*> curobjs = document().objectsSet();
@@ -604,8 +604,8 @@ void KigPart::fileSave()
 bool KigPart::internalSaveAs()
 {
   // this slot is connected to the KStdAction::saveAs action...
-  QString formats;
-  formats = i18n("*.kig|Kig Documents (*.kig)");
+  QString formats = i18n( "*.kig|Kig Documents (*.kig)\n"
+                          "*.kigz|Compressed Kig Documents (*.kigz)" );
 
   //  formats += "\n";
   //  formats += KImageIO::pattern( KImageIO::Writing );
@@ -941,18 +941,14 @@ extern "C" int convertToNative( const KURL& url, const QCString& outfile )
     return -1;
   }
 
-  std::vector<ObjectCalcer*> tmp = calcPath( getAllParents( getCalcers( doc->objects() ) ) );
+  std::vector<ObjectCalcer*> tmp = calcPath( getAllParents( getAllCalcers( doc->objects() ) ) );
   for ( std::vector<ObjectCalcer*>::iterator i = tmp.begin(); i != tmp.end(); ++i )
     ( *i )->calc( *doc );
   for ( std::vector<ObjectCalcer*>::iterator i = tmp.begin(); i != tmp.end(); ++i )
     ( *i )->calc( *doc );
 
-  bool success = true;
-  QTextStream stdoutstream( stdout, IO_WriteOnly );
-  if ( outfile == "-" )
-    success = KigFilters::instance()->save( *doc, stdoutstream );
-  else
-    success = KigFilters::instance()->save( *doc, outfile );
+  QString out = ( outfile == "-" ) ? QString::null : outfile;
+  bool success = KigFilters::instance()->save( *doc, out );
   if ( !success )
   {
     kdError() << "something went wrong while saving" << endl;
@@ -962,7 +958,7 @@ extern "C" int convertToNative( const KURL& url, const QCString& outfile )
   delete doc;
 
   return 0;
-};
+}
 
 void KigPart::toggleGrid()
 {
@@ -982,7 +978,59 @@ void KigPart::toggleAxes()
   redrawScreen();
 }
 
+void KigPart::toggleNightVision()
+{
+  bool nv = !mdocument->getNightVision();
+  aToggleNightVision->setChecked( nv );
+  mdocument->setNightVision( nv );
+
+  redrawScreen();
+}
+
 void KigPart::coordSystemChanged( int id )
 {
   aCoordSystem->setCurrentItem( id );
 }
+
+void KigPart::saveTypes()
+{
+  QString typesDir = KGlobal::dirs()->saveLocation( "appdata", "kig-types" );
+  if ( typesDir[ typesDir.length() - 1 ] != '/' )
+    typesDir += '/';
+  QString typesFileWithPath = typesDir + typesFile;
+
+  // removing existant types file
+  if ( QFile::exists( typesFileWithPath ) )
+    QFile::remove( typesFileWithPath );
+
+  MacroList* macrolist = MacroList::instance();
+  macrolist->save( macrolist->macros(), typesFileWithPath );
+}
+
+void KigPart::loadTypes()
+{
+  QString typesDir = KGlobal::dirs()->saveLocation( "appdata", "kig-types" );
+  if ( typesDir[ typesDir.length() - 1 ] != '/' )
+    typesDir += '/';
+  QString typesFileWithPath = typesDir + typesFile;
+
+  if ( QFile::exists( typesFileWithPath ) )
+  {
+    std::vector<Macro*> macros;
+    MacroList::instance()->load( typesFileWithPath, macros, *this );
+    MacroList::instance()->add( macros );
+  }
+}
+
+void KigPart::deleteTypes()
+{
+  unplugActionLists();
+  typedef MacroList::vectype vec;
+  MacroList* macrolist = MacroList::instance();
+  const vec& macros = macrolist->macros();
+  for ( vec::const_reverse_iterator i = macros.rbegin(); i != macros.rend(); ++i )
+  {
+    macrolist->remove( *i );
+  }
+  plugActionLists();
+}
