@@ -1,4 +1,3 @@
-// builtin_stuff.cpp
 // Copyright (C)  2003  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -24,19 +23,26 @@
 #include "lists.h"
 #include "special_constructors.h"
 #include "guiaction.h"
-#include "i18n.h"
 
-#include "../objects/object_imp.h"
-#include "../objects/line_type.h"
-#include "../objects/intersection_types.h"
+#include "../objects/angle_type.h"
+#include "../objects/arc_type.h"
 #include "../objects/circle_type.h"
 #include "../objects/conic_types.h"
 #include "../objects/cubic_type.h"
-#include "../objects/other_type.h"
-#include "../objects/transform_types.h"
-#include "../objects/point_type.h"
-#include "../objects/other_imp.h"
+#include "../objects/intersection_types.h"
+#include "../objects/inversion_type.h"
 #include "../objects/line_imp.h"
+#include "../objects/line_type.h"
+#include "../objects/object_imp.h"
+#include "../objects/other_imp.h"
+#include "../objects/other_type.h"
+#include "../objects/point_type.h"
+#include "../objects/tests_type.h"
+#include "../objects/transform_types.h"
+#include "../objects/vector_type.h"
+#include "../objects/polygon_type.h"
+
+#include <klocale.h>
 
 void setupBuiltinStuff()
 {
@@ -64,8 +70,8 @@ void setupBuiltinStuff()
 
     // ray by two points..
     c = new SimpleObjectTypeConstructor(
-      RayABType::instance(), I18N_NOOP( "Ray" ),
-      I18N_NOOP( "A ray by its start point, and another point somewhere on it." ),
+      RayABType::instance(), I18N_NOOP( "Half-Line" ),
+      I18N_NOOP( "A half-line by its start point, and another point somewhere on it." ),
       "ray" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_ray", Qt::Key_R ) );
@@ -73,7 +79,7 @@ void setupBuiltinStuff()
     // perpendicular line
     c = new SimpleObjectTypeConstructor(
       LinePerpendLPType::instance(), I18N_NOOP( "Perpendicular" ),
-      I18N_NOOP( "A line constructed through a point, perpendicular on another line or segment." ),
+      I18N_NOOP( "A line constructed through a point, perpendicular to another line or segment." ),
       "perpendicular" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_lineperpend" ) );
@@ -89,7 +95,7 @@ void setupBuiltinStuff()
     // circle
     c = new SimpleObjectTypeConstructor(
       CircleBCPType::instance(), I18N_NOOP( "Circle by Center && Point" ),
-      I18N_NOOP( "A circle constructed by its center and a point on its border" ),
+      I18N_NOOP( "A circle constructed by its center and a point that pertains to it" ),
       "circlebcp" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_circlebcp", Qt::Key_C ) );
@@ -110,9 +116,13 @@ void setupBuiltinStuff()
     // we only register the guiaction, cause it makes sense to have a
     // toolbar icon for this..
     static PropertyObjectConstructor anglebisectionctor(
-      AngleImp::stype(), I18N_NOOP( "Construct the bisector of this angle" ),
-      I18N_NOOP( "Angle Bisector" ), I18N_NOOP( "The bisector of an angle" ),
-      "angle-bisector", "angle-bisector" );
+      AngleImp::stype(),
+      I18N_NOOP( "Construct Bisector of This Angle" ),
+      I18N_NOOP( "Select the angle you want to construct the bisector of..." ),
+      I18N_NOOP( "Angle Bisector" ),
+      I18N_NOOP( "The bisector of an angle" ),
+      "angle-bisector",
+      "angle-bisector" );
     actions->add( new ConstructibleAction( &anglebisectionctor, "objects_new_angle_bisector" ) );
 
     // conic stuff
@@ -133,16 +143,16 @@ void setupBuiltinStuff()
 
     c = new SimpleObjectTypeConstructor(
       EllipseBFFPType::instance(),
-      I18N_NOOP( "Ellipse by Focuses && Point" ),
-      I18N_NOOP( "An ellipse constructed by its focuses and a point on its border" ),
+      I18N_NOOP( "Ellipse by Focuses && Point" ), // focuses is used in preference to foci
+      I18N_NOOP( "An ellipse constructed by its focuses and a point that pertains to it" ),
       "ellipsebffp" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_ellipsebffp" ) );
 
     c = new SimpleObjectTypeConstructor(
       HyperbolaBFFPType::instance(),
-      I18N_NOOP( "Hyperbola by Focuses && Point" ),
-      I18N_NOOP( "A hyperbola constructed by its focuses and a point on its border" ),
+      I18N_NOOP( "Hyperbola by Focuses && Point" ), // focuses is used in preference to foci
+      I18N_NOOP( "A hyperbola constructed by its focuses and a point that pertains to it" ),
       "hyperbolabffp" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_hyperbolabffp" ) );
@@ -165,8 +175,8 @@ void setupBuiltinStuff()
 
     c = new SimpleObjectTypeConstructor(
       CubicB9PType::instance(),
-      I18N_NOOP( "Cubic by Nine Points" ),
-      I18N_NOOP( "A cubic constructed through nine points" ),
+      I18N_NOOP( "Cubic Curve by Nine Points" ),
+      I18N_NOOP( "A cubic curve constructed through nine points" ),
       "cubicb9p" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_cubicb9p" ) );
@@ -189,16 +199,16 @@ void setupBuiltinStuff()
 
     c = new SimpleObjectTypeConstructor(
       CubicNodeB6PType::instance(),
-      I18N_NOOP( "Cubic with Node by Six Points" ),
-      I18N_NOOP( "A cubic with a nodal point at the origin through six points" ),
+      I18N_NOOP( "Cubic Curve with Node by Six Points" ),
+      I18N_NOOP( "A cubic curve with a nodal point at the origin through six points" ),
       "cubicnodeb6p" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_cubicnodeb6p" ) );
 
     c = new SimpleObjectTypeConstructor(
       CubicCuspB4PType::instance(),
-      I18N_NOOP( "Cubic with Cusp by Four Points" ),
-      I18N_NOOP( "A cubic with a horizontal cusp at the origin through four points" ),
+      I18N_NOOP( "Cubic Curve with Cusp by Four Points" ),
+      I18N_NOOP( "A cubic curve with a horizontal cusp at the origin through four points" ),
       "cubiccuspb4p" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_cubiccuspb4p" ) );
@@ -240,7 +250,7 @@ void setupBuiltinStuff()
       ObjectConstructor* mpotp = new MidPointOfTwoPointsConstructor();
       ObjectConstructor* mpos = new PropertyObjectConstructor(
         SegmentImp::stype(), I18N_NOOP( "Construct the midpoint of this segment" ),
-        "", "", "", "mid-point" );
+        "", "", "", "", "mid-point" );
 
       // make this a static object, so it gets deleted at the end of
       // the program.
@@ -261,14 +271,47 @@ void setupBuiltinStuff()
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_vector", Qt::Key_V ) );
 
+    c = new SimpleObjectTypeConstructor(
+      VectorSumType::instance(),
+      I18N_NOOP( "Vector Sum" ),
+      I18N_NOOP( "Construct the vector sum of two vectors." ),
+      "vectorsum" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_vectorsum", 0 ) );
+
+    c = new SimpleObjectTypeConstructor(
+      LineByVectorType::instance(),
+      I18N_NOOP( "Line by Vector" ),
+      I18N_NOOP( "Construct the line by a given vector though a given point." ),
+      "linebyvector" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_linebyvector", 0 ) );
+
+    c = new SimpleObjectTypeConstructor(
+      HalflineByVectorType::instance(),
+      I18N_NOOP( "Half-Line by Vector" ),
+      I18N_NOOP( "Construct the half-line by a given vector starting at given point." ),
+      "halflinebyvector" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_halflinebyvector", 0 ) );
+
     c = new SimpleObjectTypeConstructor(
       ArcBTPType::instance(),
-      I18N_NOOP( "Arc" ),
+      I18N_NOOP( "Arc by Three Points" ),
       I18N_NOOP( "Construct an arc through three points." ),
       "arc" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_arcbtp" ) );
 
+    c = new SimpleObjectTypeConstructor(
+      ArcBCPAType::instance(),
+      I18N_NOOP( "Arc by Center, Angle && Point" ),
+      I18N_NOOP( "Construct an arc by its center and a given angle, "
+                 "starting at a given point" ),
+      "arcbcpa" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_arcbcpa" ) );
+
     c = new SimpleObjectTypeConstructor(
       ParabolaBDPType::instance(),
       I18N_NOOP( "Parabola by Directrix && Focus" ),
@@ -278,6 +321,10 @@ void setupBuiltinStuff()
     actions->add( new ConstructibleAction( c, "objects_new_parabolabdp" ) );
 
     // Transformation stuff..
+    c = new InversionConstructor();
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_inversion" ) );
+
     c = new SimpleObjectTypeConstructor(
       TranslatedType::instance(),
       I18N_NOOP( "Translate" ),
@@ -288,16 +335,16 @@ void setupBuiltinStuff()
 
     c = new SimpleObjectTypeConstructor(
       PointReflectionType::instance(),
-      I18N_NOOP( "Reflect over Point" ),
-      I18N_NOOP( "The reflection of an object over a point" ),
+      I18N_NOOP( "Reflect in Point" ),
+      I18N_NOOP( "An object reflected in a point" ),
       "centralsymmetry" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_pointreflection" ) );
 
     c = new SimpleObjectTypeConstructor(
       LineReflectionType::instance(),
-      I18N_NOOP( "Mirror" ),
-      I18N_NOOP( "The reflection of an object over a line" ),
+      I18N_NOOP( "Reflect in Line" ),
+      I18N_NOOP( "An object reflected in a line" ),
       "mirrorpoint" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_linereflection" ) );
@@ -321,11 +368,51 @@ void setupBuiltinStuff()
     c = new SimpleObjectTypeConstructor(
       ScalingOverLineType::instance(),
       I18N_NOOP( "Scale over Line" ),
-      I18N_NOOP( "An object scaled over a point, by the ratio given by the length of a segment" ),
+      I18N_NOOP( "An object scaled over a line, by the ratio given by the length of a segment" ),
       "stretch" );
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_scalingoverline" ) );
 
+    c = new SimpleObjectTypeConstructor(
+      ScalingOverCenter2Type::instance(),
+      I18N_NOOP( "Scale (ratio given by two segments)" ),
+      I18N_NOOP( "Scale an object over a point, by the ratio given by the length of two segments" ),
+      "scale" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_scalingovercenter2" ) );
+
+    c = new SimpleObjectTypeConstructor(
+      ScalingOverLine2Type::instance(),
+      I18N_NOOP( "Scale over Line (ratio given by two segments)" ),
+      I18N_NOOP( "An object scaled over a line, by the ratio given by the length of two segments" ),
+      "stretch" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_scalingoverline2" ) );
+
+    c = new SimpleObjectTypeConstructor(
+      SimilitudeType::instance(),
+      I18N_NOOP( "Apply Similitude" ),
+      I18N_NOOP( "Apply a similitude to an object ( the sequence of a scaling and rotation around a center )" ),
+      "similitude" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_similitude" ) );
+
+    c = new SimpleObjectTypeConstructor(
+      HarmonicHomologyType::instance(),
+      I18N_NOOP( "Harmonic Homology" ),
+      I18N_NOOP( "The harmonic homology with a given center and a given axis (this is a projective transformation)" ),
+      "harmonichomology" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_harmonichomology" ) );
+
+    c = new GenericAffinityConstructor();
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_genericaffinity" ) );
+
+    c = new GenericProjectivityConstructor();
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_genericprojectivity" ) );
+
     c = new SimpleObjectTypeConstructor(
       CastShadowType::instance(),
       I18N_NOOP( "Draw Projective Shadow" ),
@@ -337,7 +424,7 @@ void setupBuiltinStuff()
 //     c = new SimpleObjectTypeConstructor(
 //       ProjectiveRotationType::instance(),
 //       I18N_NOOP( "Rotate Projectively" ),
-//       I18N_NOOP( "An object projectively rotated by an angle and a ray" ),
+//       I18N_NOOP( "An object projectively rotated by an angle and a half-line" ),
 //       "projectiverotation" );
 //     ctors->add( c );
 //     actions->add( new ConstructibleAction( c, "objects_new_projectiverotation" ) );
@@ -354,21 +441,151 @@ void setupBuiltinStuff()
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_lineconicradical") );
 
+    /* ----------- start polygons --------- */
+
+    c = new SimpleObjectTypeConstructor(
+      TriangleB3PType::instance(),
+      I18N_NOOP( "Triangle by Its Vertices" ),
+      I18N_NOOP( "Construct a triangle given its three vertices." ),
+      "triangle" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_trianglebtp" ) );
+
+    c = new PolygonBNPTypeConstructor();
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_polygonbnp" ));
+
+    c = new PolygonBCVConstructor();
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_polygonbcv" ) );
+
+    c = new PolygonVertexTypeConstructor();
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_polygonvertices" ));
+
+    c = new PolygonSideTypeConstructor();
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_polygonsides" ));
+
+    c = new SimpleObjectTypeConstructor(
+      ConvexHullType::instance(), I18N_NOOP( "Convex Hull" ),
+      I18N_NOOP( "A polygon that corresponds to the convex hull of another polygon" ),
+      "convexhull" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_convexhull" ) );
+
+    /* ----------- end polygons --------- */
+
     c = new LocusConstructor();
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_locus" ) );
 
+    // tests
+    c = new TestConstructor(
+      AreParallelType::instance(),
+      I18N_NOOP( "Parallel Test" ),
+      I18N_NOOP( "Test whether two given lines are parallel" ),
+      "testparallel" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_areparallel" ) );
+
+    c = new TestConstructor(
+      AreOrthogonalType::instance(),
+      I18N_NOOP( "Orthogonal Test" ),
+      I18N_NOOP( "Test whether two given lines are orthogonal" ),
+      "testorthogonal" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_areorthogonal" ) );
+
+    c = new TestConstructor(
+      AreCollinearType::instance(),
+      I18N_NOOP( "Collinear Test" ),
+      I18N_NOOP( "Test whether three given points are collinear" ),
+      "testcollinear" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_arecollinear" ) );
+
+    c = new TestConstructor(
+      ContainsTestType::instance(),
+      I18N_NOOP( "Contains Test" ),
+      I18N_NOOP( "Test whether a given curve contains a given point" ),
+      "testcontains" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_containstest" ) );
+
+    c = new TestConstructor(
+      InPolygonTestType::instance(),
+      I18N_NOOP( "In Polygon Test" ),
+      I18N_NOOP( "Test whether a given polygon contains a given point" ),
+      "test" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_inpolygontest" ) );
+
+    c = new TestConstructor(
+      ConvexPolygonTestType::instance(),
+      I18N_NOOP( "Convex Polygon Test" ),
+      I18N_NOOP( "Test whether a given polygon is convex" ),
+      "test" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_convexpolygontest" ) );
+
+    c = new TestConstructor(
+      SameDistanceType::instance(),
+      I18N_NOOP( "Distance Test" ),
+      I18N_NOOP( "Test whether a given point have the same distance from a given point "
+                 "and from another given point" ),
+      "test" );
+//      "testdistance" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_distancetest" ) );
+
+    c = new TestConstructor(
+      VectorEqualityTestType::instance(),
+      I18N_NOOP( "Vector Equality Test" ),
+      I18N_NOOP( "Test whether two vectors are equal" ),
+      "test" );
+//      "testequal" );
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_vectorequalitytest" ) );
+
+    c = new MeasureTransportConstructor();
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_measuretransport" ));
+
+//    c = new SimpleObjectTypeConstructor(
+//      MeasureTransportType::instance(),
+//      I18N_NOOP( "Measure Transport" ),
+//      I18N_NOOP( "Transport the measure of a segment or arc over a line or circle." ),
+//      "measuretransport" );
+//    ctors->add( c );
+//    actions->add( new ConstructibleAction( c, "objects_new_measuretransport" ) );
+
     // the generic intersection constructor..
     c = new GenericIntersectionConstructor();
     ctors->add( c );
     actions->add( new ConstructibleAction( c, "objects_new_intersection", Qt::Key_I ) );
 
+    // the generic tangent constructor
+    c = new TangentConstructor();
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_tangent", Qt::Key_T ) );
+
+    // the generic center of curvature constructor
+    c = new CocConstructor();
+    ctors->add( c );
+    actions->add( new ConstructibleAction( c, "objects_new_centerofcurvature" ) );
+
     actions->add( new ConstructPointAction( "objects_new_normalpoint" ) );
     actions->add( new ConstructTextLabelAction( "objects_new_textlabel" ) );
     actions->add( new AddFixedPointAction( "objects_new_point_xy" ) );
 
 #ifdef KIG_ENABLE_PYTHON_SCRIPTING
-    actions->add( new NewScriptAction( "objects_new_script_object" ) );
+#include "../scripting/script-common.h"
+    actions->add( new NewScriptAction(
+                        I18N_NOOP( "Python Script" ),
+                        I18N_NOOP( "Construct a new Python script." ),
+                        "objects_new_script_python",
+                        ScriptType::Python ) );
 #endif
 
 #if 0
