@@ -471,8 +471,9 @@ const LineData calcConicAsymptote(
   double d=data.coeffs[3];
   double e=data.coeffs[4];
 
+  double normabc = a*a + b*b + c*c;
   double delta = c*c - 4*a*b;
-  if (fabs(delta) < 1e-6) { valid = false; return ret; }
+  if (fabs(delta) < 1e-6*normabc) { valid = false; return ret; }
 
   double yc = (2*a*e - c*d)/delta;
   double xc = (2*b*d - c*e)/delta;
@@ -832,6 +833,7 @@ const ConicCartesianData calcConicTransformation (
   Transformation ti = t.inverse( valid );
   if ( ! valid ) return ConicCartesianData();
 
+  double supnorm = 0.0;
   for (int i = 0; i < 3; i++)
   {
     for (int j = 0; j < 3; j++)
@@ -844,6 +846,15 @@ const ConicCartesianData calcConicTransformation (
 	  b[i][j] += a[ii][jj]*ti.data( ii, i )*ti.data( jj, j );
 	}
       }
+      if ( std::fabs( b[i][j] ) > supnorm ) supnorm = std::fabs( b[i][j] );
+    }
+  }
+
+  for (int i = 0; i < 3; i++)
+  {
+    for (int j = 0; j < 3; j++)
+    {
+      b[i][j] /= supnorm;
     }
   }
 
