@@ -21,7 +21,9 @@
 #include "kigpainter.h"
 
 #include "../kig/kig_view.h"
-#include "../objects/object.h"
+#include "../kig/kig_document.h"
+#include "../misc/goniometry.h"
+#include "../objects/object_holder.h"
 #include "../objects/curve_imp.h"
 #include "../objects/point_imp.h"
 #include "object_hierarchy.h"
@@ -40,6 +42,12 @@
 KigPainter::KigPainter( const ScreenInfo& si, QPaintDevice* device,
                         const KigDocument& doc, bool no )
   : mP ( device ),
+    color( Qt::blue ),
+    style( Qt::SolidLine ),
+    pointstyle( 0 ),
+    width( -1 ),
+    brushStyle( Qt::NoBrush ),
+    brushColor( Qt::blue ),
     mdoc( doc ),
     msi( si ),
     mNeedOverlay( no ),
@@ -88,16 +96,79 @@ void KigPainter::drawFatPoint( const Coordinate& p )
 {
   int twidth = width == -1 ? 5 : width;
   mP.setPen( QPen( color, 1, style ) );
-  double radius = twidth * pixelWidth();
-  setBrushStyle( Qt::SolidPattern );
-  Coordinate rad( radius, radius );
-  rad /= 2;
-  Coordinate tl = p - rad;
-  Coordinate br = p + rad;
-  Rect r( tl, br );
-  QRect qr = toScreen( r );
-  mP.drawEllipse( qr );
-  if( mNeedOverlay ) mOverlay.push_back( qr );
+  switch ( pointstyle )
+  {
+    case 0:
+    {
+      double radius = twidth * pixelWidth();
+      setBrushStyle( Qt::SolidPattern );
+      Coordinate rad( radius, radius );
+      rad /= 2;
+      Coordinate tl = p - rad;
+      Coordinate br = p + rad;
+      Rect r( tl, br );
+      QRect qr = toScreen( r );
+      mP.drawEllipse( qr );
+      if( mNeedOverlay ) mOverlay.push_back( qr );
+      break;
+    }
+    case 1:
+    {
+      double radius = twidth * pixelWidth();
+      setBrushStyle( Qt::NoBrush );
+      Coordinate rad( radius, radius );
+      rad /= 2;
+      Coordinate tl = p - rad;
+      Coordinate br = p + rad;
+      Rect r( tl, br );
+      QRect qr = toScreen( r );
+      mP.drawEllipse( qr );
+      if( mNeedOverlay ) mOverlay.push_back( qr );
+      break;
+    }
+    case 2:
+    {
+      double radius = twidth * pixelWidth();
+      Coordinate rad( radius, radius );
+      rad /= 2;
+      Coordinate tl = p - rad;
+      Coordinate br = p + rad;
+      Rect r( tl, br );
+      QRect qr = toScreen( r );
+      mP.drawRect( qr );
+      mP.fillRect( qr, QBrush( color, Qt::SolidPattern ) );
+      if( mNeedOverlay ) mOverlay.push_back( qr );
+      break;
+    }
+    case 3:
+    {
+      double radius = twidth * pixelWidth();
+      Coordinate rad( radius, radius );
+      rad /= 2;
+      Coordinate tl = p - rad;
+      Coordinate br = p + rad;
+      Rect r( tl, br );
+      QRect qr = toScreen( r );
+      mP.drawRect( qr );
+      if( mNeedOverlay ) mOverlay.push_back( qr );
+      break;
+    }
+    case 4:
+    {
+      double radius = twidth * pixelWidth();
+      Coordinate rad( radius, radius );
+      rad /= 2;
+      Coordinate tl = p - rad;
+      Coordinate br = p + rad;
+      Rect r( tl, br );
+      QRect qr = toScreen( r );
+      mP.setPen( QPen( color, 2 ) );
+      mP.drawLine( qr.topLeft(), qr.bottomRight() );
+      mP.drawLine( qr.topRight(), qr.bottomLeft() );
+      if( mNeedOverlay ) mOverlay.push_back( qr );
+      break;
+    }
+  }
   mP.setPen( QPen( color, twidth, style ) );
 }
 
@@ -116,6 +187,9 @@ void KigPainter::drawText( const Rect p, const QString s, int textFlags, int len
 {
   QRect t = toScreen(p);
   int tf = textFlags;
+  t.moveBy( 2, 2 );
+  t.setWidth( t.width() - 4 );
+  t.setHeight( t.height() - 4 );
   mP.drawText( t, tf, s, len );
   if( mNeedOverlay ) textOverlay( t, s, tf, len );
 }
@@ -123,13 +197,21 @@ void KigPainter::drawText( const Rect p, const QString s, int textFlags, int len
 void KigPainter::textOverlay( const QRect& r, const QString s, int textFlags, int len )
 {
   //  kdDebug() << Rect::fromQRect( mP.boundingRect( r, textFlags, s, len ) ) << endl;
-  mOverlay.push_back( mP.boundingRect( r, textFlags, s, len ) );
+  QRect newr( mP.boundingRect( r, textFlags, s, len ) );
+  newr.moveBy( -2, -2 );
+  newr.setWidth( newr.width() + 4 );
+  newr.setHeight( newr.height() + 4 );
+  mOverlay.push_back( newr );
 }
 
 const Rect KigPainter::boundingRect( const Rect& r, const QString s,
                                      int f, int l ) const
 {
-  return fromScreen( mP.boundingRect( toScreen( r ), f, s, l ) );
+  QRect qr = mP.boundingRect( toScreen( r ), f, s, l );
+  qr.moveBy( -2, -2 );
+  qr.setWidth( qr.width() + 4 );
+  qr.setHeight( qr.height() + 4 );
+  return fromScreen( qr );
 }
 
 void KigPainter::setColor( const QColor& c )
@@ -151,6 +233,11 @@ void KigPainter::setWidth( const int c )
   mP.setPen( QPen( color, width == -1 ? 1 : width, style ) );
 }
 
+void KigPainter::setPointStyle( const int p )
+{
+  pointstyle = p;
+}
+
 void KigPainter::setPen( const QPen& p )
 {
   color = p.color();
@@ -178,31 +265,69 @@ void KigPainter::setBrushColor( const QColor& c )
   mP.setBrush( QBrush( brushColor, brushStyle ) );
 }
 
+bool KigPainter::getNightVision( ) const
+{
+  return mdoc.getNightVision();
+}
+
+QColor KigPainter::getColor() const
+{
+  return color;
+}
+
+/*
 static void setContains( QRect& r, const QPoint& p )
 {
   if ( r.left() > p.x() ) r.setLeft( p.x() );
   if ( r.right() < p.x() ) r.setRight( p.x() );
   // this is correct, i think.  In qt the bottom has the highest y
   // coord...
-  if ( r.bottom() < p.y() ) r.setBottom( p.x() );
-  if ( r.top() < p.y() ) r.setTop( p.x() );
+  if ( r.bottom() > p.y() ) r.setBottom( p.y() );
+  if ( r.top() < p.y() ) r.setTop( p.y() );
 }
+*/
 
 void KigPainter::drawPolygon( const std::vector<QPoint>& pts,
                               bool winding, int index, int npoints )
 {
-  QRect sr;
+  QPen oldpen = mP.pen();
+  QBrush oldbrush = mP.brush();
+  setBrush( QBrush( color, Dense4Pattern ) );
+  setPen( Qt::NoPen );
   // i know this isn't really fast, but i blame it all on Qt with its
   // stupid container classes... what's wrong with the STL ?
   QPointArray t( pts.size() );
   int c = 0;
   for( std::vector<QPoint>::const_iterator i = pts.begin(); i != pts.end(); ++i )
   {
-    setContains( sr, *i );
     t.putPoints( c++, 1, i->x(), i->y() );
   };
   mP.drawPolygon( t, winding, index, npoints );
-  mOverlay.push_back( sr );
+  setPen( oldpen );
+  setBrush( oldbrush );
+  if( mNeedOverlay ) mOverlay.push_back( t.boundingRect() );
+}
+
+void KigPainter::drawArea( const std::vector<Coordinate>& pts, bool border )
+{
+  QPen oldpen = mP.pen();
+  QBrush oldbrush = mP.brush();
+  setBrush( QBrush( color, SolidPattern ) );
+  if ( border )
+    setPen( QPen( color, width == -1 ? 1 : width ) );
+  else
+    setPen( Qt::NoPen );
+  QPointArray t( pts.size() );
+  int c = 0;
+  for( std::vector<Coordinate>::const_iterator i = pts.begin(); i != pts.end(); ++i )
+  {
+    QPoint p = toScreen( *i );
+    t.putPoints( c++, 1, p.x(), p.y() );
+  }
+  mP.drawPolygon( t );
+  setPen( oldpen );
+  setBrush( oldbrush );
+  if( mNeedOverlay ) mOverlay.push_back( t.boundingRect() );
 }
 
 Rect KigPainter::window()
@@ -364,17 +489,14 @@ void KigPainter::drawGrid( const CoordinateSystem& c, bool showGrid, bool showAx
   setWholeWinOverlay();
 }
 
-void KigPainter::drawObject( const Object* o, bool ss )
+void KigPainter::drawObject( const ObjectHolder* o, bool ss )
 {
   o->draw( *this, ss );
 }
 
-void KigPainter::drawObjects( const Objects& os )
+void KigPainter::drawObjects( const std::vector<ObjectHolder*>& os, bool sel )
 {
-  for ( Objects::const_iterator i = os.begin(); i != os.end(); ++i )
-  {
-    drawObject( *i );
-  };
+  drawObjects( os.begin(), os.end(), sel );
 }
 
 void KigPainter::drawFilledRect( const QRect& r )
@@ -459,18 +581,6 @@ void KigPainter::drawRay( const Coordinate& a, const Coordinate& b )
   drawSegment( a, tb );
 }
 
-inline Coordinate conicGetCoord( double theta, double ecostheta0,
-                                 double esintheta0, double pdimen,
-                                 const Coordinate& focus1 )
-{
-  // TODO: eliminate some cos() and sin() calls with a table...
-  double costheta = cos( theta );
-  double sintheta = sin( theta );
-  double ecosthetamtheta = costheta*ecostheta0 + sintheta*esintheta0;
-  double rho = pdimen / (1.0 - ecosthetamtheta);
-  return focus1 + rho * Coordinate( costheta, sintheta );
-}
-
 typedef std::pair<double,Coordinate> coordparampair;
 
 struct workitem
@@ -482,244 +592,13 @@ struct workitem
   Rect		 *overlay;
 };
 
-void KigPainter::drawConic( const ConicPolarData& data )
-{
-  // @author Maurizio Paolini wrote an original version of this, ( the
-  // math in conicGetCoord() is still his ), I ( Dominique ) adapted
-  // it afterwards to use a distribution mechanism as explained
-  // below. )
-
-  // this function works more or less like Locus::calcForWidget():
-  // we calc some initial points, draw them, and then keep checking if
-  // the point with the param in between two other points.  If the
-  // point with that param is not too close to one of them, and if it
-  // is in the current window(), then we draw it, and put it on the
-  // stack for further processing...
-
-  Coordinate focus1 = data.focus1;
-  double pdimen = data.pdimen;
-  double ecostheta0 = data.ecostheta0;
-  double esintheta0 = data.esintheta0;
-
-  // we manage our own overlay
-  bool tNeedOverlay = mNeedOverlay;
-  mNeedOverlay = false;
-  QPen pen = mP.pen();
-  pen.setCapStyle( Qt::RoundCap );
-  mP.setPen( pen );
-
-  // this stack contains pairs of Coordinates that we still need to
-  // process:
-  std::stack<workitem> workstack;
-  // mp: this stack contains all the generated overlays:
-  // the strategy for generating the overlay structure is the same
-  // recursive-like used to draw the segments: a new rectangle is
-  // generated whenever the length of a segment becomes lower than
-  // overlayRectSize(), or if the segment would be drawn anyway
-  // to avoid strange things from happening we impose that the
-  // distance in parameter space be less than a threshold before
-  // generating any overlay.
-  //
-  // The third parameter in workitem is a pointer into a stack of
-  // all generated rectangles (in real coordinate space); if 0
-  // there is no rectangles associated to that segment yet.
-  //
-  // Using the final mOverlay stack would be much more efficient, but
-  // 1. needs transformations into window space
-  // 2. would be more difficult to drop rectangles not intersecting
-  //    the window.
-  std::stack<Rect> overlaystack;
-
-  // mp: the original version in which an initial set of 20 intervals
-  // were pushed onto the stack is replaced by a single interval and
-  // by forcing subdivision till h < hmax (with more or less the same
-  // final result).
-  // First push the [0,2*pi] interval into the stack:
-  workstack.push( workitem(
-                    coordparampair( 0, conicGetCoord( 0, ecostheta0, esintheta0,
-                                                      pdimen, focus1 ) ),
-                    coordparampair( 2*M_PI, conicGetCoord( 2*M_PI, ecostheta0, esintheta0,
-                                                           pdimen, focus1 ) ),
-                    0 ) );
-
-  // maxlength is the square of the maximum size that we allow
-  // between two points..
-  double maxlength = 1.5 * pixelWidth();
-  maxlength *= maxlength;
-  // error squared is required to be less that sigma (half pixel)
-  double sigma = maxlength/4;
-  // distance between two parameter values cannot be too small
-  double hmin = 1e-4;
-  // distance between two parameter values cannot be too large
-  double hmax = M_PI/20;
-  double hmaxoverlay = M_PI/4;
-
-  int count = 1;               // the number of segments we've already
-                               // visited...
-  static const int maxnumberofpoints = 1000;
-
-  const Rect& sr = window();
-
-  // we don't use recursion, but a stack based approach for efficiency
-  // concerns...
-  while ( ! workstack.empty() && count < maxnumberofpoints )
-  {
-    workitem curitem = workstack.top();
-    workstack.pop();
-    bool curitemok = true;
-    while ( curitemok && count++ < maxnumberofpoints )
-    {
-      // we take the middle parameter of the two previous points...
-      Coordinate p0 = curitem.first.second;
-      Coordinate p1 = curitem.second.second;
-      double t2 = ( curitem.first.first + curitem.second.first ) / 2;
-      double h = fabs( curitem.second.first - curitem.first.first ) /2;
-      Rect *overlaypt = curitem.overlay;
-      Coordinate p2 = conicGetCoord( t2, ecostheta0, esintheta0,
-                                     pdimen, focus1 );
-      bool dooverlay = ! overlaypt && h < hmaxoverlay
- && fabs( p0.x - p1.x ) <= overlayRectSize()
- && fabs( p0.y - p1.y ) <= overlayRectSize();
-      bool addn = sr.contains( p2 );
-      // estimated error between the curve and the segments
-      double errsq = (0.5*p0 + 0.5*p1 - p2).squareLength();
-      errsq /= 4;
-      curitemok = false;
-      bool dodraw = h < hmax && ( errsq < sigma || h < hmin );
-      if ( tNeedOverlay && ( dooverlay || dodraw ) )
-      {
-        Rect newoverlay( p0, p1 );
-        overlaystack.push( newoverlay );
-        overlaypt = &overlaystack.top();
-      }
-      if ( overlaypt ) overlaypt->setContains( p2 );
-      if ( dodraw )
-      {
-        // draw the two segments
-        QPoint tp0 = toScreen(p0);
-        QPoint tp1 = toScreen(p1);
-        QPoint tp2 = toScreen(p2);
-        mP.drawLine( tp0, tp2 );
-        mP.drawLine( tp2, tp1 );
-      }
-      else
-      {
-        // push into stack in order to process both subintervals
-        if (addn || sr.contains( p0 ) || h >= hmax)
-          workstack.push( workitem( curitem.first, coordparampair( t2, p2 ),
-                                    overlaypt ) );
-        if (addn || sr.contains( p1 ) || h >= hmax)
-        {
-          curitem = workitem( coordparampair( t2, p2 ), curitem.second ,
-                              overlaypt );
-          curitemok = true;
-        }
-      }
-    }
-  }
-
-  assert ( tNeedOverlay || overlaystack.empty() );
-  if ( tNeedOverlay )
-  {
-    Rect border = window();
-    while ( ! overlaystack.empty() )
-    {
-      Rect overlay = overlaystack.top();
-      overlaystack.pop();
-      if (overlay.intersects( border ))
-        mOverlay.push_back( toScreenEnlarge( overlay ) );
-    }
-  }
-  mNeedOverlay = tNeedOverlay;
-  pen.setCapStyle( Qt::FlatCap );
-  mP.setPen( pen );
-}
-
-void KigPainter::drawCubicRecurse (
-  double& xleft, double& yleft, bool& validleft,
-  int& numrootsleft,
-  double &xright, double &yright, bool &validright,
-  int &numrootsright,
-  const CubicCartesianData &data, int &root,
-  double &ymin, double &ymax, double &tol,
-  bool& tNeedOverlay, Rect& overlay)
-{
-  double ltol = tol;
-  if ( ! ( validleft && validright && numrootsleft == numrootsright ) )
-    // in questo caso la tolleranza e' molto minore
-    ltol /= 100;
-  if ( xright - xleft < ltol )
-  {
-    if ( validleft && validright && numrootsleft == numrootsright )
-    {
-      /* draw the segment */
-      Coordinate pleft = Coordinate( xleft, yleft );
-      Coordinate pright = Coordinate( xright, yright );
-      QPoint tpleft = toScreen(pleft);
-      QPoint tpright = toScreen(pright);
-      mP.drawLine( tpleft, tpright );
-    }
-  } else {
-    double xmiddle = (xright + xleft)/2;
-    bool validmiddle;
-    int numrootsmiddle;
-    double ymiddle = calcCubicYvalue ( xmiddle, ymin, ymax, root, data,
-                                       validmiddle, numrootsmiddle );
-    Coordinate pmiddle = Coordinate( xmiddle, ymiddle );
-    if ( validmiddle && tNeedOverlay ) overlay.setContains( pmiddle );
-    drawCubicRecurse ( xleft, yleft, validleft, numrootsleft,
-                   xmiddle, ymiddle, validmiddle, numrootsmiddle,
-                   data, root, ymin, ymax, tol, tNeedOverlay, overlay );
-    drawCubicRecurse ( xmiddle, ymiddle, validmiddle, numrootsmiddle,
-                   xright, yright, validright, numrootsright,
-                   data, root, ymin, ymax, tol, tNeedOverlay, overlay );
-  }
-}
-
-void KigPainter::drawCubic( const CubicCartesianData& data )
-{
-  // we manage our own overlay
-  bool tNeedOverlay = mNeedOverlay;
-  mNeedOverlay = false;
-  QPen pen = mP.pen();
-  pen.setCapStyle( Qt::RoundCap );
-  mP.setPen( pen );
-  Rect border = window();
-  Rect overlay;
-
-  double ymin = border.bottom();
-  double ymax = border.top();
-  bool validleft, validright;
-  int numrootsleft, numrootsright;
-
-  double xleft = border.left();
-  double xright = border.right();
-  double tol = (xright - xleft)/100;
-  for ( int root = 1; root <= 3; root++ )
-  {
-    double yleft = calcCubicYvalue ( xleft, ymin, ymax, root, data,
-                   validleft, numrootsleft );
-    double yright = calcCubicYvalue ( xright, ymin, ymax, root, data,
-                   validright, numrootsright );
-    Coordinate p = Coordinate( xleft, yleft );
-    if ( validleft && tNeedOverlay ) overlay.setContains( p );
-    p = Coordinate( xright, yright );
-    if ( validright && tNeedOverlay ) overlay.setContains( p );
-    drawCubicRecurse ( xleft, yleft, validleft, numrootsleft,
-                   xright, yright, validright, numrootsright,
-                   data, root, ymin, ymax, tol,
-                   tNeedOverlay, overlay);
-  }
-  if ( tNeedOverlay ) mOverlay.push_back( toScreen( overlay ) );
-  mNeedOverlay = tNeedOverlay;
-  pen.setCapStyle( Qt::FlatCap );
-  mP.setPen( pen );
-}
-
 void KigPainter::drawLine( const LineData& d )
 {
-  LineData l = calcBorderPoints( d, window() );
-  drawSegment( l.a, l.b );
+  if ( d.a != d.b )
+  {
+    LineData l = calcBorderPoints( d, window() );
+    drawSegment( l.a, l.b );
+  }
 }
 
 void KigPainter::drawSegment( const LineData& d )
@@ -736,8 +615,8 @@ void KigPainter::drawAngle( const Coordinate& cpoint, const double dstartangle,
                             const double dangle )
 {
   // convert to 16th of degrees...
-  const int startangle = static_cast<int>( 16*180*dstartangle / M_PI );
-  const int angle = static_cast<int>( 16*180*dangle / M_PI );
+  const int startangle = static_cast<int>( Goniometry::convert( 16 * dstartangle, Goniometry::Rad, Goniometry::Deg ) );
+  const int angle = static_cast<int>( Goniometry::convert( 16 * dangle, Goniometry::Rad, Goniometry::Deg ) );
 
   QPoint point = toScreen( cpoint );
 
@@ -757,16 +636,22 @@ void KigPainter::drawAngle( const Coordinate& cpoint, const double dstartangle,
   vect = vect * 6 / vectlen;
   orthvect = orthvect * 6 / vectlen;
 
-  std::vector<QPoint> arrow;
-  arrow.push_back( end );
-  arrow.push_back( end + orthvect + vect );
-  arrow.push_back( end + orthvect - vect );
+  QPointArray arrow( 3 );
+  arrow.setPoint( 0, end );
+  arrow.setPoint( 1, end + orthvect + vect );
+  arrow.setPoint( 2, end + orthvect - vect );
+//  std::vector<QPoint> arrow;
+//  arrow.push_back( end );
+//  arrow.push_back( end + orthvect + vect );
+//  arrow.push_back( end + orthvect - vect );
 
   setBrushStyle( Qt::SolidPattern );
-  drawPolygon( arrow );
+//  drawPolygon( arrow );
+  mP.drawPolygon( arrow, false, 0, -1 );
 
 //  if ( mNeedOverlay ) mOverlay.push_back( toScreen( r ) );
-  setWholeWinOverlay();
+  setWholeWinOverlay();   //mp: ugly! why not compute a correct overlay?
+                          //    mOverlay.push_back( arrow.boundingRect() ); 
 }
 
 void KigPainter::drawPolygon( const std::vector<Coordinate>& pts,
@@ -822,7 +707,23 @@ inline Coordinate locusGetCoord( double p, const CurveImp* curve, const ObjectHi
   delete o;
   return ret;
 };
- */
+*/
+
+class CurveImpPointCalcer
+{
+  const CurveImp* curve;
+public:
+  CurveImpPointCalcer( const CurveImp* c )
+    : curve( c )
+    {
+    };
+  static const double endinterval;
+  inline const Coordinate getPoint( double param, const KigDocument& d ) const {
+    return curve->getPoint( param, d );
+  }
+};
+
+const double CurveImpPointCalcer::endinterval = 1.;
 
 void KigPainter::drawCurve( const CurveImp* curve )
 {
@@ -831,11 +732,9 @@ void KigPainter::drawCurve( const CurveImp* curve )
   mNeedOverlay = false;
 
   QPen pen = mP.pen();
-  pen.setCapStyle( Qt::RoundCap );
-  mP.setPen( pen );
 
-  // this stack contains pairs of Coordinates that we still need to
-  // process:
+  // this stack contains pairs of Coordinates ( parameter intervals )
+  // that we still need to process:
   std::stack<workitem> workstack;
   // mp: this stack contains all the generated overlays:
   // the strategy for generating the overlay structure is the same
@@ -856,21 +755,17 @@ void KigPainter::drawCurve( const CurveImp* curve )
   //    the window.
   std::stack<Rect> overlaystack;
 
-  bool valid = true; ///
-
   // mp: the original version in which an initial set of 20 intervals
   // were pushed onto the stack is replaced by a single interval and
   // by forcing subdivision till h < hmax (with more or less the same
   // final result).
   // First push the [0,1] interval into the stack:
 
-  Coordinate coo1 = curve->getPoint( 0, valid, mdoc );
-  if ( ! valid ) coo1 = coo1.invalidCoord();
-  Coordinate coo2 = curve->getPoint( 1, valid, mdoc );
-  if ( ! valid ) coo2 = coo2.invalidCoord();
+  Coordinate coo1 = curve->getPoint( 0., mdoc );
+  Coordinate coo2 = curve->getPoint( 1., mdoc );
   workstack.push( workitem(
-                    coordparampair( 0, coo1 ),
-                    coordparampair( 1, coo2 ),
+                    coordparampair( 0., coo1 ),
+                    coordparampair( 1., coo2 ),
                     0 ) );
 
   // maxlength is the square of the maximum size that we allow
@@ -882,8 +777,8 @@ void KigPainter::drawCurve( const CurveImp* curve )
   // distance between two parameter values cannot be too small
   double hmin = 3e-5;
   // distance between two parameter values cannot be too large
-  double hmax = 1.0/40;
-  double hmaxoverlay = 1.0/8;
+  double hmax = 1./40;
+  double hmaxoverlay = 1./8;
 
   int count = 1;               // the number of segments we've already
                                // visited...
@@ -891,6 +786,15 @@ void KigPainter::drawCurve( const CurveImp* curve )
 
   const Rect& sr = window();
 
+  // what this algorithm does is approximating the curve with a set of
+  // segments.  we don't draw the individual segments, but use
+  // QPainter::drawPolyline() so that the line styles work properly.
+  // Possibly there are performance advantages as well ?  this array
+  // is a buffer of the polyline approximation of the part of the
+  // curve that we are currently processing.
+  QPointArray curpolyline( 1000 );
+  int curpolylinenextfree = 0;
+
   // we don't use recursion, but a stack based approach for efficiency
   // concerns...
   while ( ! workstack.empty() && count < maxnumberofpoints )
@@ -903,11 +807,9 @@ void KigPainter::drawCurve( const CurveImp* curve )
       double t0 = curitem.first.first;
       double t1 = curitem.second.first;
       Coordinate p0 = curitem.first.second;
-      bool valid0 = true;
-      if ( ! p0.valid() ) valid0 = false;
+      bool valid0 = p0.valid();
       Coordinate p1 = curitem.second.second;
-      bool valid1 = true;
-      if ( ! p1.valid() ) valid1 = false;
+      bool valid1 = p1.valid();
 
       // we take the middle parameter of the two previous points...
       double t2 = ( t0 + t1 ) / 2;
@@ -926,13 +828,12 @@ void KigPainter::drawCurve( const CurveImp* curve )
 //      }
 
       Rect *overlaypt = curitem.overlay;
-      Coordinate p2 = curve->getPoint( t2, valid, mdoc );
-      if ( ! valid ) p2 = p2.invalidCoord();
-      bool allvalid = valid && valid0 && valid1;
+      Coordinate p2 = curve->getPoint( t2, mdoc );
+      bool allvalid = p2.valid() && valid0 && valid1;
       bool dooverlay = ! overlaypt && h < hmaxoverlay && valid0 && valid1
- && fabs( p0.x - p1.x ) <= overlayRectSize()
- && fabs( p0.y - p1.y ) <= overlayRectSize();
-      bool addn = valid && sr.contains( p2 );
+                       && fabs( p0.x - p1.x ) <= overlayRectSize()
+                       && fabs( p0.y - p1.y ) <= overlayRectSize();
+      bool addn = sr.contains( p2 ) || h >= hmax;
       // estimated error between the curve and the segments
       double errsq = 1e21;
       if ( allvalid ) errsq = (0.5*p0 + 0.5*p1 - p2).squareLength();
@@ -953,16 +854,24 @@ void KigPainter::drawCurve( const CurveImp* curve )
         QPoint tp0 = toScreen(p0);
         QPoint tp1 = toScreen(p1);
         QPoint tp2 = toScreen(p2);
-        mP.drawLine( tp0, tp2 );
-        mP.drawLine( tp2, tp1 );
+        if ( curpolylinenextfree > 0 && curpolyline[curpolylinenextfree - 1] != tp1 )
+        {
+          // flush the current part of the curve
+          mP.drawPolyline( curpolyline, 0, curpolylinenextfree );
+          curpolylinenextfree = 0;
+        }
+        if ( curpolylinenextfree == 0 )
+          curpolyline[curpolylinenextfree++] = tp1;
+        curpolyline[curpolylinenextfree++] = tp2;
+        curpolyline[curpolylinenextfree++] = tp0;
       }
       else if ( h >= hmin )   // we do not continue to subdivide indefinitely!
       {
         // push into stack in order to process both subintervals
-        if ( addn || ( valid0 && sr.contains( p0 ) ) || h >= hmax )
+        if ( addn || ( valid0 && sr.contains( p0 ) ) )
           workstack.push( workitem( curitem.first, coordparampair( t2, p2 ),
                                     overlaypt ) );
-        if ( addn || ( valid1 && sr.contains( p1 ) ) || h >= hmax )
+        if ( addn || ( valid1 && sr.contains( p1 ) ) )
         {
           curitem = workitem( coordparampair( t2, p2 ), curitem.second ,
                               overlaypt );
@@ -971,13 +880,12 @@ void KigPainter::drawCurve( const CurveImp* curve )
       }
     }
   }
+  // flush the rest of the curve
+  mP.drawPolyline( curpolyline, 0, curpolylinenextfree );
+  curpolylinenextfree = 0;
 
   if ( ! workstack.empty () )
-  {
-    kdDebug() << "Stack not empty in drawLocus!\n" << endl;
-    while ( ! workstack.empty () ) workstack.pop ();
-  }
-  assert ( workstack.empty() );
+    kdDebug() << "Stack not empty in KigPainter::drawCurve!\n" << endl;
   assert ( tNeedOverlay || overlaystack.empty() );
   if ( tNeedOverlay )
   {
@@ -991,8 +899,6 @@ void KigPainter::drawCurve( const CurveImp* curve )
     }
   }
   mNeedOverlay = tNeedOverlay;
-  pen.setCapStyle( Qt::FlatCap );
-  mP.setPen( pen );
 }
 
 void KigPainter::drawTextFrame( const Rect& frame,
@@ -1023,8 +929,8 @@ void KigPainter::drawArc( const Coordinate& center, const double radius,
                           const double dstartangle, const double dangle )
 {
   // convert to 16th of degrees...
-  const int startangle = static_cast<int>( 16*180*dstartangle / M_PI );
-  const int angle = static_cast<int>( 16*180*dangle / M_PI );
+  const int startangle = static_cast<int>( Goniometry::convert( 16 * dstartangle, Goniometry::Rad, Goniometry::Deg ) );
+  const int angle = static_cast<int>( Goniometry::convert( 16 * dangle, Goniometry::Rad, Goniometry::Deg ) );
 
   Rect krect( 0, 0, 2*radius, 2*radius );
   krect.setCenter( center );
@@ -1033,3 +939,4 @@ void KigPainter::drawArc( const Coordinate& center, const double radius,
   mP.drawArc( rect, startangle, angle );
   setWholeWinOverlay();
 }
+
