@@ -60,6 +60,8 @@
 #include <klineeditdlg.h>
 #endif
 
+#include <config.h>
+
 using namespace std;
 
 class NormalModePopupObjects;
@@ -158,11 +160,28 @@ public:
                       KigPart& doc, KigWidget& w, NormalMode& m );
 };
 
+#ifdef KIG_ENABLE_PYTHON_SCRIPTING
+#include "../scripting/script-common.h"
+#include "../scripting/script_mode.h"
+
+class ScriptActionsProvider
+  : public PopupActionProvider
+{
+  int mns;
+public:
+  void fillUpMenu( NormalModePopupObjects& popup, int menu, int& nextfree );
+  bool executeAction( int menu, int& id, const std::vector<ObjectHolder*>& os,
+                      NormalModePopupObjects& popup,
+                      KigPart& doc, KigWidget& w, NormalMode& m );
+};
+#endif
+
 NormalModePopupObjects::NormalModePopupObjects( KigPart& part,
                                                 KigWidget& view,
                                                 NormalMode& mode,
-                                                const std::vector<ObjectHolder*>& objs )
-  : KPopupMenu( &view ), mplc( QCursor::pos() ), mpart( part ), mview( view ), mobjs( objs ),
+                                                const std::vector<ObjectHolder*>& objs,
+						const QPoint& plc )
+  : KPopupMenu( &view ), mplc( plc ), mpart( part ), mview( view ), mobjs( objs ),
     mmode( mode )
 {
   bool empty = objs.empty();
@@ -204,6 +223,10 @@ NormalModePopupObjects::NormalModePopupObjects( KigPart& part,
     // stuff like "redefine point" for a fixed or constrained point..
     mproviders.push_back( new ObjectTypeActionsProvider() );
   }
+#ifdef KIG_ENABLE_PYTHON_SCRIPTING
+  // script action..
+  mproviders.push_back( new ScriptActionsProvider() );
+#endif
 
   for ( int i = 0; i < (int) NumberOfMenus; ++i )
     mmenus[i] = new QPopupMenu( this );
@@ -340,7 +363,27 @@ void BuiltinObjectActionsProvider::fillUpMenu( NormalModePopupObjects& popup, in
   if ( menu == NormalModePopupObjects::ToplevelMenu )
   {
     KIconLoader* l = popup.part().instance()->iconLoader();
-    popup.addAction( menu, i18n( "&Hide" ), nextfree++ );
+    std::vector<ObjectHolder*> os = popup.objects();
+
+    /*
+     * mp: we want the "show" action to be visible only
+     * if we selected only one object (to be conservative)
+     * and if that object is currently hidden.
+     * conversely for one hidden object we don't want
+     * the "hide" action to be inserted.
+     * in any case we have a fixed 'id' associated
+     * with the two actions.
+     */
+
+    if ( os.size() > 1 || os.front()->shown() )
+    {
+      popup.addAction( menu, i18n( "&Hide" ), nextfree );
+    }
+    if ( os.size() == 1 && !os.front()->shown() )
+    {
+      popup.addAction( menu, i18n( "&Show" ), nextfree+1 );
+    }
+    nextfree += 2;
     QPixmap p = l->loadIcon( "move", KIcon::User );
     popup.addAction( menu, p, i18n( "&Move" ), nextfree++ );
     p = l->loadIcon( "editdelete", KIcon::Toolbar );
@@ -457,7 +500,9 @@ static void addNameLabel( ObjectCalcer* object, ObjectCalcer* namecalcer, const
   args.push_back( namecalcer );
   const bool namelabelneedsframe = false;
   ObjectCalcer* attachto = 0;
-  if ( object->imp()->inherits( PointImp::stype() ) || object->imp()->inherits( CurveImp::stype() ) )
+  if ( object->imp()->inherits( PointImp::stype() ) || 
+       object->imp()->attachPoint().valid() || 
+       object->imp()->inherits( CurveImp::stype() ) )
     attachto = object;
   ObjectHolder* label = ObjectFactory::instance()->attachedLabel(
       QString::fromLatin1( "%1" ), attachto, loc, namelabelneedsframe, args, doc.document() );
@@ -494,7 +539,7 @@ bool NameObjectActionsProvider::executeAction(
       if ( !namecalcer )
       {
         justadded = true;
-        ObjectConstCalcer* c = new ObjectConstCalcer( new StringImp( i18n( "unnamed object" ) ) );
+        ObjectConstCalcer* c = new ObjectConstCalcer( new StringImp( i18n( "<unnamed object>" ) ) );
         os[0]->setNameCalcer( c );
         namecalcer = c;
       }
@@ -509,7 +554,8 @@ bool NameObjectActionsProvider::executeAction(
       // if we just added the name, we add a label to show it to the user.
       if ( justadded )
         addNameLabel( os[0]->calcer(), namecalcer,
-                      w.fromScreen( w.mapFromGlobal( popup.mapToGlobal( QPoint( 5, 0 ) ) ) ),
+//                    w.fromScreen( w.mapFromGlobal( popup.mapToGlobal( QPoint( 5, 0 ) ) ) ),
+                      w.fromScreen( popup.plc() ),
                       doc );
     }
     return true;
@@ -525,12 +571,13 @@ bool NameObjectActionsProvider::executeAction(
     ObjectCalcer* namecalcer = os[0]->nameCalcer();
     if ( !namecalcer )
     {
-      ObjectConstCalcer* c = new ObjectConstCalcer( new StringImp( i18n( "unnamed object" ) ) );
+      ObjectConstCalcer* c = new ObjectConstCalcer( new StringImp( i18n( "<unnamed object>" ) ) );
       os[0]->setNameCalcer( c );
       namecalcer = c;
     }
     addNameLabel( os[0]->calcer(), namecalcer,
-                  w.fromScreen( w.mapFromGlobal( popup.mapToGlobal( QPoint( 5, 0 ) ) ) ), doc );
+//                  w.fromScreen( w.mapFromGlobal( popup.mapToGlobal( QPoint( 5, 0 ) ) ) ), doc );
+                  w.fromScreen( popup.plc() ), doc );
     return true;
   }
   else
@@ -545,9 +592,9 @@ bool BuiltinObjectActionsProvider::executeAction(
 {
   if ( menu == NormalModePopupObjects::ToplevelMenu )
   {
-    if ( id > 2 )
+    if ( id > 3 )
     {
-      id -= 3;
+      id -= 4;
       return false;
     };
     switch( id )
@@ -557,6 +604,10 @@ bool BuiltinObjectActionsProvider::executeAction(
       doc.hideObjects( os );
       break;
     case 1:
+      // show the objects..
+      doc.showObjects( os );
+      break;
+    case 2:
     {
       // move
       QCursor::setPos( popup.mapToGlobal( QPoint( 0, 0 ) ) );
@@ -568,7 +619,7 @@ bool BuiltinObjectActionsProvider::executeAction(
       // unselected... ( or maybe we do ? )
       return true;
     }
-    case 2:
+    case 3:
       // delete
       doc.delObjects( os );
       break;
@@ -849,7 +900,14 @@ bool PropertiesActionsProvider::executeAction(
     std::vector<ObjectCalcer*> args;
     args.push_back( new ObjectPropertyCalcer( parent->calcer(), propid ) );
     args.back()->calc( doc.document() );
-    Coordinate c = w.fromScreen( w.mapFromGlobal( popup.mapToGlobal( QPoint( 5, 0 ) ) ) );
+// TODO: recover the cursor position somehow... the following does not work
+// in general...
+//    Coordinate c = w.fromScreen( w.mapFromGlobal( popup.mapToGlobal( QPoint( 5, 0 ) ) ) );
+// mp: it seems that we have no idea where to position the label, 
+// btw what's the meaning of (5,0)?    let the
+// attach method decide what to do... (passing an invalidCoord)
+//  ///////    Coordinate c = Coordinate::invalidCoord();
+    Coordinate c = w.fromScreen( popup.plc() );
     ObjectHolder* label = ObjectFactory::instance()->attachedLabel(
       QString::fromLatin1( "%1" ), parent->calcer(), c,
       false, args, doc.document() );
@@ -976,3 +1034,44 @@ void NormalModePopupObjects::setChecked( int menu, int n, bool checked )
 {
   mmenus[menu]->setItemChecked( n, checked );
 }
+
+#ifdef KIG_ENABLE_PYTHON_SCRIPTING
+void ScriptActionsProvider::fillUpMenu( NormalModePopupObjects& popup, int menu, int& nextfree )
+{
+  if ( menu == NormalModePopupObjects::StartMenu )
+  {
+    KIconLoader* l = popup.part().instance()->iconLoader();
+    QPixmap p = l->loadIcon( ScriptType::icon( ScriptType::Python ), KIcon::User );
+    popup.addAction( menu, p, i18n( "Python Script" ), nextfree++ );
+    mns++;
+  }
+}
+
+bool ScriptActionsProvider::executeAction(
+  int menu, int& id, const std::vector<ObjectHolder*>& os,
+  NormalModePopupObjects&, KigPart& doc, KigWidget& w, NormalMode& mode )
+{
+  if ( menu == NormalModePopupObjects::StartMenu )
+  {
+    if ( id == 0 )
+    {
+      ScriptMode m( doc );
+      m.setScriptType( ScriptType::Python );
+      if ( os.size() > 0 )
+      {
+        mode.clearSelection();
+        m.addArgs( os, w );
+        m.goToCodePage();
+      }
+      doc.runMode( &m );
+      return true;
+    }
+    else
+    {
+      id -= mns;
+    }
+  }
+
+  return false;
+}
+#endif
