@@ -1,4 +1,3 @@
-// base_type.h
 // Copyright (C)  2003  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -33,7 +32,8 @@ protected:
   ~ObjectABType();
 public:
   ObjectImp* calc( const Args& args, const KigDocument& ) const;
-  bool canMove() const;
+  bool canMove( const ObjectTypeCalcer& o ) const;
+  bool isFreelyTranslatable( const ObjectTypeCalcer& o ) const;
   std::vector<ObjectCalcer*> movableParents( const ObjectTypeCalcer& ourobj ) const;
   void move( ObjectTypeCalcer& o, const Coordinate& to,
              const KigDocument& d ) const;
