@@ -1,4 +1,3 @@
-// bogus_imp.cc
 // Copyright (C)  2002  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -24,6 +23,11 @@
 
 #include "../misc/rect.h"
 
+Coordinate BogusImp::attachPoint( ) const
+{
+  return Coordinate::invalidCoord();
+}
+
 void BogusImp::draw( KigPainter& ) const
 {
 }
