@@ -1,4 +1,3 @@
-// object_imp.cc
 // Copyright (C)  2002  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -152,6 +151,10 @@ void ObjectImpVisitor::visit( const ArcImp* )
 {
 }
 
+void ObjectImpVisitor::visit( const PolygonImp* )
+{
+}
+
 ObjectImpVisitor::~ObjectImpVisitor()
 {
 
