@@ -1,4 +1,3 @@
-// object_imp_factory.h
 // Copyright (C)  2002  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -29,7 +28,7 @@ public:
   static const ObjectImpFactory* instance();
   // loads data from parent, and returns a new ObjectImp from the type
   // string type.
-  ObjectImp* deserialize( const QString& type, const QDomElement& parent ) const;
+  ObjectImp* deserialize( const QString& type, const QDomElement& parent, QString& error ) const;
   // adds data to parent, and returns a type string..
   QString serialize( const ObjectImp& d, QDomElement& parent, QDomDocument& doc ) const;
 };
