@@ -1,4 +1,3 @@
-// vector_type.h
 // Copyright (C)  2004  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -43,15 +42,4 @@ public:
   const ObjectImpType* resultId() const;
 };
 
-class VectorDifferenceType
-  : public ArgsParserObjectType
-{
-  VectorDifferenceType();
-  ~VectorDifferenceType();
-public:
-  static const VectorDifferenceType* instance();
-  ObjectImp* calc( const Args& args, const KigDocument& ) const;
-  const ObjectImpType* resultId() const;
-};
-
 #endif
