@@ -1,4 +1,3 @@
-// script_mode.h
 // Copyright (C)  2003  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -19,6 +18,8 @@
 #ifndef KIG_SCRIPTING_SCRIPT_MODE_H
 #define KIG_SCRIPTING_SCRIPT_MODE_H
 
+#include "script-common.h"
+
 #include "../modes/base_mode.h"
 
 #include <set>
@@ -34,10 +35,13 @@ class ScriptMode
   std::set<ObjectHolder*> margs;
   NewScriptWizard* mwizard;
 
+  KigPart& mpart;
+
   enum WAWD { SelectingArgs, EnteringCode };
   WAWD mwawd;
 
-  QString mtype;
+  ScriptType::Type mtype;
+
 public:
   ScriptMode( KigPart& doc );
   ~ScriptMode();
@@ -63,7 +67,12 @@ public:
 
   void enableActions();
 
-  void setScriptType( QString& type );
+  void setScriptType( ScriptType::Type type );
+
+  void addArgs( const std::vector<ObjectHolder*>& obj, KigWidget& w );
+
+  void goToCodePage();
+
 };
 
 #endif
