@@ -1,16 +1,30 @@
-#include <kglobal.h>
+/**
+ This file is part of Kiten, a KDE Japanese Reference Tool...
+ Copyright (C) 2001  Jason Katz-Brown <jason@katzbrown.com>
+
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ USA
+**/
+
 #include <kdebug.h>
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <qstring.h>
 #include <qfile.h>
-#include <qtextstream.h>
-#include <qmap.h>
 #include <qregexp.h>
-#include <qstringlist.h>
 #include <qtextcodec.h>
-#include <qvaluelist.h>
 #include "deinf.h"
 
 Deinf::Index::Index()
@@ -24,7 +38,7 @@ void Deinf::Index::load()
 		return;
 
 	KStandardDirs *dirs = KGlobal::dirs();
-	QString vconj = dirs->findResource("appdata", "vconj");
+	QString vconj = dirs->findResource("data", "kiten/vconj");
 	if (vconj.isNull())
 	{
 		KMessageBox::error(0, i18n("Verb deinflection information not found, so verb deinflection cannot be used."));
@@ -82,7 +96,7 @@ QStringList possibleConjugations(const QString &text)
 }
 }
 
-QStringList Deinf::Index::deinflect(QString text, QStringList &name)
+QStringList Deinf::Index::deinflect(const QString &text, QStringList &name)
 {
 	load();
 	QStringList endings = possibleConjugations(text);
