@@ -1,16 +1,34 @@
+/**
+ This file is part of Kiten, a KDE Japanese Reference Tool...
+ Copyright (C) 2001  Jason Katz-Brown <jason@katzbrown.com>
+	       (C) 2005 Paul Temple <paul.temple@gmx.net>
+
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ USA
+**/
+
 #ifndef KITEN_H
 #define KITEN_H
 
-#include <kmainwindow.h>
-#include <qptrlist.h>
-#include <qregexp.h>
-#include <qstring.h>
-#include <qstringlist.h>
 
+#include "asyndeta.h"
 #include "dict.h"
 #include "rad.h"
 #include "deinf.h"
 
+class Config;
 class ConfigureDialog;
 class EditAction;
 class KGlobalAccel;
@@ -20,7 +38,7 @@ class KListAction;
 class Learn;
 class ResultView;
 
-class TopLevel : public KMainWindow
+class KDE_EXPORT TopLevel : public KMainWindow
 {
 	Q_OBJECT
 
@@ -34,7 +52,7 @@ signals:
 	void quizConfChanged();
 
 protected:
-	void closeEvent(QCloseEvent *);
+	virtual bool queryClose();
 
 private slots:
 	void search(bool inResults = false);
@@ -51,12 +69,12 @@ private slots:
 	void forward();
 	void goInHistory(int);
 	void historySpotChanged();
-	void slotKeyBindings();
 	void slotConfigure();
 	void slotLearnConfigure();
 	void slotConfigureHide();
 	void slotConfigureDestroy();
-	void slotUpdateConfiguration();
+	void slotConfigurationChanged(); // calls the below too
+	void updateConfiguration();
 	void kanjiDictChange();
 	void toggleCom();
 	void addToList();
@@ -76,7 +94,7 @@ private slots:
 private:
 	KStatusBar *StatusBar;
 
-	Dict::Index _Index;
+	Asyndeta _Asyndeta;
 	Rad _Rad;
 	Deinf::Index _DeinfIndex;
 	ResultView *_ResultView;
@@ -90,23 +108,19 @@ private:
 	KAction *backAction;
 	KAction *forwardAction;
 
-	bool wholeWord;
-	bool caseSensitive;
-
 	KGlobalAccel *Accel;
 
-	void doSearch(QString text, QRegExp regexp);
-	void doSearchInResults(QString text, QRegExp regexp);
+	void doSearch(const QString &text, QRegExp regexp);
+	void doSearchInResults(const QString &text, QRegExp regexp);
 	void handleSearchResult(Dict::SearchResult);
 	QString filteredClipboardText();
 	QString clipBoardText();
 
 	ConfigureDialog *optionDialog;
-
+	Config* config;
 	void setResults(unsigned int, unsigned int);
 
 	QPtrList<Learn> learnList;
-	bool autoCreateLearn;
 
 	QRegExp searchItems();
 	QRegExp readingSearchItems(bool);
@@ -116,8 +130,6 @@ private:
 
 	bool readingSearch; // if this is true and no results, try with kanjiSearchItems
 	bool beginningReadingSearch;
-	bool edictUseGlobal;
-	bool kanjidicUseGlobal;
 
 	Dict::Entry toAddKanji;
 
