@@ -1,7 +1,26 @@
+/**
+ This file is part of Kiten, a KDE Japanese Reference Tool...
+ Copyright (C) 2001  Jason Katz-Brown <jason@katzbrown.com>
+	       (C) 2005 Paul Temple <paul.temple@gmx.net>
+
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ USA
+**/
+
 #include <kaction.h>
 #include <kapplication.h>
-#include <kconfig.h>
-#include <kdialog.h>
 #include <kdebug.h>
 #include <kfiledialog.h>
 #include <klistview.h>
@@ -9,26 +28,36 @@
 #include <kmessagebox.h>
 #include <kpushbutton.h>
 #include <kstatusbar.h>
-#include <kstdaction.h>
 #include <kstringhandler.h>
-#include <ktoolbar.h>
 #include <qbuttongroup.h>
 #include <qheader.h>
 #include <qlayout.h>
-#include <qregexp.h>
-#include <qsplitter.h>
 #include <qtabwidget.h>
 #include <qtimer.h>
 #include <qtextcodec.h>
 
 #include <stdlib.h> // RAND_MAX
 #include <cassert>
+#include <set>
 
+#include "kitenconfig.h"
 #include "dict.h"
 #include "kloader.h"
 #include "ksaver.h"
 #include "learn.h"
 
+LearnItem::LearnItem(QListView *parent, QString label1, QString label2, QString label3, QString label4, QString label5, QString label6, QString label7, QString label8)
+	: QListViewItem(parent, label1, label2, label3, label4, label5, label6, label7, label8)
+{
+}
+
+int LearnItem::compare(QListViewItem *item, int col, bool ascending) const
+{
+	// "Returns < 0 if this item is less than i [item] , 0 if they
+	// are equal and > 0 if this item is greater than i [item]."
+	return key(col, ascending).toInt() - item->key(col, ascending).toInt();
+}
+
 const int Learn::numberOfAnswers = 5;
 
 Learn::Learn(Dict::Index *parentDict, QWidget *parent, const char *name)
@@ -72,8 +101,6 @@ Learn::Learn(Dict::Index *parentDict, QWidget *parent, const char *name)
 	List->setSorting(4);
 	List->setSelectionModeExt(KListView::Extended);
 
-	List->header()->setClickEnabled(false);
-
 	connect(List, SIGNAL(executed(QListViewItem *)), SLOT(showKanji(QListViewItem *)));
 	connect(List, SIGNAL(selectionChanged()), this, SLOT(itemSelectionChanged()));
 
@@ -130,7 +157,7 @@ Learn::Learn(Dict::Index *parentDict, QWidget *parent, const char *name)
 	//closeAction->plug(toolBar());
 
 	resize(600, 400);
-	applyMainWindowSettings(kapp->config(), "LearnWindow");
+	applyMainWindowSettings(Config::self()->config(), "LearnWindow");
 
 	statusBar()->message(i18n("Put on your thinking cap!"));
 
@@ -142,10 +169,9 @@ Learn::Learn(Dict::Index *parentDict, QWidget *parent, const char *name)
 
 void Learn::finishCtor()
 {
-	KConfig &config = *kapp->config();
-	config.setGroup("Learn");
-
-	setCurrentGrade(config.readNumEntry("grade", 1));
+	Config* config = Config::self();
+	
+	setCurrentGrade(config->grade());
 
 	/*
 	 * this must be done now, because
@@ -155,8 +181,7 @@ void Learn::finishCtor()
 	updateGrade();
 	updateQuizConfiguration(); // first
 
-	config.setGroup("Learn");
-	QString entry = config.readPathEntry("lastFile");
+	QString entry = config->lastFile();
 	//kdDebug() << "lastFile: " << entry << endl;
 	if (!entry.isEmpty())
 	{
@@ -209,16 +234,15 @@ bool Learn::closeWindow()
 	}
 }
 
-void Learn::closeEvent(QCloseEvent *e)
+bool Learn::queryClose()
 {
 	if (!warnClose())
-		return;
+		return false; // cancel
 
 	saveScores(); // also sync()s;
-	//kapp->config()->sync();
 
-	saveMainWindowSettings(KGlobal::config(), "LearnWindow");
-	e->accept();
+	saveMainWindowSettings(Config::self()->config(), "LearnWindow");
+	return true;
 }
 
 void Learn::random()
@@ -244,7 +268,7 @@ void Learn::prev()
 		if (!prevItem)
 			return;
 		curItem = prevItem;
-
+	
 		statusBar()->clear();
 		qupdate();
 		nogood = true;
@@ -271,12 +295,12 @@ void Learn::update()
 	View->addKanjiResult(curKanji);
 
 	// now show some compounds in which this kanji appears
-
+	
 	QString kanji = curKanji.kanji();
 
 	Dict::SearchResult compounds = index->search(QRegExp(kanji), kanji, true);
 	View->addHeader(i18n("%1 in compounds").arg(kanji));
-
+	
 	for (QValueListIterator<Dict::Entry> it = compounds.list.begin(); it != compounds.list.end(); ++it)
 	{
 		kapp->processEvents();
@@ -302,9 +326,7 @@ void Learn::updateGrade()
 	current = list.begin();
 	update();
 
-	KConfig &config = *KGlobal::config();
-	config.setGroup("Learn");
-	config.writeEntry("grade", grade);
+	Config::self()->setGrade(grade);
 }
 
 void Learn::read(const KURL &url)
@@ -329,7 +351,7 @@ void Learn::read(const KURL &url)
 		// ignore whitespace
 		if (!kanji.isSpace())
 		{
-			QRegExp regexp = QString("^%1\\W").arg(kanji);
+			QRegExp regexp ( QString("^%1\\W").arg(kanji) );
 			Dict::SearchResult res = index->searchKanji(regexp, kanji, false);
 			Dict::Entry first = Dict::firstEntry(res);
 			if (first.extendedKanjiInfo())
@@ -356,10 +378,8 @@ void Learn::open()
 	read(filename);
 
 	//kdDebug() << "saving lastFile\n";
-	KConfig &config = *kapp->config();
-	config.setGroup("Learn");
-	config.writePathEntry("lastFile", filename.url());
-	config.sync();
+	Config* config = Config::self();
+	config->setLastFile(filename.url());
 
 	// redo quiz, because we deleted the current quiz item
 	curItem = List->firstChild();
@@ -405,11 +425,8 @@ void Learn::save()
 
 	write(filename);
 
-	KConfig &config = *kapp->config();
-	//kdDebug() << "saving lastFile\n";
-	config.setGroup("Learn");
-	config.writePathEntry("lastFile", filename.url());
-	config.sync();
+	Config* config = Config::self();
+	config->setLastFile(filename.url());
 }
 
 void Learn::write(const KURL &url)
@@ -444,17 +461,18 @@ void Learn::write(const KURL &url)
 
 void Learn::saveScores()
 {
-	KConfig &config = *kapp->config();
+	KConfig &config = *Config::self()->config();
 	config.setGroup("Learn Scores");
 	for (QListViewItemIterator it(List); it.current(); ++it)
 		config.writeEntry(it.current()->text(0), it.current()->text(4).toInt());
 	config.sync();
+	Config::self()->writeConfig();
 }
 
 void Learn::add(Dict::Entry toAdd, bool noEmit)
 {
 	// Remove peripheral readings: This is a study mode, not a reference mode
-	QRegExp inNames = QString::fromLatin1(",\\s*[A-Za-z ]+:.*");
+	QRegExp inNames (",\\s*[A-Za-z ]+:.*");
 	QString readings = Dict::prettyKanjiReading(toAdd.readings()).replace(inNames, "");
 	QString meanings = shortenString(Dict::prettyMeaning(toAdd.meanings()).replace(inNames, ""));
 	QString kanji = toAdd.kanji();
@@ -475,13 +493,13 @@ void Learn::add(Dict::Entry toAdd, bool noEmit)
 
 	statusBar()->message(i18n("%1 added to your list").arg(kanji));
 
-	KConfig &config = *kapp->config();
+	KConfig &config = *Config::self()->config();
 	int score = 0;
 	config.setGroup("Learn Scores");
 	score = config.readNumEntry(kanji, score);
 
 	unsigned int grade = toAdd.grade();
-	addItem(new QListViewItem(List, kanji, meanings, readings, QString::number(grade), QString::number(score)), noEmit);
+	addItem(new LearnItem(List, kanji, meanings, readings, QString::number(grade), QString::number(score)), noEmit);
 
 	numChanged();
 }
@@ -569,24 +587,19 @@ void Learn::del()
 			delete *i;
 		}
 
-		if (List->childCount() < 1)
+		curItem = List->firstChild();
+		prevItem = curItem;
+		backAct->setEnabled(false);
+
+		if (makenewq)
 		{
-			// this isn't a good state, quizzing is unstable
-		}
-		else
-		{
-			if (makenewq)
-			{
-				curItem = List->firstChild();
-				backAct->setEnabled(false);
-				prevItem = curItem;
-				qnew();
-			}
+			qnew();
 		}
 
 		setDirty();
 	}
 
+	itemSelectionChanged();
 	numChanged();
 }
 
@@ -618,10 +631,10 @@ void Learn::answerClicked(int i)
 {
 	if (!curItem)
 		return;
-
+		
 	int newscore = 0;
-	KConfig &config = *kapp->config();
-	config.setGroup("Learn");
+//	KConfig &config = *Config::self()->config();
+//	config.setGroup("Learn");
 	bool donew = false;
 
 	if (seikai == i)
@@ -652,9 +665,11 @@ void Learn::answerClicked(int i)
 
 	//config.writeEntry(curItem->text(0) + "_4", newscore);
 
-	QListViewItem *newItem = new QListViewItem(List, curItem->text(0), curItem->text(1), curItem->text(2), curItem->text(3), QString::number(newscore));
+	QListViewItem *newItem = new LearnItem(List, curItem->text(0), curItem->text(1), curItem->text(2), curItem->text(3), QString::number(newscore));
 
 	// readd, so it sorts
+	// 20 November 2004: why?? why not List->sort() ??
+	// haha I used to be naive
 	delete curItem;
 	curItem = newItem;
 
@@ -683,13 +698,13 @@ QString Learn::randomMeaning(QStringList &oldMeanings)
 			switch (guessOn)
 			{
 				case 1:
-				meaning = shortenString(Dict::prettyMeaning((*list.at(rand)).meanings()));
+				meaning = shortenString(Dict::prettyMeaning((*list.at(static_cast<unsigned int>(rand))).meanings()));
 				break;
 				case 2:
-				meaning = Dict::prettyKanjiReading((*list.at(rand)).readings());
+				meaning = Dict::prettyKanjiReading((*list.at(static_cast<unsigned int>(rand))).readings());
 				break;
 				case 0:
-				meaning = (*list.at(rand)).kanji();
+				meaning = (*list.at(static_cast<unsigned int>(rand))).kanji();
 			}
 		}
 		else
@@ -701,7 +716,7 @@ QString Learn::randomMeaning(QStringList &oldMeanings)
 			rand = List->childCount() / rand2;
 
 			int max = (int) rand;
-
+		
 			QListViewItemIterator it(List);
 			it += max;
 
@@ -745,6 +760,14 @@ void Learn::qupdate()
 	answers->find(seikai)->setText(curItem->text(guessOn));
 }
 
+struct Learn::scoreCompare 
+{
+	bool operator()(const QListViewItem* v1, const QListViewItem* v2)
+	{
+		return v1->text(4).toInt() < v2->text(4).toInt();
+	}
+};
+
 void Learn::qnew() // new quiz kanji
 {
 	//kdDebug() << "qnew\n";
@@ -760,6 +783,11 @@ void Learn::qnew() // new quiz kanji
 	if (count < 2)
 		return;
 
+	// the following lines calculate which kanji will be used next:
+	// use f(2) every third time, f(1) otherwise
+	// where f(1) = numberOfItems * rand[0..1]
+	// and f(2) = numberOfItems * rand[0..1] * rand[0..1]
+	// rand[0..1] = kapp->random() / RAND_MAX
 	float max = static_cast<float>(count) / (static_cast<float>(RAND_MAX) / kapp->random());
 	if (kapp->random() < (static_cast<float>(RAND_MAX) / 3.25))
 		max /= (static_cast<float>(RAND_MAX) / (kapp->random() + 1));
@@ -769,29 +797,36 @@ void Learn::qnew() // new quiz kanji
 	if (max > count)
 		max = count;
 
-	QListViewItemIterator it(List);
-	QListViewItemIterator tmp(List);
+	std::multiset<const QListViewItem*, scoreCompare> scores;
+	QListViewItemIterator sIt(List);
+
+	for (; sIt.current(); ++sIt)
+		scores.insert(sIt.current());
+
+	std::multiset<const QListViewItem*>::iterator it = scores.begin();
+	std::multiset<const QListViewItem*>::iterator tmp = scores.begin();
+
 	int i;
 	for (i = 2; i <= max; ++it)
 		{i++; ++tmp;}
 
-	if (curItem->text(0) == it.current()->text(0)) // same, don't use
+	if (curItem->text(0) == (*it)->text(0)) // same, don't use
 	{
 		++it;
-		if (!it.current())
+		if (it == scores.end())
 		{
 			tmp--;
 			it = tmp;
 		}
 	}
 
-	if (!it.current())
+	if (it == scores.end())
 	{
 		return;
 	}
 
 	prevItem = curItem;
-	curItem = it.current();
+	curItem = const_cast<QListViewItem*>(*it);
 
 	qKanji->setFocus();
 	qupdate();
@@ -804,7 +839,7 @@ void Learn::cheat()
 	nogood = true;
 }
 
-QString Learn::shortenString(QString thestring)
+QString Learn::shortenString(const QString &thestring)
 {
 	return KStringHandler::rsqueeze(thestring, 60).stripWhiteSpace();
 }
@@ -875,11 +910,10 @@ void Learn::setCurrentGrade(int grade)
 
 void Learn::updateQuizConfiguration()
 {
-	KConfig &config = *kapp->config();
-	config.setGroup("Learn");
+	Config* config = Config::self();
 
-	quizOn = config.readNumEntry("Quiz On", 0);
-	guessOn = config.readNumEntry("Guess On", 1);
+	quizOn = config->quizOn();
+	guessOn = config->guessOn();
 
 	answers->setTitle(List->columnText(guessOn));
 
