@@ -18,28 +18,31 @@
  USA
 **/
 
-#ifndef WIDGETS_H
-#define WIDGETS_H
+#ifndef KITEN_WIDGETS_H
+#define KITEN_WIDGETS_H
 
+#include <qguardedptr.h>
+
+#include <kaction.h>
 #include <klineedit.h>
 #include <kmainwindow.h>
 #include <ktextbrowser.h>
 
-class KAction;
 class KListView;
 class KStatusBar;
 
+#include "dict.h"
 #include "rad.h"
 
-class ResultView : public KTextBrowser
+class KDE_EXPORT ResultView : public KTextBrowser
 {
 	Q_OBJECT
 	
 	public:
-	ResultView(bool, QWidget *parent = 0, const char *name = 0);
+	ResultView(bool showLinks, QWidget *parent = 0, const char *name = 0);
 
-	void addResult(Dict::Entry, bool = false);
-	void addKanjiResult(Dict::Entry, bool = false, Radical = Radical());
+	void addResult(Dict::Entry result, bool common = false);
+	void addKanjiResult(Dict::Entry, bool common = false, Radical = Radical());
 
 	void addHeader(const QString &, unsigned int degree = 3);
 
@@ -60,7 +63,7 @@ class ResultView : public KTextBrowser
 	bool basicMode;
 };
 
-class eEdit : public KMainWindow
+class KDE_EXPORT eEdit : public KMainWindow
 {
 	Q_OBJECT
 	
@@ -85,12 +88,12 @@ class eEdit : public KMainWindow
 	bool isMod;
 };
 
-class EditAction : public KAction
+class KDE_EXPORT EditAction : public KAction
 {
 	Q_OBJECT
 	public:
 	EditAction( const QString& text, int accel, const QObject *receiver, const char *member, QObject* parent, const char* name );
-	~EditAction();
+	virtual ~EditAction();
 
 	virtual int plug( QWidget *w, int index = -1 );
 
@@ -102,7 +105,7 @@ class EditAction : public KAction
 	QGuardedPtr<KLineEdit> editor();
 
 	public slots:
-	void insert(QString);
+	void insert(const QString &);
 
 	// also sets focus to the lineedit widget
 	void clear();
