@@ -148,8 +148,13 @@ void KLettres::registerLanguage(const QString &language, const QString &menuItem
 	kdDebug() << "m_languages :" << m_languages << endl;
 	//this is for translation of the languages
 	KConfig entry(locate("locale", "all_languages"));
-	entry.setGroup(language);
-	m_languageNames.append(entry.readEntry("Name"));
+	if (language == "hi-ro")
+	   m_languageNames.append(i18n("Romanized Hindi"));
+	else
+	{
+	   entry.setGroup(language);
+	   m_languageNames.append(entry.readEntry("Name"));
+	}
 	Prefs::setLanguages(m_languages);
 }
 
@@ -330,7 +335,7 @@ void KLettres::updateLevMenu(int id)
 void KLettres::loadLangToolBar()
 {
 	secondToolbar->clear();
-	if (m_languages[selectedLanguage]== "cs" || m_languages[selectedLanguage]== "da" || m_languages[selectedLanguage]== "sk")//Dutch, French and Italian have no special characters
+	if (m_languages[selectedLanguage]== "cs" || m_languages[selectedLanguage]== "da" || m_languages[selectedLanguage]== "sk" || m_languages[selectedLanguage]== "es")//Dutch, English, French and Italian have no special characters
 	{
 		allData.clear();
 		QString myString=QString("klettres/%1.txt").arg(m_languages[selectedLanguage]);
@@ -354,6 +359,7 @@ void KLettres::loadLangToolBar()
 		allData = QStringList::split("\n", readFileStr.read(), true);
 		openFileStream.close();
 		for (int i=0; i<(int) allData.count(); i++) {
+                     if (!allData[i].isEmpty())
 				secondToolbar->insertButton (charIcon(allData[i].at(0)), i, SIGNAL( clicked() ), this, SLOT( slotPasteChar()), true,  i18n("Inserts the character %1").arg(allData[i]), i+1 );
 		}
 	}
