@@ -37,7 +37,7 @@ class PointValidator : public QValidator
     PointValidator(Size size, QObject* parent, const char* name = 0);
     virtual ~PointValidator( );
 
-    virtual QValidator::State validate(QString& input, int& pos);
+    virtual QValidator::State validate(const QString& input, int& pos);
 
   private:
     Size s;
