@@ -42,7 +42,7 @@ config = kapp->config();
 	setName( "HighScores" );
     resize( 349, 331 ); 
     setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)5, sizePolicy().hasHeightForWidth() ) );
-    setCaption( i18n( "The Highest Scores" ) );
+    setCaption( i18n( "KMessedWords Highscore Table" ) );
     setAutoMask( FALSE );
     HighScoresLayout = new QGridLayout( this ); 
     HighScoresLayout->setSpacing( 6 );
@@ -74,13 +74,13 @@ config = kapp->config();
     scoringEasy->addColumn( i18n( "Name" ) );
     scoringEasy->header()->setClickEnabled( FALSE, scoringEasy->header()->count() - 1 );
     scoringEasy->header()->setResizeEnabled( FALSE, scoringEasy->header()->count() - 1 );
-    scoringEasy->addColumn( i18n( "Solved" ) );
+    scoringEasy->addColumn( i18n( "Words Solved" ) );
     scoringEasy->header()->setClickEnabled( FALSE, scoringEasy->header()->count() - 1 );
     scoringEasy->header()->setResizeEnabled( FALSE, scoringEasy->header()->count() - 1 );
-    scoringEasy->addColumn( i18n( "Total Messes" ) );
+    scoringEasy->addColumn( i18n( "Total Games" ) );
     scoringEasy->header()->setClickEnabled( FALSE, scoringEasy->header()->count() - 1 );
     scoringEasy->header()->setResizeEnabled( FALSE, scoringEasy->header()->count() - 1 );
-    scoringEasy->addColumn( i18n( "Total Guesses" ) );
+    scoringEasy->addColumn( i18n( "Total Attempts" ) );
     scoringEasy->header()->setClickEnabled( FALSE, scoringEasy->header()->count() - 1 );
     scoringEasy->header()->setResizeEnabled( FALSE, scoringEasy->header()->count() - 1 );
 	
@@ -115,13 +115,13 @@ config = kapp->config();
     scoringMedium->addColumn( i18n( "Name" ) );
     scoringMedium->header()->setClickEnabled( FALSE, scoringMedium->header()->count() - 1 );
     scoringMedium->header()->setResizeEnabled( FALSE, scoringMedium->header()->count() - 1 );
-    scoringMedium->addColumn( i18n( "Solved" ) );
+    scoringMedium->addColumn( i18n( "Words Solved" ) );
     scoringMedium->header()->setClickEnabled( FALSE, scoringMedium->header()->count() - 1 );
     scoringMedium->header()->setResizeEnabled( FALSE, scoringMedium->header()->count() - 1 );
-    scoringMedium->addColumn( i18n( "Total Messes" ) );
+    scoringMedium->addColumn( i18n( "Total Games" ) );
     scoringMedium->header()->setClickEnabled( FALSE, scoringMedium->header()->count() - 1 );
     scoringMedium->header()->setResizeEnabled( FALSE, scoringMedium->header()->count() - 1 );
-    scoringMedium->addColumn( i18n( "Total Guesses" ) );
+    scoringMedium->addColumn( i18n( "Total Attempts" ) );
     scoringMedium->header()->setClickEnabled( FALSE, scoringMedium->header()->count() - 1 );
     scoringMedium->header()->setResizeEnabled( FALSE, scoringMedium->header()->count() - 1 );
 
@@ -156,13 +156,13 @@ config = kapp->config();
     scoringHard->addColumn( i18n( "Name" ) );
     scoringHard->header()->setClickEnabled( FALSE, scoringHard->header()->count() - 1 );
     scoringHard->header()->setResizeEnabled( FALSE, scoringHard->header()->count() - 1 );
-    scoringHard->addColumn( i18n( "Solved" ) );
+    scoringHard->addColumn( i18n( "Words Solved" ) );
     scoringHard->header()->setClickEnabled( FALSE, scoringHard->header()->count() - 1 );
     scoringHard->header()->setResizeEnabled( FALSE, scoringHard->header()->count() - 1 );
-    scoringHard->addColumn( i18n( "Total Messes" ) );
+    scoringHard->addColumn( i18n( "Total Games" ) );
     scoringHard->header()->setClickEnabled( FALSE, scoringHard->header()->count() - 1 );
     scoringHard->header()->setResizeEnabled( FALSE, scoringHard->header()->count() - 1 );
-    scoringHard->addColumn( i18n( "Total Guesses" ) );
+    scoringHard->addColumn( i18n( "Total Attempts" ) );
     scoringHard->header()->setClickEnabled( FALSE, scoringHard->header()->count() - 1 );
     scoringHard->header()->setResizeEnabled( FALSE, scoringHard->header()->count() - 1 );
 
