@@ -45,21 +45,34 @@
 
 static void usage(void);
 static void clientMsgCB(int fd, void *arg);
-static int dispatch (XMLEle *root, char msg[]);
-static int crackDN (XMLEle *root, char **dev, char **name, char msg[]);
+static int dispatch (XMLEle *root, char errmsg[]);
+static int crackDN (XMLEle *root, char **dev, char **name, char errmsg[]);
 const  char *pstateStr(IPState s);
 const  char *sstateStr(ISState s);
 const  char *ruleStr(ISRule r);
 const  char *permStr(IPerm p);
 static char *timestamp (void);
 
+static int nroCheck;			/* # of elements in roCheck */
 static int verbose;			/* chatty */
 char *me;				/* a.out name */
 static LilXML *clixml;			/* XML parser context */
 
+/* insure RO properties are never modified. RO Sanity Check */
+typedef struct
+{
+  char propName[MAXINDINAME];
+  IPerm perm;
+} ROSC;
+
+static ROSC *roCheck;
+
 int
 main (int ac, char *av[])
 {
+        setgid( getgid() );
+        setuid( getuid() );
+
 	/* save handy pointer to our base name */
 	for (me = av[0]; av[0][0]; av[0]++)
 	    if (av[0][0] == '/')
@@ -83,6 +96,9 @@ main (int ac, char *av[])
 	/* init */
 	clixml =  newLilXML();
 	addCallback (0, clientMsgCB, NULL);
+	
+	nroCheck = 0;
+	roCheck = NULL;
 
 	/* service client */
 	eventLoop();
@@ -99,6 +115,7 @@ void
 IDDefText (const ITextVectorProperty *tvp, const char *fmt, ...)
 {
 	int i;
+	ROSC *SC;
 
 	printf ("<defTextVector\n");
 	printf ("  device='%s'\n", tvp->device);
@@ -129,6 +146,15 @@ IDDefText (const ITextVectorProperty *tvp, const char *fmt, ...)
 	}
 
 	printf ("</defTextVector>\n");
+	
+	/* Add this property to insure proper sanity check */
+	roCheck = roCheck ? (ROSC *) realloc ( roCheck, sizeof(ROSC) * (nroCheck+1))
+	                  : (ROSC *) malloc  ( sizeof(ROSC));
+	SC      = &roCheck[nroCheck++];
+	
+	strcpy(SC->propName, tvp->name);
+	SC->perm = tvp->p;
+	
 	fflush (stdout);
 }
 
@@ -137,6 +163,7 @@ void
 IDDefNumber (const INumberVectorProperty *n, const char *fmt, ...)
 {
 	int i;
+	ROSC *SC;
 
 	printf ("<defNumberVector\n");
 	printf ("  device='%s'\n", n->device);
@@ -171,14 +198,25 @@ IDDefNumber (const INumberVectorProperty *n, const char *fmt, ...)
 	}
 
 	printf ("</defNumberVector>\n");
+	
+	/* Add this property to insure proper sanity check */
+	roCheck = roCheck ? (ROSC *) realloc ( roCheck, sizeof(ROSC) * (nroCheck+1))
+	                  : (ROSC *) malloc  ( sizeof(ROSC));
+	SC      = &roCheck[nroCheck++];
+	
+	strcpy(SC->propName, n->name);
+	SC->perm = n->p;
+	
 	fflush (stdout);
 }
 
 /* tell client to create a new switch vector property */
 void
 IDDefSwitch (const ISwitchVectorProperty *s, const char *fmt, ...)
+
 {
 	int i;
+	ROSC *SC;
 
 	printf ("<defSwitchVector\n");
 	printf ("  device='%s'\n", s->device);
@@ -210,6 +248,15 @@ IDDefSwitch (const ISwitchVectorProperty *s, const char *fmt, ...)
 	}
 
 	printf ("</defSwitchVector>\n");
+	
+	/* Add this property to insure proper sanity check */
+	roCheck = roCheck ? (ROSC *) realloc ( roCheck, sizeof(ROSC) * (nroCheck+1))
+	                  : (ROSC *) malloc  ( sizeof(ROSC));
+	SC      = &roCheck[nroCheck++];
+	
+	strcpy(SC->propName, s->name);
+	SC->perm = s->p;
+	
 	fflush (stdout);
 }
 
@@ -287,7 +334,6 @@ void
 IDSetNumber (const INumberVectorProperty *nvp, const char *fmt, ...)
 {
 	int i;
-	static int lmin=0, lmax=0;
 
 	printf ("<setNumberVector\n");
 	printf ("  device='%s'\n", nvp->device);
@@ -308,12 +354,6 @@ IDSetNumber (const INumberVectorProperty *nvp, const char *fmt, ...)
 	for (i = 0; i < nvp->nnp; i++) {
 	    INumber *np = &nvp->np[i];
 	    printf ("  <oneNumber name='%s'\n", np->name);
-	    if (lmin != np->min) {
-	    printf ("    min='%g'\n", np->min);
-	    lmin = np->min; }
-	    if (lmax != np->max) {
-	    printf ("    max='%g'\n", np->max);
-	    lmax = np->max; }
 	    printf(">\n");
 	    printf ("      %g\n", np->value);
 	    printf ("  </oneNumber>\n");
@@ -323,6 +363,34 @@ IDSetNumber (const INumberVectorProperty *nvp, const char *fmt, ...)
 	fflush (stdout);
 }
 
+/* tell client to update min/max elements of an existing number vector property */
+void
+IUUpdateMinMax(INumberVectorProperty *nvp)
+{
+  int i;
+
+  printf ("<setNumberVector\n");
+  printf ("  device='%s'\n", nvp->device);
+  printf ("  name='%s'\n", nvp->name);
+  printf ("  state='%s'\n", pstateStr(nvp->s));
+  printf ("  timeout='%g'\n", nvp->timeout);
+  printf ("  timestamp='%s'\n", timestamp());
+  printf (">\n");
+
+  for (i = 0; i < nvp->nnp; i++) {
+    INumber *np = &nvp->np[i];
+    printf ("  <oneNumber name='%s'\n", np->name);
+    printf ("    min='%g'\n", np->min);
+    printf ("    max='%g'\n", np->max);
+    printf(">\n");
+    printf ("      %g\n", np->value);
+    printf ("  </oneNumber>\n");
+  }
+
+  printf ("</setNumberVector>\n");
+  fflush (stdout);
+}
+
 /* tell client to update an existing switch vector property */
 void
 IDSetSwitch (const ISwitchVectorProperty *svp, const char *fmt, ...)
@@ -637,12 +705,12 @@ usage(void)
 static void
 clientMsgCB (int fd, void *arg)
 {
-	char buf[1024], msg[1024], *bp;
+	char buf[1024], errmsg[ERRMSG_SIZE], *bp;
 	int nr;
 	arg=arg;
 
 	/* one read */
-	nr = read (fd, buf, sizeof(buf));
+	nr = read (fd, buf, sizeof(buf)-1);
 	if (nr < 0) {
 	    fprintf (stderr, "%s: %s\n", me, strerror(errno));
 	    exit(1);
@@ -651,29 +719,31 @@ clientMsgCB (int fd, void *arg)
 	    fprintf (stderr, "%s: EOF\n", me);
 	    exit(1);
 	}
+        buf[ sizeof( buf )-1 ] = '\0';
 
 	/* crack and dispatch when complete */
 	for (bp = buf; nr-- > 0; bp++) {
-	    XMLEle *root = readXMLEle (clixml, *bp, msg);
+	    XMLEle *root = readXMLEle (clixml, *bp, errmsg);
 	    if (root) {
-		if (dispatch (root, msg) < 0)
-		    fprintf (stderr, "%s dispatch error: %s\n", me, msg);
+		if (dispatch (root, errmsg) < 0)
+		    fprintf (stderr, "%s dispatch error: %s\n", me, errmsg);
 		delXMLEle (root);
-	    } else if (msg[0])
-		fprintf (stderr, "%s XML error: %s\n", me, msg);
+	    } else if (errmsg[0])
+		fprintf (stderr, "%s XML error: %s\n", me, errmsg);
 	}
 }
 
 /* crack the given INDI XML element and call driver's IS* entry points as they
  *   are recognized.
- * return 0 if ok else -1 with reason in msg[].
+ * return 0 if ok else -1 with reason in errmsg[].
  * N.B. exit if getProperties does not proclaim a compatible version.
  */
 static int
-dispatch (XMLEle *root, char msg[])
+dispatch (XMLEle *root, char errmsg[])
 {
 	XMLEle *ep;
 	int n;
+	int i;
 
 	if (verbose)
 	    prXMLEle (stderr, root, 0);
@@ -687,7 +757,7 @@ dispatch (XMLEle *root, char msg[])
 	    char *dev, *name;
 
 	    /* pull out device and name */
-	    if (crackDN (root, &dev, &name, msg) < 0)
+	    if (crackDN (root, &dev, &name, errmsg) < 0)
 		return (-1);
 
 	    /* pull out each name/value pair */
@@ -712,6 +782,16 @@ printf ("%s\n", valuXMLAtt(na));
 		    }
 		}
 	    }
+	    
+	    /* insure property is not RO */
+	    for (i=0; i < nroCheck; i++)
+	    {
+	      if (!strcmp(roCheck[i].propName, name))
+	      {
+	       if (roCheck[i].perm == IP_RO)
+	         return -1;
+	      }
+	    }
 
 	    /* invoke driver if something to do, but not an error if not */
 	    if (n > 0)
@@ -729,7 +809,7 @@ printf ("%s\n", valuXMLAtt(na));
 	    /*XMLEle *ep;*/
 
 	    /* pull out device and name */
-	    if (crackDN (root, &dev, &name, msg) < 0)
+	    if (crackDN (root, &dev, &name, errmsg) < 0)
 		return (-1);
 
 	    /* pull out each name/state pair */
@@ -760,6 +840,16 @@ printf ("%s\n", valuXMLAtt(na));
 		}
 	    }
 
+	    /* insure property is not RO */
+	    for (i=0; i < nroCheck; i++)
+	    {
+	      if (!strcmp(roCheck[i].propName, name))
+	      {
+	       if (roCheck[i].perm == IP_RO)
+	         return -1;
+	      }
+	    }
+	    
 	    /* invoke driver if something to do, but not an error if not */
 	    if (n > 0)
 		ISNewSwitch (dev, name, states, names, n);
@@ -775,7 +865,7 @@ printf ("%s\n", valuXMLAtt(na));
 	    char *dev, *name;
 
 	    /* pull out device and name */
-	    if (crackDN (root, &dev, &name, msg) < 0)
+	    if (crackDN (root, &dev, &name, errmsg) < 0)
 		return (-1);
 
 	    /* pull out each name/text pair */
@@ -797,6 +887,16 @@ printf ("%s\n", valuXMLAtt(na));
 		    }
 		}
 	    }
+	    
+	    /* insure property is not RO */
+	    for (i=0; i < nroCheck; i++)
+	    {
+	      if (!strcmp(roCheck[i].propName, name))
+	      {
+	       if (roCheck[i].perm == IP_RO)
+	         return -1;
+	      }
+	    }
 
 	    /* invoke driver if something to do, but not an error if not */
 	    if (n > 0)
@@ -828,28 +928,28 @@ printf ("%s\n", valuXMLAtt(na));
 	    return (0);
 	}
 
-	sprintf (msg, "Unknown command: %s", tagXMLEle(root));
+	snprintf (errmsg, ERRMSG_SIZE, "Unknown command: %s", tagXMLEle(root));
 	return(1);
 }
 
 /* pull out device and name attributes from root.
- * return 0 if ok else -1 with reason in msg[].
+ * return 0 if ok else -1 with reason in errmsg[].
  */
 static int
-crackDN (XMLEle *root, char **dev, char **name, char msg[])
+crackDN (XMLEle *root, char **dev, char **name, char errmsg[])
 {
 	XMLAtt *ap;
 
 	ap = findXMLAtt (root, "device");
 	if (!ap) {
-	    sprintf (msg, "%s requires 'device' attribute", tagXMLEle(root));
+	    snprintf (errmsg, ERRMSG_SIZE, "%s requires 'device' attribute", tagXMLEle(root));
 	    return (-1);
 	}
 	*dev = valuXMLAtt(ap);
 
 	ap = findXMLAtt (root, "name");
 	if (!ap) {
-	    sprintf (msg, "%s requires 'name' attribute", tagXMLEle(root));
+	    snprintf (errmsg, ERRMSG_SIZE, "%s requires 'name' attribute", tagXMLEle(root));
 	    return (-1);
 	}
 	*name = valuXMLAtt(ap);
