@@ -18,6 +18,8 @@
 
 #endif
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -31,6 +33,35 @@
 #include "lx200gps.h"
 #include "lx200classic.h"
 
+/*
+** Return the timezone offset in hours (as a double, so fractional
+** hours are possible, for instance in Newfoundland). Also sets
+** daylight on non-Linux systems to record whether DST is in effect.
+*/
+
+
+#if !(TIMEZONE_IS_INT)
+static int daylight = 0;
+#endif
+
+static inline double timezoneOffset()
+{
+/* 
+** In Linux, there's a timezone variable that holds the timezone offset;
+** Otherwise, we need to make a little detour. The directions of the offset
+** are different: CET is -3600 in Linux and +3600 elsewhere.
+*/
+#if TIMEZONE_IS_INT
+  return timezone / (60 * 60);
+#else
+  time_t now;
+  struct tm *tm;
+  now = time(NULL);
+  tm = localtime(&now);
+  daylight = tm->tm_isdst;
+  return -(tm->tm_gmtoff) / (60 * 60);
+#endif
+}
 
 LX200Generic *telescope = NULL;
 int MaxReticleFlashRate = 3;
@@ -68,12 +99,15 @@ static ISwitch SlewModeS[]       = {{"Max", "", ISS_ON, 0, 0}, {"Find", "", ISS_
 static ISwitch OnCoordSetS[]     = {{"SLEW", "Slew", ISS_ON, 0, 0 }, {"TRACK", "Track", ISS_OFF, 0, 0}, {"SYNC", "Sync", ISS_OFF, 0 , 0}};
 static ISwitch TrackModeS[]      = {{ "Default", "", ISS_ON, 0, 0} , { "Lunar", "", ISS_OFF, 0, 0}, {"Manual", "", ISS_OFF, 0, 0}};
 static ISwitch abortSlewS[]      = {{"ABORT", "Abort", ISS_OFF, 0, 0 }};
-static ISwitch ParkS[]		 = { {"Park", "", ISS_OFF, 0, 0} };
+static ISwitch ParkS[]		 = { {"PARK", "Park", ISS_OFF, 0, 0} };
 
 static ISwitch MovementS[]       = {{"N", "North", ISS_OFF, 0, 0}, {"W", "West", ISS_OFF, 0, 0}, {"E", "East", ISS_OFF, 0, 0}, {"S", "South", ISS_OFF, 0, 0}};
 
-static ISwitch	FocusSpeedS[]	 = { {"Halt", "", ISS_ON, 0, 0}, { "Fast", "", ISS_OFF, 0, 0}, {"Slow", "", ISS_OFF, 0, 0}};
-static ISwitch  FocusMotionS[]	 = { {"Focus in", "", ISS_OFF, 0, 0}, {"Focus out", "", ISS_OFF, 0, 0}};
+static ISwitch	FocusSpeedS[]	 = { {"FOCUS_HALT", "Halt", ISS_ON, 0, 0}, { "FOCUS_FAST", "Fast", ISS_OFF, 0, 0}, {"FOCUS_MEDIUM", "Medium", ISS_OFF, 0, 0}, {"FOCUS_SLOW", "Slow", ISS_OFF, 0, 0}};
+static ISwitch  FocusMotionS[]	 = { {"FOCUS_IN", "Focus in", ISS_OFF, 0, 0}, {"FOCUS_OUT", "Focus out", ISS_OFF, 0, 0}};
+static INumber  FocusTimerN[]    = { {"TIMEOUT", "Timeout (s)", "%10.6m", 0., 120., 1., 0., 0, 0, 0 }};
+
+static INumberVectorProperty FocusTimerNP = { mydev, "FOCUS_TIMEOUT", "Focus Timer", FOCUS_GROUP, IP_RW, 0, IPS_IDLE, FocusTimerN, NARRAY(FocusTimerN), 0, 0};
 
 /* equatorial position */
 INumber eq[] = {
@@ -83,7 +117,7 @@ INumber eq[] = {
 //TODO decide appropiate TIME_OUT
 // N.B. No Static identifier as it is needed for external linkage
 INumberVectorProperty eqNum = {
-    mydev, "EQUATORIAL_COORD", "Equatorial J2000", BASIC_GROUP, IP_RW, 0, IPS_IDLE,
+    mydev, "EQUATORIAL_EOD_COORD", "Equatorial JNow", BASIC_GROUP, IP_RW, 0, IPS_IDLE,
     eq, NARRAY(eq), 0, 0};
 
 /* Fundamental group */
@@ -94,11 +128,6 @@ static ITextVectorProperty Port		= { mydev, "DEVICE_PORT", "Ports", COMM_GROUP,
 /* Basic data group */
 static ISwitchVectorProperty AlignmentSw	= { mydev, "Alignment", "", COMM_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, AlignmentS, NARRAY(AlignmentS), 0, 0};
 
-static INumber altLimit[] = {
-       {"minAlt", "min Alt", "%+03f", -90., 90., 0., 0., 0, 0, 0},
-       {"maxAlt", "max Alt", "%+03f", -90., 90., 0., 0., 0, 0, 0}};
-static INumberVectorProperty elevationLimit = { mydev, "altLimit", "Slew elevation Limit", BASIC_GROUP, IP_RW, 0, IPS_IDLE, altLimit, NARRAY(altLimit), 0, 0};
-
 /* Movement group */
 static ISwitchVectorProperty OnCoordSetSw    = { mydev, "ON_COORD_SET", "On Set", BASIC_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, OnCoordSetS, NARRAY(OnCoordSetS), 0, 0};
 
@@ -110,16 +139,16 @@ static ISwitchVectorProperty SlewModeSw      = { mydev, "Slew rate", "", MOVE_GR
 
 static ISwitchVectorProperty TrackModeSw  = { mydev, "Tracking Mode", "", MOVE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, TrackModeS, NARRAY(TrackModeS), 0, 0};
 
-static INumber TrackFreq[]  = {{ "trackFreq", "Freq", "%g", 50.0, 80.0, 0.1, 60.1, 0, 0, 0}};
+static INumber TrackFreq[]  = {{ "trackFreq", "Freq", "%g", 56.4, 60.1, 0.1, 60.1, 0, 0, 0}};
 
 static INumberVectorProperty TrackingFreq= { mydev, "Tracking Frequency", "", MOVE_GROUP, IP_RW, 0, IPS_IDLE, TrackFreq, NARRAY(TrackFreq), 0, 0};
 
 static ISwitchVectorProperty MovementSw      = { mydev, "MOVEMENT", "Move toward", MOVE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, MovementS, NARRAY(MovementS), 0, 0};
 
 // Focus Control
-static ISwitchVectorProperty	FocusSpeedSw  = {mydev, "Speed", "", FOCUS_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, FocusSpeedS, NARRAY(FocusSpeedS), 0, 0};
+static ISwitchVectorProperty	FocusSpeedSw  = {mydev, "FOCUS_SPEED", "Speed", FOCUS_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, FocusSpeedS, NARRAY(FocusSpeedS), 0, 0};
 
-static ISwitchVectorProperty	FocusMotionSw = {mydev, "Motion", "", FOCUS_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, FocusMotionS, NARRAY(FocusMotionS), 0, 0};
+static ISwitchVectorProperty	FocusMotionSw = {mydev, "FOCUS_MOTION", "Motion", FOCUS_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, FocusMotionS, NARRAY(FocusMotionS), 0, 0};
 
 /* Data & Time */
 static IText UTC[] = {{"UTC", "UTC", 0, 0, 0, 0}};
@@ -148,7 +177,6 @@ void changeLX200GenericDeviceName(const char * newName)
   strcpy(AlignmentSw.device, newName);
 
   // BASIC_GROUP
-  strcpy(elevationLimit.device , newName );
   strcpy(eqNum.device, newName);
   strcpy(OnCoordSetSw.device , newName );
   strcpy(abortSlewSw.device , newName );
@@ -163,6 +191,7 @@ void changeLX200GenericDeviceName(const char * newName)
   // FOCUS_GROUP
   strcpy(FocusSpeedSw.device , newName );
   strcpy(FocusMotionSw.device , newName );
+  strcpy(FocusTimerNP.device, newName);
 
   // DATETIME_GROUP
   strcpy(Time.device , newName );
@@ -194,7 +223,6 @@ void ISInit()
   return;
 
  isInit = 1;
-
  
   PortT[0].text = strcpy(new char[32], "/dev/ttyS0");
   UTC[0].text   = strcpy(new char[32], "YYYY-MM-DDTHH:MM:SS");
@@ -275,7 +303,6 @@ LX200Generic::LX200Generic()
    time_t t;
    time (&t);
    utp = gmtime (&t);
-
    
    currentSiteNum = 1;
    trackingMode   = LX200_TRACK_DEFAULT;
@@ -287,6 +314,7 @@ LX200Generic::LX200Generic()
    currentRA      = 0;
    currentDEC     = 0;
    currentSet     = 0;
+   UTCOffset      = 0;
    lastMove[0] = lastMove[1] = lastMove[2] = lastMove[3] = 0;
 
    localTM = new tm;
@@ -299,6 +327,9 @@ LX200Generic::LX200Generic()
    
    // Children call parent routines, this is the default
    IDLog("initilizaing from generic LX200 device...\n");
+   IDLog("INDI Version: 2004-02-17\n");
+ 
+   //enableSimulation(true);  
 }
 
 void LX200Generic::setCurrentDeviceName(const char * devName)
@@ -319,7 +350,6 @@ void LX200Generic::ISGetProperties(const char *dev)
   IDDefSwitch (&AlignmentSw, NULL);
 
   // BASIC_GROUP
-  IDDefNumber (&elevationLimit, NULL);
   IDDefNumber (&eqNum, NULL);
   IDDefSwitch (&OnCoordSetSw, NULL);
   IDDefSwitch (&abortSlewSw, NULL);
@@ -334,6 +364,7 @@ void LX200Generic::ISGetProperties(const char *dev)
   // FOCUS_GROUP
   IDDefSwitch(&FocusSpeedSw, NULL);
   IDDefSwitch(&FocusMotionSw, NULL);
+  IDDefNumber(&FocusTimerNP, NULL);
 
   // DATETIME_GROUP
   IDDefText   (&Time, NULL);
@@ -352,7 +383,6 @@ void LX200Generic::ISGetProperties(const char *dev)
 
 void LX200Generic::ISNewText (const char *dev, const char *name, char *texts[], char *names[], int n)
 {
-	double UTCOffset, dayDiff;
 	int err;
 	struct tm *ltp = new tm;
 	struct tm utm;
@@ -403,7 +433,7 @@ void LX200Generic::ISNewText (const char *dev, const char *name, char *texts[],
        {
 	  if (checkPower(&Time))
 	   return;
-
+	  
 	  if (extractISOTime(texts[0], &utm) < 0)
 	  {
 	    Time.s = IPS_IDLE;
@@ -416,14 +446,17 @@ void LX200Generic::ISNewText (const char *dev, const char *name, char *texts[],
 		ltp->tm_year += 1900;
 
 	        
-                dayDiff = utm.tm_mday - ltp->tm_mday;
+                /*dayDiff = utm.tm_mday - ltp->tm_mday;
 		if (dayDiff == 0)
 		   UTCOffset = (ltp->tm_hour - utm.tm_hour);  
 		else if (dayDiff > 0)
 		   UTCOffset = ltp->tm_hour - utm.tm_hour - 24;
-		else UTCOffset = ltp->tm_hour - utm.tm_hour + 24;
+		else UTCOffset = ltp->tm_hour - utm.tm_hour + 24;*/
+		tzset();
 		
-		IDLog("time is %02d:%02d:%02d\n", ltp->tm_hour, ltp->tm_min, ltp->tm_sec);
+		UTCOffset = timezoneOffset();
+		
+		IDLog("local time is %02d:%02d:%02d\nUTCOffset: %g\n", ltp->tm_hour, ltp->tm_min, ltp->tm_sec, UTCOffset);
 		
 		getSDTime(&STime[0].value);
 		IDSetNumber(&SDTime, NULL);
@@ -462,10 +495,21 @@ void LX200Generic::ISNewText (const char *dev, const char *name, char *texts[],
 
 		localTM = ltp;
 		
-		if ( ( err = setCalenderDate(ltp->tm_mday, ltp->tm_mon, ltp->tm_year) < 0) )
-	  	{
-		  handleError(&Time, err, "Setting local date.");
-		  return;
+		if (!strcmp(dev, "LX200 GPS"))
+		{
+			if ( ( err = setCalenderDate(utm.tm_mday, utm.tm_mon, utm.tm_year) < 0) )
+	  		{
+		  		handleError(&Time, err, "Setting UTC date.");
+		  		return;
+			}
+		}
+		else
+		{
+			if ( ( err = setCalenderDate(ltp->tm_mday, ltp->tm_mon, ltp->tm_year) < 0) )
+	  		{
+		  		handleError(&Time, err, "Setting local date.");
+		  		return;
+			}
 		}
 		
  		IDSetText(&Time , "Date changed, updating planetary data...");
@@ -506,17 +550,28 @@ void LX200Generic::ISNewNumber (const char *dev, const char *name, double values
 	  if (nset == 2)
 	  {
 	   /*eqNum.s = IPS_BUSY;*/
+	   char RAStr[32], DecStr[32];
 
-	   IDLog("We recevined J2000 RA %f - DEC %f\n", newRA, newDEC);;
-	   apparentCoord( (double) J2000, JD, &newRA, &newDEC);
-	   IDLog("Processed to RA %f - DEC %f\n", newRA, newDEC);
+	   fs_sexa(RAStr, newRA, 2, 3600);
+	   fs_sexa(DecStr, newDEC, 2, 3600);
+	  
+	   IDLog("We received J2000 RA %g - DEC %g\n", newRA, newDEC);
+	   IDLog("We received J2000 RA %s - DEC %s\n", RAStr, DecStr);
+	   
+	   /*apparentCoord( (double) J2000, JD, &newRA, &newDEC);
+	   
+	   fs_sexa(RAStr, newRA, 2, 3600);
+	   fs_sexa(DecStr, newDEC, 2, 3600);
+	   
+	   IDLog("Processed to JNow RA %f - DEC %f\n", newRA, newDEC);
+	   IDLog("Processed to JNow RA %s - DEC %s\n", RAStr, DecStr);*/
 
 	   if ( (err = setObjectRA(newRA)) < 0 || ( err = setObjectDEC(newDEC)) < 0)
 	   {
 	     handleError(&eqNum, err, "Setting RA/DEC");
 	     return;
-	   }
-
+	   } 
+	   
            /*eqNum.s = IPS_BUSY;*/
 	   targetRA  = newRA;
 	   targetDEC = newDEC;
@@ -620,13 +675,13 @@ void LX200Generic::ISNewNumber (const char *dev, const char *name, double values
 		setSiteLatitude(newLat);
 		geoNum.np[0].value = newLat;
 		geoNum.np[1].value = newLong;
-		sprintf (msg, "Site location updated to Lat %s - Long %s", l, L);
+		snprintf (msg, sizeof(msg), "Site location updated to Lat %.32s - Long %.32s", l, L);
 	    } else
 	    {
 		geoNum.s = IPS_IDLE;
-		sprintf (msg, "Lat or Long missing or invalid");
+		strcpy(msg, "Lat or Long missing or invalid");
 	    }
-	    IDSetNumber (&geoNum, msg);
+	    IDSetNumber (&geoNum, "%s", msg);
 	    return;
 	}
 
@@ -660,48 +715,25 @@ void LX200Generic::ISNewNumber (const char *dev, const char *name, double values
 	 
 	  return;
 	}
-
-	if (!strcmp (name, elevationLimit.name))
+	
+	if (!strcmp(name, FocusTimerNP.name))
 	{
-	    // new elevation limits
-	    double minAlt = 0, maxAlt = 0;
-	    int i, nset;
-
-	  if (checkPower(&elevationLimit))
+	  if (checkPower(&FocusTimerNP))
 	   return;
+	   
+	  // Don't update if busy
+	  if (FocusTimerNP.s == IPS_BUSY)
+	   return;
+	   
+	  IUUpdateNumbers(&FocusTimerNP, values, names, n);
+	  
+	  FocusTimerNP.s = IPS_OK;
+	  
+	  IDSetNumber(&FocusTimerNP, NULL);
+	  IDLog("Setting focus timer to %g\n", FocusTimerN[0].value);
+	  
+	  return;
 
-	    for (nset = i = 0; i < n; i++)
-	    {
-		INumber *altp = IUFindNumber (&elevationLimit, names[i]);
-		if (altp == &altLimit[0])
-		{
-		    minAlt = values[i];
-		    nset += minAlt >= -90.0 && minAlt <= 90.0;
-		} else if (altp == &altLimit[1])
-		{
-		    maxAlt = values[i];
-		    nset += maxAlt >= -90.0 && maxAlt <= 90.0;
-		}
-	    }
-	    if (nset == 2)
-	    {
-		//char l[32], L[32];
-		if ( ( err = setMinElevationLimit( (int) minAlt) < 0) )
-	 	{
-	         handleError(&elevationLimit, err, "Setting elevation limit");
-	 	}
-		setMaxElevationLimit( (int) maxAlt);
-		elevationLimit.np[0].value = minAlt;
-		elevationLimit.np[1].value = maxAlt;
-		elevationLimit.s = IPS_OK;
-		IDSetNumber (&elevationLimit, NULL);
-	    } else
-	    {
-		elevationLimit.s = IPS_IDLE;
-		IDSetNumber(&elevationLimit, "elevation limit missing or invalid");
-	    }
-
-	    return;
 	}
 
 }
@@ -719,7 +751,7 @@ void LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
 	//IDLog("in new Switch with Device= %s and Property= %s and #%d items\n", dev, name,n);
 	//IDLog("SolarSw name is %s\n", SolarSw.name);
 
-	IDLog("The device name is %s\n", dev);
+	//IDLog("The device name is %s\n", dev);
 	// ignore if not ours //
 	if (strcmp (thisDevice, dev))
 	    return;
@@ -829,7 +861,7 @@ void LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
 	    else
 	    {
 	        IUResetSwitches(&MovementSw);
-	        abortSlewSw.s = IPS_IDLE;
+	        abortSlewSw.s = IPS_OK;
 	        IDSetSwitch(&abortSlewSw, NULL);
 	    }
 
@@ -880,7 +912,8 @@ void LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
 	      return;
 	  }
 
-	  geoNum.np[0].value = dd + mm / 60.0;
+	  if (dd > 0) geoNum.np[0].value = dd + mm / 60.0;
+	  else geoNum.np[0].value = dd - mm / 60.0;
 	  
 	  if ( ( err = getSiteLongitude(&dd, &mm) < 0))
 	  {
@@ -888,7 +921,8 @@ void LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
 		return;
 	  }
 	  
-	  geoNum.np[1].value = dd + mm / 60.0;
+	  if (dd > 0) geoNum.np[1].value = 360.0 - (dd + mm / 60.0);
+	  else geoNum.np[1].value = (dd - mm / 60.0) * -1.0;
 	  
 	  getSiteName( SiteName.tp[0].text, currentSiteNum);
 
@@ -912,12 +946,24 @@ void LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
 	   IUUpdateSwitches(&FocusSpeedSw, states, names, n);
 	   index = getOnSwitch(&FocusSpeedSw);
 	  
+	  
 	  if ( ( err = setFocuserSpeedMode(index) < 0) )
 	  {
 	        handleError(&FocusSpeedSw, err, "Setting focuser speed mode"); 
 		return;
 	  }
 	  
+	  /* disable timer and motion */
+	  if (index == 0)
+	  {
+	    IUResetSwitches(&FocusMotionSw);
+	    FocusMotionSw.s = IPS_IDLE;
+	    FocusTimerNP.s  = IPS_IDLE;
+	    IDSetSwitch(&FocusMotionSw, NULL);
+	    IDSetNumber(&FocusTimerNP, NULL);
+	  }
+	    
+	  
 	  FocusSpeedSw.s = IPS_OK;
 	  IDSetSwitch(&FocusSpeedSw, NULL);
 	  return;
@@ -930,16 +976,32 @@ void LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
 	   return;
 
 	  IUResetSwitches(&FocusMotionSw);
+	  
+	  // If speed is "halt"
+	  if (FocusSpeedS[0].s == ISS_ON)
+	  {
+	    FocusMotionSw.s = IPS_IDLE;
+	    IDSetSwitch(&FocusMotionSw, NULL);
+	    return;
+	  }
+	  
 	  IUUpdateSwitches(&FocusMotionSw, states, names, n);
 	  index = getOnSwitch(&FocusMotionSw);
 	  
+	  
 	  if ( ( err = setFocuserMotion(index) < 0) )
 	  {
 	     handleError(&FocusMotionSw, err, "Setting focuser speed");
              return;
 	  }
 	  
-	  FocusMotionSw.s = IPS_OK;
+	  
+	  FocusMotionSw.s = IPS_BUSY;
+	  
+	  // with a timer 
+	  if (FocusTimerN[0].value > 0)  
+	     FocusTimerNP.s  = IPS_BUSY;
+	  
 	  IDSetSwitch(&FocusMotionSw, NULL);
 	  return;
 	}
@@ -1216,6 +1278,7 @@ static void retryConnection(void * p)
 void LX200Generic::ISPoll()
 {
         double dx, dy;
+	/*static int okCounter = 3;*/
 	int err=0;
 	
 	if (!isTelescopeOn())
@@ -1250,15 +1313,17 @@ void LX200Generic::ISPoll()
 	    // Wait until acknowledged or within threshold
 	    if (fabs(dx) <= RA_THRESHOLD && fabs(dy) <= DEC_THRESHOLD)
 	    {
+	      /* Don't set current to target. This might leave residual cumulative error 
 		currentRA = targetRA;
 		currentDEC = targetDEC;
-		apparentCoord( JD, (double) J2000, &currentRA, &currentDEC);
-		eqNum.np[0].value = currentRA;
-		eqNum.np[1].value = currentDEC;
-		IUResetSwitches(&OnCoordSetSw);
-		OnCoordSetSw.s = IPS_OK;
-		eqNum.s = IPS_OK;
-		IDSetNumber (&eqNum, NULL);
+	      */
+		
+	       eqNum.np[0].value = lastRA  = currentRA;
+	       eqNum.np[1].value = lastDEC = currentDEC;
+	       IUResetSwitches(&OnCoordSetSw);
+	       OnCoordSetSw.s = IPS_OK;
+	       eqNum.s = IPS_OK;
+	       IDSetNumber (&eqNum, NULL);
 
 		switch (currentSet)
 		{
@@ -1302,7 +1367,6 @@ void LX200Generic::ISPoll()
 
 	    } else
 	    {
-	        apparentCoord( JD, (double) J2000, &currentRA, &currentDEC);
 		eqNum.np[0].value = currentRA;
 		eqNum.np[1].value = currentDEC;
 		IDSetNumber (&eqNum, NULL);
@@ -1310,6 +1374,13 @@ void LX200Generic::ISPoll()
 	    break;
 
 	case IPS_OK:
+	  
+	  /*if (--okCounter >= 0)
+	    break;
+	  
+	// Activate again in 3 seconds
+	  okCounter = 3;*/
+	  
 	if ( (err = getLX200RA(&currentRA)) < 0 || (err = getLX200DEC(&currentDEC)) < 0)
 	{
 	  handleError(&eqNum, err, "Getting RA/DEC");
@@ -1318,18 +1389,12 @@ void LX200Generic::ISPoll()
 	
 	if (fault)
 	  correctFault();
-
-        if ( fabs (currentRA - lastRA) > 0.01 || fabs (currentDEC - lastDEC) > 0.01)
+	
+	if ( (currentRA != lastRA) || (currentDEC != lastDEC))
 	{
-		eqNum.np[0].value = currentRA;
-		eqNum.np[1].value = currentDEC;
-		lastRA  = currentRA;
-		lastDEC = currentDEC;
-		apparentCoord( JD, (double) J2000, &currentRA, &currentDEC);
-		eqNum.np[0].value = currentRA;
-		eqNum.np[1].value = currentDEC;
+	  	eqNum.np[0].value = lastRA  = currentRA;
+		eqNum.np[1].value = lastDEC = currentDEC;
 		IDSetNumber (&eqNum, NULL);
-
 	}
         break;
 
@@ -1345,7 +1410,7 @@ void LX200Generic::ISPoll()
 	 case IPS_BUSY:
 	   getLX200RA(&currentRA);
 	   getLX200DEC(&currentDEC);
-	   apparentCoord( JD, (double) J2000, &currentRA, &currentDEC);
+	   /*apparentCoord( JD, (double) J2000, &currentRA, &currentDEC);*/
 	   eqNum.np[0].value = currentRA;
 	   eqNum.np[1].value = currentDEC;
 
@@ -1356,13 +1421,54 @@ void LX200Generic::ISPoll()
 	 case IPS_ALERT:
 	   break;
 	 }
+	 
+	 switch (FocusTimerNP.s)
+	 {
+	   case IPS_IDLE:
+	     break;
+	     
+	   case IPS_BUSY:
+	    FocusTimerN[0].value--;
+	    
+	    if (FocusTimerN[0].value == 0)
+	    {
+	      
+	      if ( ( err = setFocuserSpeedMode(0) < 0) )
+              {
+	        handleError(&FocusSpeedSw, err, "setting focuser speed mode");
+                IDLog("Error setting focuser speed mode\n");
+                return;
+	      } 
+         
+	      
+	      FocusMotionSw.s = IPS_IDLE;
+	      FocusTimerNP.s  = IPS_OK;
+	      FocusSpeedSw.s  = IPS_OK;
+	      
+              IUResetSwitches(&FocusMotionSw);
+	      IUResetSwitches(&FocusSpeedSw);
+	      FocusSpeedS[0].s = ISS_ON;
+	      
+	      IDSetSwitch(&FocusSpeedSw, NULL);
+	      IDSetSwitch(&FocusMotionSw, NULL);
+	    }
+	    
+	    IDSetNumber(&FocusTimerNP, NULL);
+	    break;
+	    
+	   case IPS_OK:
+	    break;
+	    
+	   case IPS_ALERT:
+	    break;
+	 }
+    
 
 }
 
 void LX200Generic::getBasicData()
 {
 
-  int dd, mm;
   int err;
   struct tm *timep;
   time_t ut;
@@ -1370,7 +1476,7 @@ void LX200Generic::getBasicData()
   timep = gmtime (&ut);
   strftime (Time.tp[0].text, sizeof(Time.tp[0].text), "%Y-%m-%dT%H:%M:%S", timep);
 
-  IDLog("time is %s\n", Time.tp[0].text);
+  IDLog("PC UTC time is %s\n", Time.tp[0].text);
 
   getAlignment();
   
@@ -1392,31 +1498,7 @@ void LX200Generic::getBasicData()
   eqNum.np[0].value = targetRA;
   eqNum.np[1].value = targetDEC;
   
-  IDSetNumber (&eqNum, NULL);
-
-  if ( (err = getSDTime(&STime[0].value)) < 0)
-    IDMessage(thisDevice, "Failed to retrieve siderial time from device.");
-  else
-    IDSetNumber (&SDTime, NULL);
-    
-     
-  if ( (err = selectSite(currentSiteNum)) < 0)
-    IDMessage(thisDevice, "Failed to select a site from device.");
-  else
-   IDSetSwitch (&SitesSw, NULL);
-
-  
-  if ( (err = getSiteLatitude(&dd, &mm)) < 0)
-    IDMessage(thisDevice, "Failed to get site latitude from device.");
-  else
-    geoNum.np[0].value = dd + mm/60.0;
-  
-  if ( (err = getSiteLongitude(&dd, &mm)) < 0)
-    IDMessage(thisDevice, "Failed to get site longitude from device.");
-  else
-    geoNum.np[1].value = dd + mm/60.0;
-
-  IDSetNumber (&geoNum, NULL);
+  IDSetNumber (&eqNum, NULL);  
   
   SiteNameT[0].text = new char[64];
   
@@ -1429,9 +1511,10 @@ void LX200Generic::getBasicData()
      IDMessage(thisDevice, "Failed to get tracking frequency from device.");
   else
      IDSetNumber (&TrackingFreq, NULL);
-  
-  IDSetText   (&Time, NULL);
-  
+     
+     
+  updateLocation();
+  updateTime();
   
 }
 
@@ -1442,6 +1525,8 @@ int LX200Generic::handleCoordSet()
   char syncString[256];
   char RAStr[32], DecStr[32];
   double dx, dy;
+  
+  IDLog("In Handle Coord Set()\n");
 
   switch (currentSet)
   {
@@ -1451,6 +1536,7 @@ int LX200Generic::handleCoordSet()
           lastSet = LX200_SLEW;
 	  if (eqNum.s == IPS_BUSY)
 	  {
+	     IDLog("Aboring Slew\n");
 	     abortSlew();
 
 	     // sleep for 100 mseconds
@@ -1466,13 +1552,16 @@ int LX200Generic::handleCoordSet()
 	  eqNum.s = IPS_BUSY;
 	  fs_sexa(RAStr, targetRA, 2, 3600);
 	  fs_sexa(DecStr, targetDEC, 2, 3600);
-	  IDSetNumber(&eqNum, "Slewing to J2000 RA %s - DEC %s", RAStr, DecStr);
+	  IDSetNumber(&eqNum, "Slewing to JNow RA %s - DEC %s", RAStr, DecStr);
+	  IDLog("Slewing to JNow RA %s - DEC %s\n", RAStr, DecStr);
 	  break;
 
      // Track
      case LX200_TRACK:
+          IDLog("We're in LX200_TRACK\n");
           if (eqNum.s == IPS_BUSY)
 	  {
+	     IDLog("Aboring Slew\n");
 	     abortSlew();
 
 	     // sleep for 200 mseconds
@@ -1498,7 +1587,8 @@ int LX200Generic::handleCoordSet()
 		fs_sexa(RAStr, targetRA, 2, 3600);
 	        fs_sexa(DecStr, targetDEC, 2, 3600);
 		eqNum.s = IPS_BUSY;
-		IDSetNumber(&eqNum, "Slewing to J2000 RA %s - DEC %s", RAStr, DecStr);
+		IDSetNumber(&eqNum, "Slewing to JNow RA %s - DEC %s", RAStr, DecStr);
+		IDLog("Slewing to JNow RA %s - DEC %s\n", RAStr, DecStr);
 	  }
 	  else
 	  {
@@ -1636,8 +1726,16 @@ void LX200Generic::powerTelescope()
 {
      switch (PowerSP.sp[0].s)
      {
-      case ISS_ON:
-
+      case ISS_ON:  
+	
+        if (simulation)
+	{
+	  PowerSP.s = IPS_OK;
+	  IDSetSwitch (&PowerSP, "Simulated telescope is online.");
+	  updateTime();
+	  return;
+	}
+	
          if (Connect(Port.tp[0].text))
 	 {
 	   PowerS[0].s = ISS_OFF;
@@ -1676,7 +1774,6 @@ void LX200Generic::slewError(int slewCode)
 {
     OnCoordSetSw.s = IPS_IDLE;
     ParkSP.s = IPS_IDLE;
-    
     IDSetSwitch(&ParkSP, NULL);
 
     if (slewCode == 1)
@@ -1695,7 +1792,7 @@ void LX200Generic::getAlignment()
    if (PowerSP.s != IPS_OK)
     return;
 
-   char align = ACK();
+   signed char align = ACK();
    if (align < 0)
    {
      IDSetSwitch (&AlignmentSw, "Failed to get telescope alignment.");
@@ -1730,3 +1827,213 @@ void LX200Generic::enableSimulation(bool enable)
    else
      IDLog("Simulation is disabled.\n");
 }
+
+void LX200Generic::updateTime()
+{
+
+  char cdate[32];
+  double ctime;
+  int h, m, s;
+  int day, month, year, result;
+  int UTC_h, UTC_month, UTC_year, UTC_day, daysInFeb;
+  bool leapYear;
+  
+  tzset();
+  
+  UTCOffset = timezoneOffset();
+  IDLog("Daylight: %s - TimeZone: %g\n", daylight ? "Yes" : "No", UTCOffset);
+  
+	
+  if (simulation)
+  {
+    sprintf(UTC[0].text, "%d-%02d-%02dT%02d:%02d:%02d", 1979, 6, 25, 3, 30, 30);
+    IDLog("Telescope ISO date and time: %s\n", UTC[0].text);
+    IDSetText(&Time, NULL);
+    return;
+  }
+  
+  getLocalTime24(&ctime);
+  getSexComponents(ctime, &h, &m, &s);
+  
+  UTC_h = h;
+  
+  if ( (result = getSDTime(&STime[0].value)) < 0)
+    IDMessage(thisDevice, "Failed to retrieve siderial time from device.");
+  
+  getCalenderDate(cdate);
+  
+  result = sscanf(cdate, "%d/%d/%d", &year, &month, &day);
+  if (result != 3) return;
+  
+  if (year % 4 == 0)
+  {
+    if (year % 100 == 0)
+    {
+      if (year % 400 == 0)
+       leapYear = true;
+      else 
+       leapYear = false;
+    }
+    else
+       leapYear = true;
+  }
+  else
+       leapYear = false;
+  
+  daysInFeb = leapYear ? 29 : 28;
+  
+  UTC_year  = year; 
+  UTC_month = month;
+  UTC_day   = day;
+  
+  IDLog("day: %d - month %d - year: %d\n", day, month, year);
+  
+  // we'll have to convert telescope time to UTC manually starting from hour up
+  // seems like a stupid way to do it.. oh well
+  UTC_h = (int) UTCOffset + h;
+  if (UTC_h < 0)
+  {
+   UTC_h += 24;
+   UTC_day--;
+  }
+  else if (UTC_h > 24)
+  {
+   UTC_h -= 24;
+   UTC_day++;
+  }
+  
+  switch (UTC_month)
+  {
+    case 1:
+    case 8:
+     if (UTC_day < 1)
+     {
+     	UTC_day = 31;
+     	UTC_month--;
+     }
+     else if (UTC_day > 31)
+     {
+       UTC_day = 1;
+       UTC_month++;
+     }
+     break;
+     
+   case 2:
+   if (UTC_day < 1)
+     {
+     	UTC_day = 31;
+     	UTC_month--;
+     }
+     else if (UTC_day > daysInFeb)
+     {
+       UTC_day = 1;
+       UTC_month++;
+     }
+     break;
+     
+  case 3:
+     if (UTC_day < 1)
+     {
+     	UTC_day = daysInFeb;
+     	UTC_month--;
+     }
+     else if (UTC_day > 31)
+     {
+       UTC_day = 1;
+       UTC_month++;
+     }
+     break;
+   
+   case 4:
+   case 6:
+   case 9:
+   case 11:
+    if (UTC_day < 1)
+     {
+     	UTC_day = 31;
+     	UTC_month--;
+     }
+     else if (UTC_day > 30)
+     {
+       UTC_day = 1;
+       UTC_month++;
+     }
+     break;
+   
+   case 5:
+   case 7:
+   case 10:
+   case 12:
+    if (UTC_day < 1)
+     {
+     	UTC_day = 30;
+     	UTC_month--;
+     }
+     else if (UTC_day > 31)
+     {
+       UTC_day = 1;
+       UTC_month++;
+     }
+     break;
+   
+  }   
+       
+  if (UTC_month < 1)
+  {
+   UTC_month = 12;
+   UTC_year--;
+  }
+  else if (UTC_month > 12)
+  {
+    UTC_month = 1;
+    UTC_year++;
+  }
+  
+  /* Format it into ISO 8601 */
+  sprintf(UTC[0].text, "%d-%02d-%02dT%02d:%02d:%02d", UTC_year, UTC_month, UTC_day, UTC_h, m, s);
+  
+  IDLog("Local telescope time: %02d:%02d:%02d\n", h, m , s);
+  IDLog("Telescope SD Time is: %g\n", STime[0].value);
+  IDLog("UTC date and time: %s\n", UTC[0].text);
+  
+
+  // Let's send everything to the client
+  IDSetText(&Time, NULL);
+  IDSetNumber(&SDTime, NULL);
+
+}
+
+void LX200Generic::updateLocation()
+{
+
+ int dd = 0, mm = 0, err = 0;
+ 
+ if ( (err = getSiteLatitude(&dd, &mm)) < 0)
+    IDMessage(thisDevice, "Failed to get site latitude from device.");
+  else
+  {
+    if (dd > 0)
+    	geoNum.np[0].value = dd + mm/60.0;
+    else
+        geoNum.np[0].value = dd - mm/60.0;
+  
+      IDLog("Autostar Latitude: %d:%d\n", dd, mm);
+      IDLog("INDI Latitude: %g\n", geoNum.np[0].value);
+  }
+  
+  if ( (err = getSiteLongitude(&dd, &mm)) < 0)
+    IDMessage(thisDevice, "Failed to get site longitude from device.");
+  else
+  {
+    if (dd > 0) geoNum.np[1].value = 360.0 - (dd + mm/60.0);
+    else geoNum.np[1].value = (dd - mm/60.0) * -1.0;
+    
+    IDLog("Autostar Longitude: %d:%d\n", dd, mm);
+    IDLog("INDI Longitude: %g\n", geoNum.np[1].value);
+  }
+  
+  IDSetNumber (&geoNum, NULL);
+
+}
+
+
