@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include <kdebug.h>
+#include <qpainter.h>
 
 #include "infobox.h"
 
@@ -119,7 +120,7 @@ bool InfoBox::constrain( QRect r, bool inside ) {
 	}
 }
 
-void InfoBox::draw( QPainter &p, QColor BGColor, bool fillBG ) {
+void InfoBox::draw( QPainter &p, QColor BGColor, unsigned int BGMode ) {
 	QRect r;
 	int w,h;
 
@@ -149,11 +150,8 @@ void InfoBox::draw( QPainter &p, QColor BGColor, bool fillBG ) {
 	constrain( QRect( 0, 0, p.window().width(), p.window().height() ) );
 
 //Draw the box boundary and the text
-
-	if ( fillBG ) {
-		p.fillRect( x(), y(), width(), height(), QBrush( BGColor ) );
-		p.drawRect( x(), y(), width(), height() );
-	}
+	if ( BGMode==1 ) p.fillRect( x(), y(), width(), height(), QBrush( BGColor, Dense4Pattern ) );
+	if ( BGMode==2 ) p.fillRect( x(), y(), width(), height(), QBrush( BGColor ) );
 
 	p.drawText( x() + padx(), y() + ShadedTextHeight/2 + pady(), text1() );
 
@@ -172,7 +170,7 @@ void InfoBox::move( int x, int y ) {
 }
 
 void InfoBox::move( QPoint p ) {
-	move( p.x(), p.y() );
+	move( p.x(), p.y() ); emit moved( QPoint( p.x(), p.y() ) );
 }
 
 #include "infobox.moc"
