@@ -60,11 +60,13 @@ public:
 	*@param addTrail if true, the add/remove planet trail item reads "Add Trail"
 	*if false, it reads "Remove Trail".
 	*@param showAngularDistance if true, the Angular Distance item is added.
-	*/
+	*@param showObsList if true, the Add to List/Remove from List item is added.
+ */
 	void initPopupMenu( SkyObject *obj, QString name1, QString name2, QString type,
 			bool showRiseSet=true, bool showCenterTrack=true,
 			bool showDetails=true, bool showTrail=false, 
-			bool addTrail=false, bool showAngularDistance=true );
+			bool addTrail=false, bool showAngularDistance=true,
+			bool showObsList=true );
 
 /**Add an item to the popup menu for each of the URL links associated with 
 	*this object.  URL links appear in two categories: images and information pages.
@@ -148,7 +150,7 @@ public:
 
 private:
 	KStars *ksw;
-	QLabel *pmTitle, *pmTitle2, *pmType;
+	QLabel *pmTitle, *pmTitle2, *pmType, *pmConstellation;
 	QLabel *pmRiseTime, *pmSetTime, *pmTransitTime;
 
 };
