@@ -73,9 +73,8 @@ KStarsData::KStarsData() : stdDirs(0), locale(0),
 
 	//Check to see if config file already exists.  If not, set 
 	//useDefaultOptions = true
-	QString fname = locateLocal( "config", "kstarsrc" );
-	if ( QFile( fname ).exists() ) useDefaultOptions = false;
-	else useDefaultOptions = true;
+	QString fname = locate( "config", "kstarsrc" );
+	useDefaultOptions = fname.isEmpty();
 
 	//Instantiate LST and HourAngle
 	LST = new dms();
@@ -319,16 +318,16 @@ bool KStarsData::readINDIHosts(void)
   QFile localeFile;
   QFile file;
   char errmsg[1024];
-  char c;
+  signed char c;
   LilXML *xmlParser = newLilXML();
   XMLEle *root = NULL;
   XMLAtt *ap;
 
-  file.setName( locateLocal( "appdata", indiFile ) );
-		if ( !file.open( IO_ReadOnly ) )
+  file.setName( locate( "appdata", indiFile ) );
+	if ( file.name().isEmpty() || !file.open( IO_ReadOnly ) )
 		 return false;
 
-while ( (c = (char) file.getch()) != -1)
+ while ( (c = (signed char) file.getch()) != -1)
  {
     root = readXMLEle(xmlParser, c, errmsg);
 
@@ -1050,6 +1049,9 @@ bool KStarsData::readUserLog(void)
 		data   = sub.mid(sub.find("]") + 2, endIndex - (sub.find("]") + 2));
 		buffer = buffer.mid(endIndex + 11);
 
+		//Find the sky object named 'name'.
+		//Note that ObjectNameList::find() looks for the ascii representation 
+		//of star genetive names, so stars are identified that way in the user log.
 		SkyObjectName *sonm = ObjNames.find(name);
 		if (sonm == 0) {
 			kdWarning() << k_funcinfo << name << " not found" << endl;
@@ -1208,7 +1210,7 @@ bool KStarsData::readCustomData( QString filename, QPtrList<DeepSkyObject> &objL
 //						StarObject *o = new StarObject( RA, Dec, mag, name, "", spType );
 //						objList.append( o );
 //					} else if ( iType > 2 && iType <= 8 ) { //Deep-sky objects...
-						if ( name == "" ) name = i18n( "unnamed object" );
+						if ( name.isEmpty()) name = i18n( "unnamed object" );
 
 						DeepSkyObject *o = new DeepSkyObject( iType, RA, Dec, mag, name, "", "" );
 						objList.append( o );
@@ -1404,8 +1406,8 @@ bool KStarsData::readCityData( void ) {
 // end new code
 
 	//check for local cities database, but don't require it.
-	file.setName( locateLocal( "appdata", "mycities.dat" ) ); //determine filename in local user KDE directory tree.
-	if ( file.open( IO_ReadOnly ) ) {
+	file.setName( locate( "appdata", "mycities.dat" ) ); //determine filename in local user KDE directory tree.
+	if ( file.exists() && file.open( IO_ReadOnly ) ) {
 		QTextStream stream( &file );
 
   	while ( !stream.eof() ) {
