@@ -127,7 +127,7 @@ void KStars::initActions() {
 	KToggleAction *a = new KToggleAction(i18n( "Show the information boxes", "Show &Info Boxes"),
 			0, 0, 0, actionCollection(), "show_boxes");
 #if KDE_IS_VERSION( 3, 2, 90 )
-	a->setCheckedState(i18n("Hide &Info Boxes"));
+//	a->setCheckedState(i18n("Hide &Info Boxes"));
 #endif
 	a->setChecked( Options::showInfoBoxes() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(setVisible(bool)));
@@ -137,7 +137,7 @@ void KStars::initActions() {
 	a = new KToggleAction(i18n( "Show time-related info box", "Show &Time Box"),
 			0, 0, 0, actionCollection(), "show_time_box");
 #if KDE_IS_VERSION( 3, 2, 90 )
-	a->setCheckedState(i18n("Hide &Time Box"));
+	//a->setCheckedState(i18n("Hide &Time Box"));
 #endif
 	a->setChecked( Options::showTimeBox() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(showTimeBox(bool)));
@@ -146,7 +146,7 @@ void KStars::initActions() {
 	a = new KToggleAction(i18n( "Show focus-related info box", "Show &Focus Box"),
 			0, 0, 0, actionCollection(), "show_focus_box");
 #if KDE_IS_VERSION( 3, 2, 90 )
-	a->setCheckedState(i18n("Hide &Focus Box"));
+	//a->setCheckedState(i18n("Hide &Focus Box"));
 #endif
 	a->setChecked( Options::showFocusBox() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(showFocusBox(bool)));
@@ -155,7 +155,7 @@ void KStars::initActions() {
 	a = new KToggleAction(i18n( "Show location-related info box", "Show &Location Box"),
 			0, 0, 0, actionCollection(), "show_location_box");
 #if KDE_IS_VERSION( 3, 2, 90 )
-	a->setCheckedState(i18n("Hide &Location Box"));
+	//a->setCheckedState(i18n("Hide &Location Box"));
 #endif
 	a->setChecked( Options::showGeoBox() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(showGeoBox(bool)));
@@ -165,7 +165,7 @@ void KStars::initActions() {
 	a = new KToggleAction(i18n( "Show Main Toolbar" ),
 			0, 0, 0, actionCollection(), "show_mainToolBar");
 #if KDE_IS_VERSION( 3, 2, 90 )
-	a->setCheckedState(i18n("Hide Main Toolbar"));
+	//a->setCheckedState(i18n("Hide Main Toolbar"));
 #endif
 	a->setChecked( Options::showMainToolBar() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
@@ -173,7 +173,7 @@ void KStars::initActions() {
 	a = new KToggleAction(i18n( "Show View Toolbar" ),
 			0, 0, 0, actionCollection(), "show_viewToolBar");
 #if KDE_IS_VERSION( 3, 2, 90 )
-	a->setCheckedState(i18n("Hide View Toolbar"));
+	//a->setCheckedState(i18n("Hide View Toolbar"));
 #endif
 	a->setChecked( Options::showViewToolBar() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
@@ -182,21 +182,21 @@ void KStars::initActions() {
 	a = new KToggleAction(i18n( "Show Statusbar" ),
 			0, 0, 0, actionCollection(), "show_statusBar");
 #if KDE_IS_VERSION( 3, 2, 90 )
-	a->setCheckedState(i18n("Hide Statusbar"));
+	//a->setCheckedState(i18n("Hide Statusbar"));
 #endif
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 	a->setChecked( Options::showStatusBar() );
 	a = new KToggleAction(i18n( "Show Az/Alt Field" ),
 			0, 0, 0, actionCollection(), "show_sbAzAlt");
 #if KDE_IS_VERSION( 3, 2, 90 )
-	a->setCheckedState(i18n("Hide Az/Alt Field"));
+	//a->setCheckedState(i18n("Hide Az/Alt Field"));
 #endif
 	a->setChecked( Options::showAltAzField() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 	a = new KToggleAction(i18n( "Show RA/Dec Field" ),
 			0, 0, 0, actionCollection(), "show_sbRADec");
 #if KDE_IS_VERSION( 3, 2, 90 )
-	a->setCheckedState(i18n("Hide RA/Dec Field"));
+	//a->setCheckedState(i18n("Hide RA/Dec Field"));
 #endif
 	a->setChecked( Options::showRADecField() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
@@ -215,8 +215,8 @@ void KStars::initActions() {
 //Add any user-defined color schemes:
 	QFile file;
 	QString line, schemeName, filename;
-	file.setName( locateLocal( "appdata", "colors.dat" ) ); //determine filename in local user KDE directory tree.
-	if ( file.open( IO_ReadOnly ) ) {
+	file.setName( locate( "appdata", "colors.dat" ) ); //determine filename in local user KDE directory tree.
+	if ( file.exists() && file.open( IO_ReadOnly ) ) {
 		QTextStream stream( &file );
 
 		while ( !stream.eof() ) {
@@ -256,8 +256,11 @@ void KStars::initActions() {
 		actionCollection(), "startwizard" );
 
 //Tools Menu:
-	new KAction(i18n( "Calculator..."), KShortcut( "Ctrl+C"),
-			this, SLOT( slotCalculator() ), actionCollection(), "astrocalculator");
+        new KAction(i18n( "Calculator..."), KShortcut( "Ctrl+C"),
+                    this, SLOT( slotCalculator() ), actionCollection(), "astrocalculator");
+
+        new KAction(i18n( "Observing List..."), KShortcut( "Ctrl+L"),
+                    this, SLOT( slotObsList() ), actionCollection(), "obslist");
 
 	// enable action only if file was loaded and processed successfully.
 	if (!data()->VariableStarsList.isEmpty())
@@ -443,6 +446,7 @@ void KStars::initFOV() {
 			ostream << i18n( "use field-of-view for binoculars", "7x35 Binoculars" ) << ":558:1:#AAAAAA" << endl;
 			ostream << i18n( "use 1-degree field-of-view indicator", "One Degree" ) << ":60:2:#AAAAAA" << endl;
 			ostream << i18n( "use HST field-of-view indicator", "HST WFPC2" ) << ":2.4:0:#AAAAAA" << endl;
+			ostream << i18n( "use Radiotelescope HPBW", "30m at 1.3cm" ) << ":1.79:1:#AAAAAA" << endl;
 			f.close();
 		}
 	}
@@ -507,7 +511,9 @@ void KStars::datainitFinished(bool worked) {
 	data()->setFullTimeUpdate();
 	updateTime();
 
-	data()->clock()->start();
+	//Do not start the clock if the user specified "--paused" on the cmd line
+	if ( StartClockRunning )
+		data()->clock()->start();
 
 //Initialize FOV symbol from options
 	data()->fovSymbol.setName( Options::fOVName() );
@@ -617,9 +623,13 @@ void KStars::privatedata::buildGUI() {
 
 	ks->resize( Options::windowWidth(), Options::windowHeight() );
 
-	// initialize clock with current time/date
-	ks->slotSetTimeToNow();
-
+	// initialize clock with current time/date or the date/time specified on the command line
+	KStarsDateTime startDate = KStarsDateTime::fromString( ks->StartDateString );
+	if ( startDate.isValid() )
+		ks->data()->changeDateTime( ks->geo()->LTtoUT( startDate ) );
+	else 
+		ks->slotSetTimeToNow();
+	
 	//Define the celestial equator, horizon and ecliptic
 	KSNumbers tempnum(ks->data()->ut().djd());
 	ks->data()->initGuides(&tempnum);
