@@ -46,7 +46,7 @@ LocationDialog::LocationDialog( QWidget* parent )
 	CoordBox = new QGroupBox( page, "CoordBox" );
 	CityBox->setTitle( i18n( "Choose City" ) );
 	CoordBox->setTitle( i18n( "Choose/Modify Coordinates" ) );
-	
+
 //Create Layout managers
 	RootLay = new QVBoxLayout( page, 4, 4 ); //root mgr for dialog
 	CityLay = new QVBoxLayout( CityBox, 6, 4 ); //root mgr for CityBox
@@ -109,7 +109,7 @@ LocationDialog::LocationDialog( QWidget* parent )
 	TZBox->setDuplicatesEnabled( false );
 
 	for ( int i=0; i<25; ++i )
-		TZBox->insertItem( QString("%1").arg( (double)(i-12), 0, 'f', 2 ) );
+		TZBox->insertItem( KGlobal::locale()->formatNumber( (double)(i-12) ) );
 
 	QMap<QString, TimeZoneRule>::Iterator it = p->data()->Rulebook.begin();
 	QMap<QString, TimeZoneRule>::Iterator itEnd = p->data()->Rulebook.end();
@@ -120,18 +120,18 @@ LocationDialog::LocationDialog( QWidget* parent )
 	ShowTZRules = new QPushButton( i18n( "Explain DST Rules" ), CoordBox, "ShowDSTRules" );
 
 	AddCityButton = new QPushButton( i18n ( "Add to List" ), CoordBox, "AddCityButton" );
-	
+
 //Pack the widgets into the layouts
 	RootLay->addWidget( CityBox, 0, 0 );
 	RootLay->addWidget( CoordBox, 0, 0 );
-	
+
 	CityLay->addSpacing( 14 );
 	CityLay->addLayout( hlay, 0 );
-	
+
 	hlay->addLayout( vlay, 0 );
 	hlay->addSpacing( 12 );
 	hlay->addWidget( GeoBox, 0, 0 );
-	
+
 	vlay->addWidget( MapView, 0, 0 );
 	vlay->addLayout( glay, 0 );
 	vlay->addWidget( CountLabel, 0, 0 );
@@ -144,11 +144,11 @@ LocationDialog::LocationDialog( QWidget* parent )
 	glay->addWidget( CountryFilter, 2, 1 );
 
 	hlay->activate();
-	
+
 	CoordLay->addSpacing( 14 );
 	CoordLay->addLayout( glay2, 0 );
 	CoordLay->addLayout( hlay3, 0 );
-	
+
 	glay2->addWidget( NewCityLabel, 0, 0 );
 	glay2->addWidget( NewProvinceLabel, 1, 0 );
 	glay2->addWidget( NewCountryLabel, 2, 0 );
@@ -175,11 +175,9 @@ LocationDialog::LocationDialog( QWidget* parent )
 
 	hlay3->addStretch();
 	hlay3->addWidget( AddCityButton, 0 );
-	
+
 	CoordLay->activate();
 	RootLay->activate();
-	
-  GeoID.resize(10000);
 
 	connect( this, SIGNAL( cancelClicked() ), this, SLOT( reject() ) );
 	connect( CityFilter, SIGNAL( textChanged( const QString & ) ), this, SLOT( filterCity() ) );
@@ -207,6 +205,8 @@ LocationDialog::LocationDialog( QWidget* parent )
 	CityFilter->setTrapReturnKey(true);
 	ProvinceFilter->setTrapReturnKey(true);
 	CountryFilter->setTrapReturnKey(true);
+
+	filteredCityList.setAutoDelete( false );
 	
 	initCityList();
 	resize (640, 480);
@@ -219,54 +219,42 @@ void LocationDialog::initCityList( void ) {
 	KStars *p = (KStars *)parent();
 	for (GeoLocation *loc = p->data()->geoList.first(); loc; loc = p->data()->geoList.next())
 	{
-		QString s;
-		if ( loc->province().isEmpty() ) {
-			s = loc->translatedName() + ", " + loc->translatedCountry();
-		} else {
-			s = loc->translatedName() + ", " + loc->translatedProvince() + ", " + loc->translatedCountry();
-		}
-		GeoBox->insertItem( s );
-		GeoID[GeoBox->count() - 1] = p->data()->geoList.at();
+		GeoBox->insertItem( loc->fullName() );
+		filteredCityList.append( loc );
 
-		//If TZ is not even integer value, add it to listbox 
-		if ( loc->TZ0() - int( loc->TZ0() ) && ! TZBox->listBox()->findItem( QString("%1").arg( loc->TZ0(), 0, 'f', 2 ) ) ) {
+		//If TZ is not even integer value, add it to listbox
+		if ( loc->TZ0() - int( loc->TZ0() ) && ! TZBox->listBox()->findItem( KGlobal::locale()->formatNumber( loc->TZ0() ) ) ) {
 			for ( unsigned int i=0; i<((unsigned int) TZBox->count()); ++i ) {
 				if ( TZBox->text( i ).toDouble() > loc->TZ0() ) {
-					TZBox->insertItem( QString("%1").arg( loc->TZ0(), 0, 'f', 2 ), i-1 );
+					TZBox->insertItem( KGlobal::locale()->formatNumber( loc->TZ0() ), i-1 );
 					break;
 				}
 			}
 		}
 	}
 
-	QString scount;
-	if (GeoBox->count()==1)
-		scount = i18n( "One city matches search criteria" );
-	else
-		scount = i18n( "%1 cities match search criteria" ).arg( (int)GeoBox->count());
-
-	CountLabel->setText( scount );
+	//Sort the list of Cities alphabetically...note that filteredCityList may now have a different ordering!
+	GeoBox->sort();
 	
-	bool cityFound(false);
-	if ( GeoBox->firstItem() ) {
-		// attempt to set the current location
-		for (GeoLocation *loc = p->data()->geoList.first(); loc; loc = p->data()->geoList.next()) {
-			if ( loc->name() == p->geo()->name() &&
-						loc->province().stripWhiteSpace() == p->geo()->province().stripWhiteSpace() &&
-						loc->country() == p->geo()->country() ) {
-				cityFound = true;
+	CountLabel->setText( i18n("One city matches search criteria","%n cities match search criteria",GeoBox->count()) );
+
+	// attempt to highlight the current kstars location in the GeoBox
+	GeoBox->setCurrentItem( 0 );
+	if ( GeoBox->count() ) {
+		for ( uint i=0; i<GeoBox->count(); i++ ) {
+			if ( GeoBox->item(i)->text() == p->geo()->fullName() ) {
+				GeoBox->setCurrentItem( i );
 				break;
 			}
 		}
-
-		if ( cityFound ) GeoBox->setCurrentItem( p->data()->geoList.at() );
-		else GeoBox->setCurrentItem( GeoBox->firstItem() );
 	}
 }
 
 void LocationDialog::filterCity( void ) {
 	KStars *p = (KStars *)parent();
 	GeoBox->clear();
+	filteredCityList.clear();
+	
 	nameModified = false;
 	dataModified = false;
 	AddCityButton->setEnabled( false );
@@ -281,25 +269,15 @@ void LocationDialog::filterCity( void ) {
 		if ( sc.lower().startsWith( CityFilter->text().lower() ) &&
 				sp.lower().startsWith( ProvinceFilter->text().lower() ) &&
 				ss.lower().startsWith( CountryFilter->text().lower() ) ) {
-			sc.append( ", " );
-			if ( !sp.isEmpty() ) {
-				sc.append( sp );
-				sc.append( ", " );
-			}
-			sc.append( ss );
 
-			GeoBox->insertItem( sc );
-			GeoID[GeoBox->count() - 1] = p->data()->geoList.at();
+			GeoBox->insertItem( loc->fullName() );
+			filteredCityList.append( loc );
 		}
 	}
 
-	QString scount;
-	if (GeoBox->count()==1)
-		scount = i18n( "One city matches search criteria" );
-	else
-		scount = i18n( "%1 cities match search criteria" ).arg( (int)GeoBox->count());
-
-	CountLabel->setText( scount );
+	GeoBox->sort();
+	
+	CountLabel->setText( i18n("One city matches search criteria","%n cities match search criteria", GeoBox->count()) );
 
 	if ( GeoBox->firstItem() )		// set first item in list as selected
 		GeoBox->setCurrentItem( GeoBox->firstItem() );
@@ -309,43 +287,46 @@ void LocationDialog::filterCity( void ) {
 
 void LocationDialog::changeCity( void ) {
 	//when the selected city changes, set newCity, and redraw map
-	//Also, fill the fields at the bottom of the window with the selected city's data.
-	newCity = GeoID[GeoBox->currentItem()];
-	MapView->repaint();
-
-	KStars *p = (KStars *)parent();
-	GeoLocation c = p->data()->geoList.at(newCity);
-//	kdWarning() << "TimeZoneRule: " << p->data()->geoList.at(newCity)->tzrule() << endl;
-	NewCityName->setText( c.translatedName() );
-	NewProvinceName->setText( c.translatedProvince() );
-	NewCountryName->setText( c.translatedCountry() );
-	NewLong->showInDegrees( c.lng() );
-	NewLat->showInDegrees( c.lat() );
-	TZBox->setCurrentText( QString("%1").arg( c.TZ0(), 0, 'f', 2 ) );
-
-//Pick the City's rule from the rulebook
-	for ( int i=0; i<TZRuleBox->count(); ++i ) {
-		if ( p->data()->Rulebook[ TZRuleBox->text(i) ].equals( c.tzrule() ) ) {
-			TZRuleBox->setCurrentItem( i );
-			break;
+	SelectedCity = 0L;
+	if ( GeoBox->currentItem() >= 0 ) {
+		for (GeoLocation *loc = filteredCityList.first(); loc; loc = filteredCityList.next()) {
+			if ( loc->fullName() == GeoBox->currentText() ) {
+				SelectedCity = loc;
+				break;
+			}
 		}
 	}
+	
+	MapView->repaint();
 
+	//Fill the fields at the bottom of the window with the selected city's data.
+	if ( SelectedCity ) {
+		KStars *p = (KStars *)parent();
+		NewCityName->setText( SelectedCity->translatedName() );
+		NewProvinceName->setText( SelectedCity->translatedProvince() );
+		NewCountryName->setText( SelectedCity->translatedCountry() );
+		NewLong->showInDegrees( SelectedCity->lng() );
+		NewLat->showInDegrees( SelectedCity->lat() );
+		TZBox->setCurrentText( KGlobal::locale()->formatNumber( SelectedCity->TZ0() ) );
+		
+		//Pick the City's rule from the rulebook
+		for ( int i=0; i<TZRuleBox->count(); ++i ) {
+			if ( p->data()->Rulebook[ TZRuleBox->text(i) ].equals( SelectedCity->tzrule() ) ) {
+				TZRuleBox->setCurrentItem( i );
+				break;
+			}
+		}
+	}
+	
 	nameModified = false;
 	dataModified = false;
 	AddCityButton->setEnabled( false );
 }
 
-int LocationDialog::getCityIndex( void ) {
-	int i = GeoBox->currentItem();
-	if (i >= 0) { return GeoID[i]; }
-	else { return i; }
-}
-
 void LocationDialog::addCity( void ) {
 	KStars *p = (KStars *)parent();
 	bCityAdded = false;
-	
+
 	if ( !nameModified && !dataModified ) {
 		QString message = i18n( "This City already exists in the database." );
 		KMessageBox::sorry( 0, message, i18n( "Error: Duplicate Entry" ) );
@@ -361,8 +342,8 @@ void LocationDialog::addCity( void ) {
 		QString message = i18n( "All fields (except province) must be filled to add this location." );
 		KMessageBox::sorry( 0, message, i18n( "Fields are Empty" ) );
 		return;
-	
-	//FIXME after strings freeze lifts, separate TZ check from lat/long check 
+
+	//FIXME after strings freeze lifts, separate TZ check from lat/long check
 	} else if ( ! latOk || ! lngOk || ! tzOk ) {
 		QString message = i18n( "Could not parse coordinates." );
 		KMessageBox::sorry( 0, message, i18n( "Bad Coordinates" ) );
@@ -404,23 +385,28 @@ void LocationDialog::addCity( void ) {
 			stream << entry;
 			file.close();
 
-			//Add city to geoList and GeoBox
-			//insert the new city into geoList alphabetically by city name
-			unsigned int i;
-			for ( i=0; i < p->data()->geoList.count(); ++i ) {
-				if ( p->data()->geoList.at(i)->name().lower() > NewCityName->text().lower() ) {
-					p->data()->geoList.insert( i, new GeoLocation( lng.Degrees(), lat.Degrees(),
-							NewCityName->text(), NewProvinceName->text(), NewCountryName->text(),
-							TZ, &p->data()->Rulebook[ TZrule ] ) );
-					break;
+			//Add city to geoList...don't need to insert it alphabetically, since we always sort GeoList
+			GeoLocation *g = new GeoLocation( lng.Degrees(), lat.Degrees(),
+														NewCityName->text(), NewProvinceName->text(), NewCountryName->text(),
+														TZ, &p->data()->Rulebook[ TZrule ] );
+			p->data()->geoList.append( g );
+			
+			//(possibly) insert new city into GeoBox by running filterCity()
+			filterCity();
+			
+			//Attempt to highlight new city in list
+			GeoBox->setCurrentItem( 0 );
+			if ( GeoBox->count() ) {
+				for ( uint i=0; i<GeoBox->count(); i++ ) {
+					if ( GeoBox->item(i)->text() == g->fullName() ) {
+						GeoBox->setCurrentItem( i );
+						break;
+					}
 				}
-      }
-
-			GeoBox->clear();
-			initCityList();
-			GeoBox->setCurrentItem( i );
+			}
+		
 		}
-	}     
+	}
 
 	bCityAdded = true;
 	return;
@@ -431,29 +417,18 @@ void LocationDialog::findCitiesNear( int lng, int lat ) {
 
 	//find all cities within 3 degrees of (lng, lat); list them in GeoBox
 	GeoBox->clear();
-	for ( unsigned int i=0; i<ks->data()->geoList.count(); ++i ) {
-		if ( ( abs(	lng - int( ks->data()->geoList.at(i)->lng()->Degrees() ) ) < 3 ) &&
-				 ( abs( lat - int( ks->data()->geoList.at(i)->lat()->Degrees() ) ) < 3 ) ) {
-	    QString sc( ks->data()->geoList.at(i)->translatedName() );
-			sc.append( ", " );
-			if ( !ks->data()->geoList.at(i)->province().isEmpty() ) {
-	      sc.append( ks->data()->geoList.at(i)->translatedProvince() );
-	      sc.append( ", " );
-			}
-      sc.append( ks->data()->geoList.at(i)->translatedCountry() );
-
-      GeoBox->insertItem( sc );
-      GeoID[GeoBox->count() - 1] = i;
+	filteredCityList.clear();
+	for (GeoLocation *loc = ks->data()->geoList.first(); loc; loc = ks->data()->geoList.next()) {
+		if ( ( abs(	lng - int( loc->lng()->Degrees() ) ) < 3 ) &&
+				 ( abs( lat - int( loc->lat()->Degrees() ) ) < 3 ) ) {
+			
+			GeoBox->insertItem( loc->fullName() );
+			filteredCityList.append( loc );
 		}
 	}
 
-	QString scount;
-	if (GeoBox->count()==1)
-		scount = i18n( "One city matches search criteria" );
-	else
-		scount = i18n( "%1 cities match search criteria" ).arg( (int)GeoBox->count());
-
-	CountLabel->setText( scount );
+	GeoBox->sort();
+	CountLabel->setText( i18n("One city matches search criteria","%n cities match search criteria",GeoBox->count()) );
 
 	if ( GeoBox->firstItem() )		// set first item in list as selected
 		GeoBox->setCurrentItem( GeoBox->firstItem() );
@@ -463,13 +438,13 @@ void LocationDialog::findCitiesNear( int lng, int lat ) {
 
 bool LocationDialog::checkLongLat( void ) {
 	if ( NewLong->text().isEmpty() || NewLat->text().isEmpty() ) return false;
-	
+
 	bool ok(false);
 	double lng = NewLong->createDms(true, &ok).Degrees();
 	if ( ! ok ) return false;
 	double lat = NewLat->createDms(true, &ok).Degrees();
 	if ( ! ok ) return false;
-	 
+
 	if ( lng < -180.0 || lng > 180.0 ) return false;
 	if ( lat <  -90.0 || lat >  90.0 ) return false;
 
@@ -485,11 +460,12 @@ void LocationDialog::clearFields( void ) {
 	NewCountryName->clear();
 	NewLong->clearFields();
 	NewLat->clearFields();
-	TZBox->lineEdit()->setText( QString( "%1" ).arg( 0.0, 0, 'f', 2 ) );
+	TZBox->lineEdit()->setText( KGlobal::locale()->formatNumber( 0.0 ) );
 	TZRuleBox->setCurrentItem( 0 );
 	nameModified = true;
 	dataModified = false;
 	AddCityButton->setEnabled( false );
+	NewCityName->setFocus();
 }
 
 void LocationDialog::showTZRules( void ) {
@@ -553,12 +529,6 @@ void LocationDialog::slotOk( void ) {
 	if ( bOkToClose ) accept();
 }
 
-QString LocationDialog::selectedCity() { return NewCityName->text(); }
-
-QString LocationDialog::selectedProvince() { return NewProvinceName->text(); }
-
-QString LocationDialog::selectedCountry() { return NewCountryName->text(); }
-
 bool LocationDialog::addCityEnabled() { return AddCityButton->isEnabled(); }
 
 #include "locationdialog.moc"
