@@ -22,8 +22,14 @@
 #include <kdebug.h>
 
 #include "kstars.h"
+#include "kstarsdata.h"
+#include "kstarsdatetime.h"
+#include "skymap.h"
+#include "simclock.h"
+#include "ksnumbers.h"
+#include "Options.h"
 
-#define KSTARS_VERSION "1.0"
+#define KSTARS_VERSION "1.1.1"
 
 static const char description[] =
 	I18N_NOOP("Desktop Planetarium");
@@ -33,17 +39,18 @@ static const char notice[] =
 
 static KCmdLineOptions options[] =
 {
-	{ "!dump", I18N_NOOP( "dump sky image to file" ), 0 },
-	{ "script ", I18N_NOOP( "script to execute" ), 0 },
-	{ "width ", I18N_NOOP( "width of sky image" ), "640" },
-	{ "height ", I18N_NOOP( "height of sky image" ), "480" },
-	{ "filename ", I18N_NOOP( "filename for sky image" ), "kstars.png" },
+	{ "!dump", I18N_NOOP( "Dump sky image to file" ), 0 },
+	{ "script ", I18N_NOOP( "Script to execute" ), 0 },
+	{ "width ", I18N_NOOP( "Width of sky image" ), "640" },
+	{ "height ", I18N_NOOP( "Height of sky image" ), "480" },
+	{ "filename ", I18N_NOOP( "Filename for sky image" ), "kstars.png" },
+	{ "date ", I18N_NOOP( "Date and time" ), "" },
+	{ "!paused", I18N_NOOP( "Start with clock paused" ), 0 },
 	KCmdLineLastOption
 };
 
 int main(int argc, char *argv[])
 {
-
 	KAboutData aboutData( "kstars", I18N_NOOP("KStars"),
 		KSTARS_VERSION, description, KAboutData::License_GPL,
 		I18N_NOOP("(c) 2001-2003, The KStars Team"), notice, "http://edu.kde.org/kstars");
@@ -72,7 +79,7 @@ int main(int argc, char *argv[])
 		else if ( ext.lower() == "gif" ) { format = "GIF"; }
 		else if ( ext.lower() == "pnm" ) { format = "PNM"; }
 		else if ( ext.lower() == "bmp" ) { format = "BMP"; }
-		else { kdWarning() << i18n( "Could not parse image format of %1; assuming PNG!" ).arg( fname ) << endl; }
+		else { kdWarning() << i18n( "Could not parse image format of %1; assuming PNG." ).arg( fname ) << endl; }
 
 		//parse width and height
 		bool ok(false);
@@ -91,10 +98,44 @@ int main(int argc, char *argv[])
 		dat->initialize();
 		while (!dat->startupComplete) { kapp->processEvents(50); }
 
-		//reset clock now that we have a location:
-		dat->clock()->setUTC( QDateTime::currentDateTime().addSecs( -3600 * dat->geo()->TZ() ) );
+		//Set Geographic Location
+		dat->setLocationFromOptions(); 
 
-		KSNumbers num( dat->clock()->JD() );
+		//Set color scheme
+		dat->colorScheme()->loadFromConfig( kapp->config() );
+
+		//set clock now that we have a location:
+		//Check to see if user provided a date/time string.  If not, use current CPU time
+		QString datestring = args->getOption( "date" );
+		KStarsDateTime kdt;
+		if ( ! datestring.isEmpty() ) {
+			if ( datestring.contains( "-" ) ) { //assume ISODate format
+				if ( datestring.contains( ":" ) ) { //also includes time
+					kdt = KStarsDateTime::fromString( datestring, Qt::ISODate );
+				} else { //string probably contains date only
+					kdt.setDate( ExtDate::fromString( datestring, Qt::ISODate ) );
+					kdt.setTime( QTime( 0, 0, 0 ) );
+				}
+			} else { //assume Text format for date string
+				kdt = dat->geo()->LTtoUT( KStarsDateTime::fromString( datestring, Qt::TextDate ) );
+			}
+			
+			if ( ! kdt.isValid() ) {
+				kdWarning() << i18n( "Could not parse Date/Time string: " ) << datestring << endl;
+				kdWarning() << i18n( "Valid date formats: " ) << endl;
+				kdWarning() << "  1950-02-25  ;  1950-02-25 05:30:00" << endl;
+				kdWarning() << "  Feb 25 1950 ;  Feb 25 1950 05:30:00" << endl;
+				kdWarning() << "  25 Feb 1950 ;  25 Feb 1950 05:30:00" << endl;
+				kdWarning() << i18n( "Using CPU date/time instead." ) << endl;
+				
+				kdt = dat->geo()->LTtoUT( KStarsDateTime::currentDateTime() );
+			}
+		} else { 
+			kdt = dat->geo()->LTtoUT( KStarsDateTime::currentDateTime() );
+		}
+		dat->clock()->setUTC( kdt );
+		
+		KSNumbers num( dat->ut().djd() );
 		dat->initGuides(&num);
 
 		SkyMap *map = new SkyMap( dat );
@@ -104,7 +145,7 @@ int main(int argc, char *argv[])
 		dat->setFullTimeUpdate();
 		dat->updateTime(dat->geo(), map );
 
-		map->setDestination( new SkyPoint( dat->getOptions()->focusRA, dat->getOptions()->focusDec ) );
+		map->setDestination( new SkyPoint( Options::focusRA(), Options::focusDec() ) );
 		map->destination()->EquatorialToHorizontal( dat->lst(), dat->geo()->lat() );
 		map->setFocus( map->destination() );
 		map->focus()->EquatorialToHorizontal( dat->lst(), dat->geo()->lat() );
@@ -131,8 +172,14 @@ int main(int argc, char *argv[])
 		return 0;
 	}
 
-	//start up normally
-	KStars *kstars = new KStars( true );
+	//start up normally in GUI mode
+	
+	//warn about invalid dates
+	QString datestring = args->getOption( "date" );
+	if ( ! datestring.isEmpty() && ! KStarsDateTime::fromString( datestring ).isValid() )
+		kdWarning() << i18n("Specified date (%1) is invalid.  Will use current CPU date instead." ).arg( datestring ) << endl;
+	
+	new KStars( true, ! args->isSet( "paused" ), datestring );
 	QObject::connect(kapp, SIGNAL(lastWindowClosed()), kapp, SLOT(quit()));
 	return a.exec();
 
