@@ -21,35 +21,29 @@
 #include <cstdlib>
 
 // include files for Qt
-#include <qdir.h>
-#include <qwidget.h>
-#include <qtextstream.h>
 #include <qmessagebox.h>
 
 // include files for KDE
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kio/job.h>
 #include <kio/netaccess.h>
-#include <kstandarddirs.h>
 
 // application specific includes
 #include "verbspanish.h"
 #include "kverbosdoc.h"
-#include "kverbos.h"
 #include "kverbosview.h"
 #include "kverbosuser.h"
 
 
 
 
-QList<KVerbosView> *KVerbosDoc::pViewList = 0L;
+QPtrList<KVerbosView> *KVerbosDoc::pViewList = 0L;
 
 KVerbosDoc::KVerbosDoc(QWidget *parent, const char *name) : QObject(parent, name)
 {
 	if(!pViewList)
 	{
-		pViewList = new QList<KVerbosView>();
+		pViewList = new QPtrList<KVerbosView>();
 	};
 	pViewList->setAutoDelete(true);
 	// Zufallsgenerator mit einem seed-Wert versorgen
@@ -171,7 +165,7 @@ bool KVerbosDoc::openDocument(const KURL& url, const char *format /*=0*/)
 	QFile file(url.path());
 	if ( file.open(IO_ReadOnly) ) {    // file opened successfully
 		deleteContents();
-	if ((url.filename().right(4) == "html")||(url.filename().right(3) == "htm"))
+	if ((url.fileName().right(4) == "html")||(url.fileName().right(3) == "htm"))
 	{
 		// qWarning("ffnen eines HTML-files");
 		b = openDocHTML(file);
@@ -429,7 +423,7 @@ bool KVerbosDoc::saveDocument(const KURL& url, const char *format /*=0*/)
 	QFile file(url.path());
 	if ( file.open(IO_WriteOnly) )
 	{    // file opened successfully
-		if ((url.filename().right(4) == "html")||(url.filename().right(3) == "htm"))
+		if ((url.fileName().right(4) == "html")||(url.fileName().right(3) == "htm"))
 		{
 			// qWarning("als HTML speichern");
 			b = saveDocHTML(file);
@@ -490,7 +484,7 @@ bool KVerbosDoc::saveDocHTML(QFile &f)
   else
   {
     spanishVerbList::Iterator it;
-    for (it = verbList2.begin(); it != verbList2.end(); it++)
+    for (it = verbList2.begin(); it != verbList2.end(); ++it)
     {
     	// erst die spanische und die deutsche Bedeutung abspeichern und den Typ
      	t << "<hr color=#000000 size=3 noshade>" << endl;
@@ -633,7 +627,7 @@ bool KVerbosDoc::saveDocVERBOS(QFile &f)
   else
   {
     spanishVerbList::Iterator it;
-    for (it = verbList2.begin(); it!=verbList2.end(); it++)
+    for (it = verbList2.begin(); it!=verbList2.end(); ++it)
     {
     	// erst die spanische und die deutsche Bedeutung abspeichern und den Typ
    		t << (*it).getSpanish() << endl;
@@ -694,8 +688,11 @@ QString KVerbosDoc::getAuswahl(QString s[][3], int &t)
 	// feststellen, wie viele aktivierte Zeiten in den Optionen vorhanden sind
 	int ti[MAX_TIEMPOS*MAX_SUBTYPES], ty[MAX_TIEMPOS*MAX_SUBTYPES];
 	bool op[MAX_TIEMPOS][MAX_SUBTYPES];
-	dynamic_cast<KVerbosApp*>(parent())->getTimeOptions(op);
 	int zeitenZahl = 0;
+	KVerbosApp *app = dynamic_cast<KVerbosApp*>(parent());
+	if (app) {
+		app->getTimeOptions(op);
+	}
 	for (int i=0; i<MAX_TIEMPOS; i++)
 		for (int j=0; j<MAX_SUBTYPES; j++)
 			if (op[i][j])
