@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: DocPropDlg.h,v 1.7 2003/07/17 12:48:20 binner Exp $
+    $Id: DocPropDlg.h 290564 2004-02-23 15:02:57Z annma $
 
                    document properties dialog class
 
@@ -30,7 +30,6 @@
 #define DocPropsDlg_included
 
 #include <qtabdialog.h>
-#include <qlabel.h>
 
 #include "DocOptionsPage.h"
 #include "LessOptPage.h"
@@ -40,7 +39,6 @@
 #include "TitlePage.h"
 
 #include <GrammerManager.h>
-#include <kvoctraindoc.h>
 
 #include <vector>
 using namespace std;
