@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: LangPropPage.cpp,v 1.10 2003/07/17 12:48:20 binner Exp $
+    $Id: LangPropPage.cpp 290564 2004-02-23 15:02:57Z annma $
 
                    language properties dialog page
 
@@ -28,15 +28,12 @@
 
 
 #include <langset.h>
-#include <kvoctraindoc.h>
 #include <GrammerManager.h>
 
 #include "LangPropPage.h"
 
-#include <kapplication.h>
 #include <klocale.h>
 
-#include <qkeycode.h>
 #include <qlineedit.h>
 #include <qcheckbox.h>
 #include <qlabel.h>
