@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: TenseOptPage.cpp,v 1.13 2003/07/17 12:48:20 binner Exp $
+    $Id: TenseOptPage.cpp 323842 2004-06-26 18:10:38Z binner $
 
                    user tense options dialog page
 
@@ -28,16 +28,13 @@
 
 #include "TenseOptPage.h"
 
-#include <qkeycode.h>
-#include <qlistbox.h>
 #include <qpushbutton.h>
 
 #include <kapplication.h>
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 
-#include <kvoctraindoc.h>
 #include <QueryManager.h>
 
 #define TENSE_TAG ". "
@@ -48,7 +45,7 @@ TenseOptPage::TenseOptPage
         kvoctrainDoc    *_doc,
         QWidget         *parent,
         const char      *name,
-        bool             modal
+        bool             
 )
 	:
 	TenseOptPageForm( parent, name )
@@ -98,21 +95,22 @@ void TenseOptPage::slotTenseChosen(int index)
 
 void TenseOptPage::slotNewTense()
 {
-     KLineEditDlg dlg(i18n("Enter tense description:"), QString::null, this);
-     dlg.setCaption(i18n("Tense Description"));
-     if (dlg.exec()) {
+     bool ok;
+     QString getTense = KInputDialog::getText(
+                 i18n( "Tense Description" ), i18n( "Enter tense description:" ), QString::null, &ok );
+         if( !ok )
+                 return;
        QString str;
        int i = tenseList->count()+1;
        str.setNum (i);
        if (i <= 9)
          str.insert (0, " ");
-       tenseList->insertItem (str+TENSE_TAG+dlg.text().stripWhiteSpace());
+       tenseList->insertItem (str+TENSE_TAG+getTense.stripWhiteSpace());
        tenseIndex.push_back(-(i-1));
        act_tense = tenseList->count();
        tenseList->setCurrentItem (i-1);
        b_modify->setEnabled(true);
        b_delete->setEnabled(true);
-     }
 }
 
 
@@ -123,16 +121,16 @@ void TenseOptPage::slotModifyTense()
      QString str = tenseList->text (act_tense);
      int pos = str.find (TENSE_TAG);
      str.remove (0, pos+strlen (TENSE_TAG));
-
-     KLineEditDlg dlg(i18n("Enter tense description:"), str, this);
-     dlg.setCaption(i18n("Tense Description"));
-     if (dlg.exec()) {
+     bool ok;
+     QString getTense = KInputDialog::getText(
+                i18n( "Tense Description" ), i18n( "Enter tense description:" ), str, &ok );
+     if( !ok )
+           return;
        QString str2;
        str2.setNum (act_tense+1);
        if (act_tense <= 9)
          str2.insert (0, " ");
-       tenseList->changeItem (str2+TENSE_TAG+dlg.text().stripWhiteSpace(), act_tense);
-     }
+       tenseList->changeItem (str2+TENSE_TAG+getTense.stripWhiteSpace(), act_tense);
    }
 }
 
@@ -170,7 +168,7 @@ void TenseOptPage::slotDeleteTense()
            if (conj.getType(con) == t) {
              KMessageBox::information(this,
                        i18n("This user defined tense could not be deleted\nbecause it is in use."),
-                       kapp->makeStdCaption(i18n("Deleting a Tense Description")));
+                       kapp->makeStdCaption(i18n("Deleting Tense Description")));
              return;
            }
          }
