@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: AdjEntryPage.cpp,v 1.10 2003/07/17 12:48:20 binner Exp $
+    $Id: AdjEntryPage.cpp 290564 2004-02-23 15:02:57Z annma $
 
                    dialog page for adjectives (comparison)
 
@@ -32,11 +32,8 @@
 
 #include <langset.h>
 
-#include <qkeycode.h>
 #include <qlineedit.h>
-#include <qlabel.h>
 
-#include <kapplication.h>
 
 AdjEntryPage::AdjEntryPage
 (
