@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: FromToEntryPage.cpp,v 1.14 2003/07/17 12:48:20 binner Exp $
+    $Id: FromToEntryPage.cpp 290564 2004-02-23 15:02:57Z annma $
 
                      edit properties from/to original
 
@@ -30,17 +30,13 @@
 #include "FromToEntryPage.h"
 #include "EntryDlg.h"
 
-#include <qkeycode.h>
 #include <qlineedit.h>
-#include <qlabel.h>
 #include <qcombobox.h>
 #include <qpushbutton.h>
 #include <qgroupbox.h>
 
-#include <kapplication.h>
 #include <klocale.h>
 
-#include <kvoctraindoc.h>
 #include <QueryManager.h>
 #include <langset.h>
 
