@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: MCEntryPage.cpp,v 1.6 2003/07/17 12:48:20 binner Exp $
+    $Id: MCEntryPage.cpp 290564 2004-02-23 15:02:57Z annma $
 
               dialog page for multiple choice suggestions
 
@@ -32,11 +32,8 @@
 
 #include <langset.h>
 
-#include <qkeycode.h>
 #include <qlineedit.h>
-#include <qlabel.h>
 
-#include <kapplication.h>
 
 MCEntryPage::MCEntryPage
 (
