@@ -1,6 +1,6 @@
  /***************************************************************************
 
-    $Id: PhoneticEntryPage.h,v 1.2 2003/07/17 12:48:20 binner Exp $
+    $Id: PhoneticEntryPage.h 290564 2004-02-23 15:02:57Z annma $
 
               dialog page for characters from the phonetic alphabet
 
@@ -30,7 +30,7 @@
 #ifndef PHONETICENTRYPAGE_H
 #define PHONETICENTRYPAGE_H
 
-#include <PhoneticEntryPageForm.h>
+#include "PhoneticEntryPageForm.h"
 
 #include <qpushbutton.h>
 
