@@ -1,16 +1,14 @@
 /***************************************************************************
 
-    $Id: kva_io.cpp,v 1.40 2004/07/13 22:10:17 binner Exp $
-
                          i/o part of kvoctrain
 
     -----------------------------------------------------------------------
 
-    begin                : Thu Mar 11 20:50:53 MET 1999
+    begin          : Thu Mar 11 20:50:53 MET 1999
 
-    copyright            : (C) 1999-2001 Ewald Arnold
-                           (C) 2001 The KDE-EDU team
-    email                : kvoctrain@ewald-arnold.de
+    copyright      : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
+                     (C) 2001 The KDE-EDU team
+                     (C) 2004-2005 Peter Hedlund <peter@peterandlinda.com>
 
     -----------------------------------------------------------------------
 
@@ -57,23 +55,6 @@
 #define FILTER_WPATTERN  i18n(PATTERN_ML)+i18n(PATTERN_VCB)+i18n(PATTERN_CSV)+i18n(PATTERN_LEX)+i18n(PATTERN_ALL)
 
 
-// helper that gets a file name (it only differs in the caption of the dialog)
-static QString getFileName(const QString &caption,
-			   const QString &dir = 0, const QString &filter = 0,
-			   QWidget* parent = 0, const QString &name = 0)
-{
-    QString filename;
-    KFileDialog dlg(dir, filter, parent, name.local8Bit(), true /*, false*/);
-
-    dlg.setCaption(caption);
-
-    if (dlg.exec() == QDialog::Accepted)
-	filename = dlg.selectedFile();
-
-    return filename;
-}
-
-
 void kvoctrainApp::slotTimeOutBackup()
 {
   if (backupTime > 0 && doc && doc->isModified() ) {
@@ -86,12 +67,6 @@ void kvoctrainApp::slotTimeOutBackup()
 }
 
 
-void kvoctrainApp::aboutToShowFile()
-{
-  file_menu->setItemEnabled(ID_FILE_SAVE, doc->isModified());
-}
-
-
 bool kvoctrainApp::queryClose()
 {
    bool erg = queryExit();
@@ -125,8 +100,8 @@ bool kvoctrainApp::queryExit()
      }
   }
 
-  if (save) {  
-    if (!doc->getFileName().isEmpty())
+  if (save) {
+    if (!doc->URL().isEmpty())
       slotFileSave();       // save and exit
     if (doc->isModified())
     {
@@ -142,7 +117,7 @@ void kvoctrainApp::slotFileQuit()
 {
   ///////////////////////////////////////////////////////////////////
   // exits the Application
-  if(this->queryExit())
+  if(queryExit())
     {
       doc->setModified(false);  // Make sure not to bother about saving again.
       kapp->quit();
@@ -162,84 +137,15 @@ void kvoctrainApp::slotProgress(kvoctrainDoc *curr_doc, int percent)
 }
 
 
-void kvoctrainApp::slotFileOpenRecent(int id_)
+void kvoctrainApp::slotFileOpenRecent(const KURL& url)
 {
   slotStatusMsg(i18n("Opening file..."));
-
-  id_ >>= 16;
-  if (queryExit() && recent_files.count() != 0) {
-    QString name = recent_files[id_];
-    if (!name.isEmpty() ) {
-      view->setView(0, langset, gradecols);
-      delete doc;
-      doc = 0;
-
-      QString format = i18n("Loading %1");
-      QString msg = format.arg(name);
-
-      slotStatusMsg(msg);
-      prepareProgressBar();
-      doc = new kvoctrainDoc (this, name, separator, &paste_order);
-      removeProgressBar();
-      loadDocProps(doc);
-      addRecentFile(name);
-      view->setView(doc, langset, gradecols);
-      view->getTable()->setFont(tablefont);
-      view->adjustContent();
-      connect (doc, SIGNAL (docModified(bool)), this, SLOT(slotModifiedDoc(bool)));
-      doc->setModified(false);
-    }
+  if (queryExit() && fileOpenRecent->items().count() > 0)
+  {
+    fileOpenRecent->setCurrentItem(-1);
+    loadfileFromPath(url);
   }
   slotStatusMsg(IDS_DEFAULT);
-
-  for (int i = 0; i < 10; i++)
-    kapp->processEvents();
-}
-
-
-void kvoctrainApp::addRecentFile(const QString &rel_file)
-{
-  if (rel_file.stripWhiteSpace().length() == 0)
-    return;
-
-  QString file = QFileInfo (rel_file).absFilePath();
-
-  int pos = recent_files.findIndex(file);
-  if((pos == -1)){
-    if( recent_files.count() < MAX_RECENTFILES) {
-      recent_files.insert(recent_files.begin(), file);
-      KRecentDocument::add (file, false);
-    }
-    else{
-      recent_files.remove(--recent_files.end());
-      recent_files.insert(recent_files.begin(), file);
-      KRecentDocument::add (file, false);
-    }
-  }
-  else {
-    recent_files.remove(recent_files.at(pos));
-    recent_files.insert(recent_files.begin(), file);  // make most recent the first entry
-    KRecentDocument::add (file, false);
-  }
-
-  // create/update the file_open_popup for the toolbar and the menu
-  QString accel;
-  for ( unsigned i = 0 ; i < recent_files.count(); i++){
-    accel.setNum (i);
-    accel.insert (0, "&");
-    accel += "  ";
-    accel += recent_files[i];
-
-    if (i < recent_files_menu->count())
-      recent_files_menu->changeItem((i << 16) | ID_FILE_OPEN_RECENT, accel);
-    else
-      recent_files_menu->insertItem(accel, (i << 16) | ID_FILE_OPEN_RECENT, i);
-
-    if (i < file_open_popup->count())
-      file_open_popup->changeItem((i << 16) | ID_FILE_OPEN_RECENT, accel);
-    else
-      file_open_popup->insertItem(accel, (i << 16) | ID_FILE_OPEN_RECENT, i);
-  }
 }
 
 
@@ -251,7 +157,7 @@ void kvoctrainApp::slotFileNew()
     view->setView (0, langset, gradecols);
     delete doc;
     QString name = "";
-    doc = new kvoctrainDoc (this, name, separator, &paste_order);
+    doc = new kvoctrainDoc (this, 0 /*KURL(name)*/, separator, &paste_order);
     loadDocProps(doc);
     if (doc->numLangs() == 0) {
       QString l = "en";
@@ -273,11 +179,8 @@ void kvoctrainApp::slotFileOpen()
 
   if (queryExit() ) {
     QString s;
-    if (recent_files.count() > 0)
-      s = recent_files[0];
-    QString name = getFileName(kapp->makeStdCaption(i18n("Open Vocabulary File")),
-                               s, FILTER_RPATTERN, parentWidget());
-    loadfileFromPath(KURL(name));
+    KURL url = KFileDialog::getOpenURL(QString::null, FILTER_RPATTERN, parentWidget(), i18n("Open Vocabulary File"));
+    loadfileFromPath(url, true);
   }
   slotStatusMsg(IDS_DEFAULT);
 }
@@ -295,14 +198,14 @@ void kvoctrainApp::loadfileFromPath(const KURL & url, bool addRecent)
 
       slotStatusMsg(msg);
       prepareProgressBar();
-      doc = new kvoctrainDoc (this, url.path(), separator, &paste_order);
+      doc = new kvoctrainDoc (this, url, separator, &paste_order);
       removeProgressBar();
       loadDocProps(doc);
       view->setView(doc, langset, gradecols);
       view->getTable()->setFont(tablefont);
       view->adjustContent();
       if (addRecent)
-         addRecentFile (url.path());
+        fileOpenRecent->addURL(url) /*addRecentFile (url.path())*/;
       connect (doc, SIGNAL (docModified(bool)), this, SLOT(slotModifiedDoc(bool)));
       doc->setModified(false);
     }
@@ -315,11 +218,10 @@ void kvoctrainApp::slotFileOpenExample()
   if (queryExit() ) {
     QString s;
     s = locate("data",  "kvoctrain/examples/");
-    QString name = getFileName(kapp->makeStdCaption(i18n("Open Example Vocabulary File")),
-                               s, FILTER_RPATTERN, parentWidget());
-    loadfileFromPath(KURL(name), false);
+    KURL url = KFileDialog::getOpenURL(s, FILTER_RPATTERN, parentWidget(), i18n("Open Example Vocabulary File"));
+    loadfileFromPath(url, false);
     if (doc)
-       doc->setFileName(QString::null);
+       doc->URL().setFileName(QString::null);
   }
   slotStatusMsg(IDS_DEFAULT);
 }
@@ -330,18 +232,16 @@ void kvoctrainApp::slotFileMerge()
   slotStatusMsg(i18n("Merging file..."));
 
   QString s;
-  if (recent_files.count() > 0)
-    s = recent_files[0];
-  QString name = getFileName(kapp->makeStdCaption(i18n("Merge Vocabulary File")),
-                             s, FILTER_RPATTERN, parentWidget());
-  if (!name.isEmpty() ) {
+  KURL url = KFileDialog::getOpenURL(QString::null, FILTER_RPATTERN, parentWidget(), i18n("Merge Vocabulary File"));
+
+  if (!url.isEmpty() ) {
 
     QString format = i18n("Loading %1");
-    QString msg = format.arg(name);
+    QString msg = format.arg(url.path());
 
     slotStatusMsg(msg);
     prepareProgressBar();
-    kvoctrainDoc *new_doc = new kvoctrainDoc (this, name, separator, &paste_order);
+    kvoctrainDoc *new_doc = new kvoctrainDoc (this, url, separator, &paste_order);
     connect (new_doc, SIGNAL (docModified(bool)), this, SLOT(slotModifiedDoc(bool)));
     doc->setModified(false);
     removeProgressBar();
@@ -362,7 +262,7 @@ void kvoctrainApp::slotFileMerge()
     vector<QString> new_usages = new_doc->getUsageDescr();
 
     format = i18n("Merging %1");
-    msg = format.arg(name);
+    msg = format.arg(url.path());
     slotStatusMsg(msg);
 
     QApplication::setOverrideCursor( waitCursor );
@@ -566,7 +466,7 @@ void kvoctrainApp::slotFileMerge()
       }
     }
     delete (new_doc);
-    addRecentFile (name);
+    fileOpenRecent->addURL(url); // addRecentFile (url.path());
   }
 
   view->setView(doc, langset, gradecols);
@@ -582,25 +482,24 @@ void kvoctrainApp::slotFileSave()
   if (entryDlg != 0)
     commitEntryDlg(false);
 
-  if (doc->getFileName().isEmpty() ) {
+  if (doc->URL().fileName() == i18n("Untitled") ) {
     slotFileSaveAs();
     return;
   }
 
   QString format = i18n("Saving %1");
-  QString msg = format.arg(doc->getFileName());
+  QString msg = format.arg(doc->URL().path());
   slotStatusMsg(msg);
 
   // remove previous backup
-  QFile::remove(QFile::encodeName(doc->getFileName()+"~"));
-  ::rename (QFile::encodeName(doc->getFileName()),
-            QFile::encodeName(doc->getFileName()+"~"));
+  QFile::remove(QFile::encodeName(doc->URL().path()+"~"));
+  ::rename (QFile::encodeName(doc->URL().path()),
+            QFile::encodeName(doc->URL().path()+"~"));
 
   prepareProgressBar();
   saveDocProps(doc);
-  doc->saveAs(this, doc->getFileName(), doc->getTitle(),
-              kvoctrainDoc::automatic, separator, &paste_order);
-  addRecentFile(doc->getFileName());
+  doc->saveAs(this, doc->URL(), doc->getTitle(), kvoctrainDoc::automatic, separator, &paste_order);
+  fileOpenRecent->addURL(doc->URL()); //addRecentFile(doc->URL().path());
   removeProgressBar();
 
   slotStatusMsg(IDS_DEFAULT);
@@ -681,41 +580,30 @@ void kvoctrainApp::slotFileSaveAs()
   if (entryDlg != 0)
     commitEntryDlg(false);
 
-  QString s;
-/*
-  if (recent_files.count() > 0)
-    s = recent_files[0];
-*/
-  QString name = getFileName(kapp->makeStdCaption(i18n("Save Vocabulary As")),
-                             s, FILTER_WPATTERN, parentWidget());
-  if (!name.isEmpty() ) {
+  KURL url = KFileDialog::getSaveURL(QString::null, FILTER_WPATTERN, parentWidget(), i18n("Save Vocabulary As"));
 
-    QFile file (name);
-    if (file.exists() ) {
-      QString format = i18n("Your selected file exists already.\n"
-                            "Do you want to overwrite \"%1\"?");
-      QString msg = format.arg(name);
-
-      int exit = KMessageBox::warningYesNo(this,
-                    msg,
-                    kapp->makeStdCaption(i18n("File Exists")));
-      if(exit!=KMessageBox::Yes)
-        return;
+  if (!url.isEmpty() ) {
+    QFileInfo fileinfo(url.path());
+    if (fileinfo.exists() && KMessageBox::questionYesNo(0,
+       i18n("<qt>The file<br><b>%1</b><br>already exists. Do you want to overwrite it?</qt>")
+       .arg(url.path())) == KMessageBox::No)
+    {
+    // do nothing
     }
+    else
 
     if (doc) {
       QString format = i18n("Saving %1");
-      QString msg = format.arg(name);
+      QString msg = format.arg(url.path());
       slotStatusMsg(msg);
 
-      QFile::remove(QFile::encodeName(name+"~"));         // remove previous backup
-      ::rename (QFile::encodeName(name), QFile::encodeName(QString(name+"~")));
+      QFile::remove(QFile::encodeName(url.path()+"~"));         // remove previous backup
+      ::rename (QFile::encodeName(url.path()), QFile::encodeName(QString(url.path()+"~")));
       saveDocProps(doc);
 
       prepareProgressBar();
-      doc->saveAs(this, name, doc->getTitle(),
-                  kvoctrainDoc::automatic, separator, &paste_order);
-      addRecentFile(doc->getFileName());
+      doc->saveAs(this, url, doc->getTitle(), kvoctrainDoc::automatic, separator, &paste_order);
+      fileOpenRecent->addURL(doc->URL()); //addRecentFile(doc->URL().path());
       removeProgressBar();
     }
   }
@@ -743,36 +631,31 @@ void kvoctrainApp::slotSaveSelection ()
     if (doc->getEntry(i)->isInQuery() )
       seldoc.appendEntry(doc->getEntry(i));
 
-  QString s;
-  QString name = getFileName(kapp->makeStdCaption(i18n("Save Vocabulary Block As")),
-                             s, FILTER_WPATTERN, parentWidget());
-  if (!name.isEmpty() ) {
+  KURL url = KFileDialog::getSaveURL(QString::null, FILTER_WPATTERN, parentWidget(), i18n("Save Vocabulary As"));
 
-    QFile file (name);
-    if (file.exists() ) {
-      QString format = i18n("Your selected file exists already.\n"
-                            "Do you want to overwrite \"%1\"?");
-      QString msg = format.arg(name);
-
-      int exit = KMessageBox::warningYesNo(this, msg,
-                 kapp->makeStdCaption(i18n("File Exists")));
-      if(exit!=KMessageBox::Yes)
-        return;
+  if (!url.isEmpty() ) {
+    QFileInfo fileinfo(url.path());
+    if (fileinfo.exists() && KMessageBox::questionYesNo(0,
+       i18n("<qt>The file<br><b>%1</b><br>already exists. Do you want to overwrite it?</qt>")
+       .arg(url.path())) == KMessageBox::No)
+    {
+    // do nothing
     }
+    else
+    {
+      QString format = i18n("Saving %1");
+      QString msg = format.arg(url.path());
+      slotStatusMsg(msg);
 
-    QString format = i18n("Saving %1");
-    QString msg = format.arg(name);
-    slotStatusMsg(msg);
+      QFile::remove(url.path()+"~");         // remove previous backup
+      // FIXME: check error
+      ::rename (QFile::encodeName(url.path()), QFile::encodeName(url.path()+"~"));
+      saveDocProps(&seldoc);
 
-    QFile::remove(name+"~");         // remove previous backup
-    // FIXME: check error
-    ::rename (QFile::encodeName(name), QFile::encodeName(name+"~"));
-    saveDocProps(&seldoc);
-
-    prepareProgressBar();
-    seldoc.saveAs(this, name, i18n ("Part of: ") + doc->getTitle(),
-                kvoctrainDoc::automatic, separator, &paste_order);
-    removeProgressBar();
+      prepareProgressBar();
+      seldoc.saveAs(this, url, i18n ("Part of: ") + doc->getTitle(), kvoctrainDoc::automatic, separator, &paste_order);
+      removeProgressBar();
+    }
   }
   slotStatusMsg(IDS_DEFAULT);
 }
