@@ -1,7 +1,5 @@
 /***************************************************************************
 
-    $Id: kva_query.cpp,v 1.28 2003/11/18 23:30:59 kniederk Exp $
-
                        query parts of kvoctrain
 
     -----------------------------------------------------------------------
@@ -10,6 +8,7 @@
 
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
+ 
     email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
@@ -25,9 +24,7 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qtimer.h>
 
-#include <klocale.h>
 #include <kdebug.h>
 
 #include "kvoctrain.h"
@@ -52,11 +49,11 @@ static const char not_answered[] = I18N_NOOP(
 static const char not_contain[] = I18N_NOOP(
     "There are currently no suitable expressions for the "
     "query you started.\n"
-    "Several reasons can cause this. Maybe you don't have "
+    "There are several possible reasons for this; maybe you do not have "
     "any expressions for the type of query you requested.\n"
-    "Most likely you should adjust your settings referring to "
-    "thresholds and blocking values in the query options.\n"
-    "Should the query options dialog be invoked now?");
+    "Most likely, you should adjust your settings referring to "
+    "thresholds and blocking values in the query options:\n"
+    "should the query options dialog be invoked now?");
 
 
 void kvoctrainApp::slotQueryOptions()
@@ -76,6 +73,16 @@ void kvoctrainApp::slotQueryOptions(int pageindex)
                     lessons,
                     &querymanager,
                     swap_querydir,
+                    suggestions,
+                    split,
+                    periods,
+                    colons,
+                    semicolons,
+                    commas,
+                    fields,
+                    show_more,
+                    i_know,
+                    alt_learn,
                     block,
                     expire,
                     presettings);
@@ -91,6 +98,16 @@ void kvoctrainApp::slotQueryOptions(int pageindex)
       showcounter = qodlg.getShowCounter();
       querymanager = qodlg.getQueryManager();
       swap_querydir = qodlg.getSwapDir();
+      suggestions = qodlg.getSuggestions();
+      split = qodlg.getSplit();
+      periods = qodlg.getPeriods();
+      colons = qodlg.getColons();
+      semicolons = qodlg.getSemicolons();
+      commas = qodlg.getCommas();
+      fields = qodlg.getFields();
+      show_more = qodlg.getShowMore();
+      i_know = qodlg.getIKnow();
+      alt_learn = qodlg.getAltLearn();
       block = qodlg.getBlock();
       expire = qodlg.getExpire();
       presettings = qodlg.getPreSetting();
@@ -197,7 +214,7 @@ void kvoctrainApp::slotTimeOutProperty(QueryDlgBase::Result res)
       if (++num_queryTimeout >= MAX_QUERY_TIMEOUT) {
         slotStopQuery(true);
         KMessageBox::information(this, i18n(not_answered),
-                                 kapp->makeStdCaption("Stopping Query"));
+                                 kapp->makeStdCaption(i18n("Stopping Query")));
         return;
       }
       else {
@@ -284,7 +301,7 @@ void kvoctrainApp::slotTimeOutProperty(QueryDlgBase::Result res)
 }
 
 
-void kvoctrainApp::slotStartTypeQuery(int col, QString type)
+void kvoctrainApp::slotStartTypeQuery(int col, const QString & type)
 {
   removeEntryDlg();
   slotStatusMsg(i18n("Starting special query..."));
@@ -418,7 +435,7 @@ void kvoctrainApp::slotTimeOutType(QueryDlgBase::Result res)
       if (++num_queryTimeout >= MAX_QUERY_TIMEOUT) {
         slotStopQuery(true);
         KMessageBox::information(this, i18n(not_answered),
-                                 kapp->makeStdCaption("Stopping Query"));
+                                 kapp->makeStdCaption(i18n("Stopping Query")));
         return;
       }
       else {
@@ -571,7 +588,7 @@ void kvoctrainApp::slotRestartQuery()
 }
 
 
-void kvoctrainApp::slotStartQuery(QString translang, QString orglang, bool create_new)
+void kvoctrainApp::slotStartQuery(const QString & translang, const QString & orglang, bool create_new)
 {
   removeEntryDlg();
   slotStatusMsg(i18n("Starting random query..."));
@@ -598,7 +615,7 @@ void kvoctrainApp::slotStartQuery(QString translang, QString orglang, bool creat
 
   if (create_new || queryList.size() == 0)
     queryList = querymanager.select (doc, act_lesson, oindex, tindex,
-                                     swap_querydir, block, expire);
+                                     swap_querydir, alt_learn, block, expire);
 
   query_startnum = 0;
   if (queryList.size() > 0) {
@@ -658,8 +675,17 @@ void kvoctrainApp::slotStartQuery(QString translang, QString orglang, bool creat
                              doc,
                              maxqueryTime,
                              showcounter,
-                             type_querytimeout
-			     );
+                             type_querytimeout,
+                             suggestions,
+                             split,
+                             periods,
+                             colons,
+                             semicolons,
+                             commas,
+                             fields,
+                             show_more,
+                             i_know,
+                             swap_querydir);
       randomQueryDlg->initFocus();
       connect( randomQueryDlg, SIGNAL(sigEditEntry(int,int)),
                this, SLOT(slotEditEntry(int,int)));
@@ -720,7 +746,8 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
 
   int tindex = view->getTable()->findIdent(act_query_trans);
   int oindex = view->getTable()->findIdent(act_query_org);
-  kvoctrainExpr *exp = random_expr1[random_query_nr].exp;
+  QueryEntryRef qer = random_expr1[random_query_nr];
+  kvoctrainExpr *exp = qer.exp;
 
   if (res != QueryDlgBase::StopIt) {
     doc->setModified();
@@ -740,13 +767,19 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
       if (++num_queryTimeout >= MAX_QUERY_TIMEOUT) {
         slotStopQuery(true);
         KMessageBox::information(this, i18n(not_answered),
-                                 kapp->makeStdCaption("Stopping Query"));
+                                 kapp->makeStdCaption(i18n("Stopping Query")));
         return;
       }
       else {
-        random_expr2.push_back (random_expr1[random_query_nr]);
         random_expr1.erase (random_expr1.begin() + random_query_nr);
 
+        //When you get it wrong Leisner style, it ends up in the back
+        //of the line
+        if (alt_learn)
+          random_expr1.push_back (qer);
+        else
+          random_expr2.push_back (qer);
+
         if (oindex == 0) {
           exp->incBadCount(tindex, false);
           exp->setGrade(tindex, KV_LEV1_GRADE, false);  // unknown: reset grade
@@ -760,9 +793,15 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
 
     case QueryDlgBase::Unknown :
       num_queryTimeout = 0;
-      random_expr2.push_back (random_expr1[random_query_nr]);
       random_expr1.erase (random_expr1.begin() + random_query_nr);
 
+      //When you get it wrong Leisner style, it ends up in the back
+      //of the line
+      if (alt_learn)
+        random_expr1.push_back (qer);
+      else
+        random_expr2.push_back (qer);
+
       if (oindex == 0) {
         exp->incBadCount(tindex, false);
         exp->setGrade(tindex, KV_LEV1_GRADE, false);  // unknown: reset grade
@@ -775,6 +814,52 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
 
     case QueryDlgBase::Known :
       num_queryTimeout = 0;
+      if (alt_learn) {
+        //we always store the current question in the random_expr
+        //array, so delete it from there.
+        random_expr1.erase (random_expr1.begin() + random_query_nr);
+
+        //The user guessed right (or she actually knew the
+        //answer). Move the exp up to next level.
+        switch (query_cycle) {
+        case 1:
+          correct_1_times.push_back (qer);
+          break;
+        case 2:
+          correct_2_times.push_back (qer);
+          break;
+        case 3:
+          correct_3_times.push_back (qer);
+          break;
+        case 4:
+          //The user has answered correctly four times in a row. She
+          //is good!
+          exp->setInQuery(false);
+          
+          query_num--;
+          if (oindex == 0) {
+            exp->incGrade(tindex, false);
+          }
+          else {
+            exp->incGrade(oindex, true);
+          }
+          break;
+        default:
+          kdError() << "You should not be able to answer correctly more than 4 times\n";
+          slotStopQuery(true);
+          return;
+        }
+
+        if (random_expr1.size() == 0
+            && correct_1_times.size() == 0
+            && correct_2_times.size() == 0
+            && correct_3_times.size() == 0) {
+          slotStopQuery (true);
+          return;
+        }
+
+      }
+      else { //not alt_learn
       query_num--;
       if (query_cycle <= 1) {
         if (oindex == 0) {
@@ -801,6 +886,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
         slotStopQuery (true);
         return;
       }
+      }
     break;
 
     case QueryDlgBase::StopIt :
@@ -815,6 +901,51 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
       return;
   }
 
+  if (alt_learn) {
+
+    if (correct_3_times.size() > 7 ||
+        (correct_3_times.size() > 0
+         && correct_2_times.size() == 0
+         && correct_1_times.size() == 0
+         && random_expr1.size() == 0)) {
+      QueryEntryRef t_qer = correct_3_times[0];
+      correct_3_times.erase(correct_3_times.begin());
+      random_query_nr = random_expr1.size();
+      random_expr1.push_back(t_qer);
+      query_cycle = 4;
+    }
+    else if (correct_2_times.size() > 5 ||
+             (correct_2_times.size() > 0
+              && correct_1_times.size() == 0
+              && random_expr1.size() == 0)) {
+      QueryEntryRef t_qer = correct_2_times[0];
+      correct_2_times.erase(correct_2_times.begin());
+      random_query_nr = random_expr1.size();
+      random_expr1.push_back(t_qer);
+      query_cycle = 3;
+    }
+    else if (correct_1_times.size() > 5 ||
+             (correct_1_times.size() > 0
+              && random_expr1.size() == 0)) {
+      QueryEntryRef t_qer = correct_1_times[0];
+      correct_1_times.erase(correct_1_times.begin());
+      random_query_nr = random_expr1.size();
+      random_expr1.push_back(t_qer);
+      query_cycle = 2;
+    }
+    else {
+      //else we just pick from random_expr1 then
+      if (random_expr1.size() == 0 ) {
+        slotStopQuery(true);
+        return;
+      }
+      query_cycle = 1;
+
+      random_query_nr = random.getLong(random_expr1.size());
+    }
+
+  }
+  else {  // not alt_learn
   if (random_expr1.size() == 0 ) {
     if (   random_expr2.size() == 0
         && queryList.size() == 0) {
@@ -841,6 +972,8 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
   }
   
   random_query_nr = random.getLong(random_expr1.size());
+  }
+
   exp = random_expr1[random_query_nr].exp;
 
   tindex = view->getTable()->findIdent(act_query_trans);
