@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvd_csv.cpp,v 1.10 2003/07/17 12:48:21 binner Exp $
+    $Id: kvd_csv.cpp 294303 2004-03-07 22:46:58Z annma $
 
                     maintain a document in text format
 
@@ -26,43 +26,38 @@
  ***************************************************************************/
 
 #include <klocale.h>
-#include <kapplication.h>
-#include <kmessagebox.h>
 
-#include "kvoctraindoc.h"
 #include "kvoctrain.h"
-#include "kvoctraincore.h"
 
-#include <qtextstream.h>
 #include <qtextcodec.h>
 
 #include <vector>
 using namespace std;
 
-bool kvoctrainDoc::saveTypeNameCsv (QTextStream &os)
+bool kvoctrainDoc::saveTypeNameCsv (QTextStream &)
 {
  return true;
 }
 
 
-bool kvoctrainDoc::loadTypeNameCsv (QTextStream &is)
+bool kvoctrainDoc::loadTypeNameCsv (QTextStream &)
 {
  return true;
 }
 
 
-bool kvoctrainDoc::saveLessonCsv (QTextStream &os)
+bool kvoctrainDoc::saveLessonCsv (QTextStream &)
 {
  return true;
 }
 
 
-bool kvoctrainDoc::loadLessonCsv (QTextStream &is)
+bool kvoctrainDoc::loadLessonCsv (QTextStream &)
 {
  return true;
 }
 
-bool kvoctrainDoc::saveToCsv (QTextStream& os, QString &title,
+bool kvoctrainDoc::saveToCsv (QTextStream& os, QString &,
                               const QString &separator, QStringList *lang_order)
 {
   saveTypeNameCsv (os);
@@ -86,7 +81,7 @@ bool kvoctrainDoc::saveToCsv (QTextStream& os, QString &title,
 
     ent_no++;
     if (ent_percent != 0 && (ent_no % ent_percent) == 0 )
-      emit progressChanged(this, ent_no / f_ent_percent);
+      emit progressChanged(this, ent_no / (int) f_ent_percent);
 
     exp = "";
     // now concat columns according to paste-order
@@ -142,7 +137,7 @@ bool kvoctrainDoc::loadFromCsv (QTextStream& is,
 
     // autodetect utf8
     if (!utf8_mode) {
-      for (int i = 0; !utf8_mode && i < s.length(); ++i) {
+      for (int i = 0; !utf8_mode && i < (int) s.length(); ++i) {
         ushort trigger = s[i].unicode();
         if (trigger >= 0x80) {
           int remain = s.length() - i;
@@ -195,7 +190,7 @@ bool kvoctrainDoc::loadFromCsv (QTextStream& is,
     ln--;
     if (ln <= 0) {
       ln = size / 20 / 100;  // assume each line about 20 chars
-      emit progressChanged(this, is.device()->at() / f_ent_percent);
+      emit progressChanged(this, is.device()->at() / (int) f_ent_percent);
     }
 
     // similar in kva_clip.cpp::slotEditPaste()
