@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvd_rb_kvtml1.cpp,v 1.14 2003/07/17 12:48:21 binner Exp $
+    $Id: kvd_rb_kvtml1.cpp 356998 2004-10-23 00:54:18Z hedlund $
 
                      read big body of a kvtml document
 
@@ -26,14 +26,11 @@
  ***************************************************************************/
 
 
-#include "kvoctraindoc.h"
-#include "kvoctraincore.h"
 #include "QueryManager.h"
 #include "UsageManager.h"
 
 #include <kapplication.h>
 #include <klocale.h>
-#include <kstandarddirs.h>
 #include <kmessagebox.h>
 
 bool kvoctrainDoc::extract_T_DESCR_attr (XmlReader &xml,
@@ -829,15 +826,15 @@ bool kvoctrainDoc::unknownAttribute (int line, const QString &name,
 
    unknown_attr = true;
 
-   QString ln = i18n("File:\t%1\nLine:\t%2\n").arg(getFileName()).arg(line);
+   QString ln = i18n("File:\t%1\nLine:\t%2\n").arg(URL().path()).arg(line);
 
    QString format = i18n(
       "Your document contains an unknown attribute <%1> "   // keep trailing space
        "in tag <%2>.\n"
       "Maybe your version of KVocTrain is too old, "
       "or the document is damaged.\n"
-      "If you proceed and save afterwards you are likely to lose data!\n"
-      "Do you want to proceed anyway?\n"
+      "If you proceed and save afterwards you are likely to lose data;\n"
+      "do you want to proceed anyway?\n"
      );
    QString msg = format.arg(attr).arg(name);
 
@@ -853,7 +850,7 @@ void kvoctrainDoc::unknownElement (int line, const QString &elem )
 {
    unknown_elem = true;
 
-   QString ln = i18n("File:\t%1\nLine:\t%2\n").arg(getFileName()).arg(line);
+   QString ln = i18n("File:\t%1\nLine:\t%2\n").arg(URL().path()).arg(line);
 
    QString format = i18n(
       "Your document contains an unknown tag <%1>.  "  // keep trailing space
@@ -874,7 +871,7 @@ void kvoctrainDoc::errorKvtMl (int line, const QString &text )
 {
    QApplication::setOverrideCursor( arrowCursor, true );
    QString s = kapp->makeStdCaption(i18n("Error"));
-   QString ln = i18n("File:\t%1\nLine:\t%2\n").arg(getFileName()).arg(line);
+   QString ln = i18n("File:\t%1\nLine:\t%2\n").arg(URL().path()).arg(line);
 
    QString msg = text;
    KMessageBox::error(0, ln+msg, s);
@@ -886,7 +883,7 @@ void kvoctrainDoc::warningKvtMl (int line, const QString &text )
 {
    QApplication::setOverrideCursor( arrowCursor, true );
    QString s = kapp->makeStdCaption(i18n("Warning"));
-   QString ln = i18n("File:\t%1\nLine:\t%2\n").arg(getFileName()).arg(line);
+   QString ln = i18n("File:\t%1\nLine:\t%2\n").arg(URL().path()).arg(line);
    QString msg = text;
    KMessageBox::information(0, ln+msg, s);
    QApplication::restoreOverrideCursor();
