@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvd_rb_kvtml2.cpp,v 1.14 2003/09/20 16:47:35 binner Exp $
+    $Id: kvd_rb_kvtml2.cpp 290564 2004-02-23 15:02:57Z annma $
 
                       read big body of a kvtml document
 
@@ -26,15 +26,10 @@
  ***************************************************************************/
 
 
-#include "kvoctraindoc.h"
-#include "kvoctraincore.h"
 #include "QueryManager.h"
 
-#include <kapplication.h>
 #include <klocale.h>
-#include <kstandarddirs.h>
 
-#include <qmessagebox.h>
 
 bool kvoctrainDoc::parseBody_e (XmlElement elem, XmlReader& xml)
 {
