@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvd_wkvtml.cpp,v 1.12 2002/09/27 18:08:37 arnold Exp $
+    $Id: kvd_wkvtml.cpp 294303 2004-03-07 22:46:58Z annma $
 
                          write a kvtml document
 
@@ -14,48 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: kvd_wkvtml.cpp,v $
-    Revision 1.12  2002/09/27 18:08:37  arnold
-    fixed saving (conjugation got lost)
-
-    Revision 1.11  2002/04/19 09:12:11  arnold
-    xml structure now more conforming
-
-    Revision 1.10  2002/02/08 19:24:03  arnold
-    fixed sleeping dialog, applied patches for Tru64 unix
-
-    Revision 1.9  2002/01/05 18:51:37  arnold
-    fixed i18n() related isuses
-
-    Revision 1.8  2001/12/26 15:11:53  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.7  2001/11/25 11:11:23  arnold
-    switch for inline edit, splitted kv_resource.h
-
-    Revision 1.6  2001/11/16 18:53:21  arnold
-    added possibility to disable expressions
-
-    Revision 1.5  2001/11/10 22:28:46  arnold
-    removed compatibility for kde1
-
-    Revision 1.4  2001/10/30 14:10:53  arnold
-    added property 'multiple choice'
-
-    Revision 1.3  2001/10/21 15:29:27  arnold
-    removed all the 'charset' stuff
-
-    Revision 1.2  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.1  2001/10/05 15:42:01  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
@@ -67,14 +25,10 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "kvoctraindoc.h"
 #include "kvoctraincore.h"
 #include "QueryManager.h"
 
 #include <kdebug.h>
-#include <kapplication.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
 
 #include <qtextcodec.h>
 
@@ -770,7 +724,7 @@ bool kvoctrainDoc::saveToKvtMl (QTextStream& os, QString &title) {
 
     ent_no++;
     if (ent_percent != 0 && (ent_no % ent_percent) == 0 )
-      emit progressChanged(this, ent_no / f_ent_percent);
+      emit progressChanged(this, ent_no / (int) f_ent_percent);
 
     if ((*first).getLesson() != 0) {   // entry belongs to lesson x
       QString ls;
