@@ -1,7 +1,5 @@
 /***************************************************************************
 
-    $Id: kvoctraincore.h,v 1.19 2004/02/28 01:08:22 annma Exp $
-
                      common #defines for kvoctrain core
 
     -----------------------------------------------------------------------
@@ -58,9 +56,6 @@
 #define       CFG_AUTOSAVEOPT          "AutoSaveOptions"
 #define       CFG_ENTRYAUTOAPPLY       "EntryAutomaticApply"
 
-#define      CFG_WINPROP              "WindowProperties"
-#define       CFG_WINWIDTH             "WindowWidth"
-#define       CFG_WINHEIGHT            "WindowHeight"
 #define       CFG_LESSONSIZE           "LessonSize"
 
 #define      CFG_QUERYPROP            "QueryProperties"
@@ -73,6 +68,7 @@
 #define       CFG_L_SHORT2             "Short2Id"
 # define      CFG_L_LANG               "LongId_KDE2"
 # define      CFG_L_PIXMAP             "Pixmap_KDE2"
+#define       CFG_L_KBLAYOUT           "KeyboardLayout"
 #define       CFG_L_FONT               "Font"
 #define       CFG_L_STDFONT            "SpecialFont"
 
@@ -117,6 +113,6 @@
 #define MAX_LANGSET      100
 
 #define KVTLIB_DEBUG_AREA         12003
-#define KVOCTRAIN_VERSION_STRING  "0.8.1"  // maybe split KVTLIB_VERSION/KVAPP_VERSION
+#define KVOCTRAIN_VERSION_STRING  "0.8.2"  // maybe split KVTLIB_VERSION/KVAPP_VERSION
 
 #endif // KVOCTRAINCORE_H
