@@ -1,17 +1,17 @@
 /***************************************************************************
 
-    $Id: kvoctraindoc.h,v 1.10 2003/07/17 12:48:21 binner Exp $
+    $Id: kvoctraindoc.h 360878 2004-11-06 00:09:28Z hedlund $
 
                          maintain a kvoctrain document
 
     -----------------------------------------------------------------------
 
     begin                : Thu Mar 11 20:50:53 MET 1999
-                                           
+
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
-                         
-    email                : kvoctrain@ewald-arnold.de                                    
+
+    email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
 
@@ -35,6 +35,8 @@
 
 #include <qobject.h>
 
+#include <kurl.h>
+
 #include "kvoctrainexpr.h"
 
 #include "kvt-xml/XmlReader.h"
@@ -265,8 +267,7 @@ class kvoctrainDoc : public QObject
    * @param obj              calling object
    * @param filename         name of file to parse
    */
-  kvoctrainDoc(QObject* obj, QString name,
-               QString separator, QStringList *lang_order = 0);
+  kvoctrainDoc(QObject* obj, const KURL& url, QString separator, QStringList *lang_order = 0);
 
   /** Destructor for the fileclass of the application */
   ~kvoctrainDoc();
@@ -422,12 +423,11 @@ class kvoctrainDoc : public QObject
 
   /** saves the data under the given name
    *
-   * @param name     if name is empty (or NULL) actual name is preserved
+   * @param url     if url is empty (or NULL) actual name is preserved
    * @result         true if successful
    */
-  bool saveAs (QObject *parent, QString name, QString title,
-               FileType ft,
-               const QString &separator, QStringList *lang_order = 0);
+  bool saveAs (QObject *parent, const KURL & url, QString title, FileType ft, const QString &separator,
+    QStringList *lang_order = 0);
 
   /** returns count of entries
    */
@@ -447,7 +447,7 @@ class kvoctrainDoc : public QObject
 
   /** append new lang ident
    */
-  inline void appendLang(QString id) { langs.push_back(id); }
+  inline void appendLang(const QString & id) { langs.push_back(id); }
 
   /** returns pointer to expression object x
    *
@@ -470,11 +470,11 @@ class kvoctrainDoc : public QObject
   int search(QString substr, int id,
              int first=0, int last=-1, bool word_start = false, bool tolerant=false);
 
-  /** returns name of xml file  */
-  inline QString getFileName() const { return mainfile; }
+  /** returns url of xml file  */
+  inline KURL URL() const {return doc_url; }
 
-  /** sets name of xml file  */
-  inline void setFileName(const QString &s) { mainfile = s; }
+  /** sets url of xml file  */
+  inline void setURL(const KURL& url) {doc_url = url;}
 
   /** returns title of xml file  */
   QString getTitle() const;
@@ -495,16 +495,16 @@ class kvoctrainDoc : public QObject
     { queryorg = org; querytrans = trans; }
 
   /** sets title of xml file  */
-  void setTitle(QString title);
+  void setTitle(const QString & title);
 
   /** sets author of file  */
-  void setAuthor(QString author);
+  void setAuthor(const QString & author);
 
   /** sets license of file  */
-  void setLicense(QString license);
+  void setLicense(const QString & license);
 
   /** sets remark of file  */
-  void setDocRemark(QString rem);
+  void setDocRemark(const QString & rem);
 
   /** gets version of loaded file  */
   void getVersion(int &major, int &minor, int &patch);
@@ -601,7 +601,7 @@ protected:
   void Init();
 
   /** sets version of loaded file  */
-  void setVersion(QString ver);
+  void setVersion(const QString & ver);
 
   bool saveToKvtMl     (QTextStream& os, QString &title);
   bool loadFromKvtMl   (QTextStream& is);
@@ -712,7 +712,7 @@ protected:
 
  private:
   bool                  dirty;
-  QString               mainfile;
+  KURL                  doc_url;
   vector<bool>          sort_lang;
   bool                  sort_lesson;
   bool                  unknown_attr;
