@@ -3,12 +3,7 @@
 /*
   -----------------------------------------------------------------------
 
-  $Id: koxml_config.h,v 1.1 2001/10/05 15:43:20 arnold Exp $
-
-  $Log: koxml_config.h,v $
-  Revision 1.1  2001/10/05 15:43:20  arnold
-  import of version 0.7.0pre8 to kde-edu
-
+  $Id: koxml_config.h 237589 2003-07-17 12:48:23Z binner $
 
   -----------------------------------------------------------------------
 */
@@ -30,7 +25,8 @@
 
 #else
 
-# include <iostream.h>
+# include <iostream>
+using namespace std;
 # define KOXML_ISTREAM istream
 # define KOXML_OSTREAM ostream
 
