@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: langset.h,v 1.4 2003/07/17 12:48:21 binner Exp $
+    $Id: langset.h 360878 2004-11-06 00:09:28Z hedlund $
 
                      properties for a language
 
@@ -43,8 +43,13 @@ class LangSet
 
    LangSet () {}
 
-   void addSet (QString shortId, QString longId, QString PixMapFile);
-   void addSet (QString shortId, QString shortId2, QString longId, QString PixMapFile);
+   void addSet (QString shortId, QString longId, QString PixMapFile, 
+		const QString& shortId2 = QString::null,
+		const QString& keyboardLayout = QString::null);
+
+/*    void addSet (QString shortId, QString shortId2, QString longId, */
+/* 		QString PixMapFile,  */
+/* 		const QString& keyboardLayout = QString::null); */
 
    void appendSet(const LangSet &set);
 
@@ -56,18 +61,21 @@ class LangSet
    QString shortId2 (int index) const;
    QString longId (int index) const;
    QString PixMapFile (int index) const;
+   QString keyboardLayout (int index) const;
 
    int indexShortId (QString shortId) const;
    int indexLongId (QString longId) const;
    int indexPixMapFile (QString PixMapFile) const;
+   // doesn't make sense for keyboard layouts since there is no 1-to-1 relation to languages
 
-   void setShortId (QString shortId, int index);
-   void setShortId2 (QString shortId2, int index);
-   void setLongId (QString longId, int index);
-   void setPixMapFile (QString PixMapFile, int index);
+   void setShortId (const QString & shortId, int index);
+   void setShortId2 (const QString & shortId2, int index);
+   void setLongId (const QString & longId, int index);
+   void setPixMapFile (const QString & PixMapFile, int index);
+   void setKeyboardLayout(const QString & layout, int index);
 
-   QString findShortId (const QString &longId)  const;
-   QString findLongId  (const QString &shortId) const;
+   QString findShortId (const QString & longId)  const;
+   QString findLongId  (const QString & shortId) const;
 
  private:
 
@@ -75,7 +83,8 @@ class LangSet
      QString shortId,
              shortId2,
              longId,
-             PixMapFile;
+       PixMapFile,
+       keyboardLayout;
    };
 
    vector<LangDef> langs;
