@@ -1,17 +1,15 @@
 /***************************************************************************
 
-    $Id: GeneralOptionsDlg.cpp,v 1.14 2003/07/17 12:48:22 binner Exp $
-
                      general options dialog class
 
     -----------------------------------------------------------------------
 
     begin                : Thu Mar 11 20:50:53 MET 1999
-                                           
+
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
-                         
-    email                : kvoctrain@ewald-arnold.de                                    
+
+    email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
 
@@ -29,7 +27,6 @@
 
 #include "GeneralOptionsDlg.h"
 
-#include <kv_resource.h>
 #include <langset.h>
 
 #include <klocale.h>
@@ -37,8 +34,6 @@
 #include <kstandarddirs.h>
 #include <kapplication.h>
 
-#include <qcombobox.h>
-#include <qpixmap.h>
 
 #define Inherited QTabDialog
 
@@ -52,7 +47,7 @@ GeneralOptionsDlg::GeneralOptionsDlg
         int           btime,
         LangSet      &_langset,
         QString      &lastPix,
-        QComboBox    *lessons,
+        QComboBox    *,
         QStringList  &paste_list,
         bool          useCurrent,
         kvoctrainDoc *doc,
@@ -94,8 +89,6 @@ GeneralOptionsDlg::GeneralOptionsDlg
   connect (this, SIGNAL(selected(const QString&)), pasteOptPage, SLOT(slotSyncLangSet(const QString&)));
   connect( this, SIGNAL(applyButtonPressed()), SLOT(okButton()) );
   connect( this, SIGNAL(cancelButtonPressed()), SLOT(cancelButton()) );
-
-  setIcon (QPixmap (locate("data",  "kvoctrain/mini-kvoctrain.xpm" )));
 }
 
 
