@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: PasteOptPage.cpp,v 1.9 2003/06/21 14:31:23 deller Exp $
+    $Id: PasteOptPage.cpp 294303 2004-03-07 22:46:58Z annma $
 
                     clipboard options dialog page
 
@@ -27,23 +27,19 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qkeycode.h>
 #include <qlistbox.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
-#include <qgroupbox.h>
 #include <qcombobox.h>
 #include <qcheckbox.h>
 
 #include <iostream>
 using namespace std;
 
-#include <kapplication.h>
 #include <klocale.h>
 
 
 #include <langset.h>
-#include <kvoctraindoc.h>
 
 #include "PasteOptPage.h"
 #include "GeneralOptionsDlg.h"
@@ -91,11 +87,11 @@ PasteOptPage::PasteOptPage
         langset(_langset),
         doc(_doc)
 {
-  connect( item_curr_doc, SIGNAL(toggled(bool)), SLOT(slotCurrentDoc(bool)) );
+  connect( kcfg_useCurrent, SIGNAL(toggled(bool)), SLOT(slotCurrentDoc(bool)) );
   connect( item_down, SIGNAL(clicked()), SLOT(slotItemDown()) );
   connect( item_skip, SIGNAL(clicked()), SLOT(slotItemSkip()) );
   connect( item_up, SIGNAL(clicked()), SLOT(slotItemUp()) );
-  connect( d_sep, SIGNAL(highlighted(int)), SLOT(slotSelectSep(int)) );
+  connect( kcfg_separator, SIGNAL(highlighted(int)), SLOT(slotSelectSep(int)) );
   connect( order_list, SIGNAL(highlighted(int)), SLOT(slotSelectOrder(int)) );
 
 
@@ -109,13 +105,13 @@ PasteOptPage::PasteOptPage
   while (*seps) {
     if (*sepid == sep)
       sel = seps - separator_name;
-    d_sep->insertItem (i18n(*seps));
+    kcfg_separator->insertItem (i18n(*seps));
     seps++;
     sepid++;
   }
-  d_sep->setSizeLimit( seps - separator_name );
-  d_sep->setCurrentItem(sel);
-  label_sep->setBuddy(d_sep);
+  kcfg_separator->setSizeLimit( seps - separator_name );
+  kcfg_separator->setCurrentItem(sel);
+  label_sep->setBuddy(kcfg_separator);//could be done in the ui file
 
   order_list->clear();
   for (int i = 0; i < (int) paste_list.count(); i++) {
@@ -138,7 +134,7 @@ PasteOptPage::PasteOptPage
   }
 
   order_list->setCurrentItem (0);
-  item_curr_doc->setChecked (useCurrent);
+  kcfg_useCurrent->setChecked (useCurrent);
   order_list->setEnabled(!useCurrent);
   item_down->setEnabled(!useCurrent);
   item_skip->setEnabled(!useCurrent);
@@ -149,7 +145,7 @@ PasteOptPage::PasteOptPage
 
 void PasteOptPage::initFocus() const
 {
-  d_sep->setFocus();
+  kcfg_separator->setFocus();
 }
 
 
@@ -212,7 +208,7 @@ void PasteOptPage::slotSelectSep(int idx)
 }
 
 
-void PasteOptPage::slotSelectOrder(int idx)
+void PasteOptPage::slotSelectOrder(int )
 {
   slotEnableCursor();
 }
