@@ -1,7 +1,5 @@
 /***************************************************************************
 
-    $Id: ArtQueryDlg.cpp,v 1.16 2003/11/18 23:39:48 kniederk Exp $
-
                      query dialog for articles
 
     -----------------------------------------------------------------------
@@ -10,6 +8,7 @@
 
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
+                           (C) 2004 Peter Hedlund
     email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
@@ -27,16 +26,14 @@
 
 
 #include "ArtQueryDlg.h"
-#include "QueryDlgBase.h"
-#include "MyProgress.h"
 
 #include <kv_resource.h>
-#include <kvoctraindoc.h>
 #include <QueryManager.h>
 
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kapplication.h>
+#include <kprogress.h>
 
 #include <qtimer.h>
 #include <qradiobutton.h>
@@ -85,11 +82,12 @@ ArtQueryDlg::ArtQueryDlg
    setQuery (type, entry, col,
              query_cycle, query_num, query_startnum,
              exp, doc, articles, mqtime, _show, type_to);
-   setIcon (QPixmap (locate("data",  "kvoctrain/mini-kvoctrain.xpm" )));
+   countbar->setFormat("%v/%m");
+   timebar->setFormat("%v");
 }
 
 
-void ArtQueryDlg::setQuery(QString type,
+void ArtQueryDlg::setQuery(QString,
                            int entry,
                            int col,
                            int q_cycle,
@@ -162,8 +160,8 @@ void ArtQueryDlg::setQuery(QString type,
    s.setNum (q_cycle);
    progCount->setText (s);
 
-   countbar->setData (q_start, q_start-q_num+1, true);
-   countbar->repaint();
+   countbar->setTotalSteps(q_start);
+   countbar->setProgress(q_start - q_num + 1);
 
    if (mqtime >= 1000) { // more than 1000 milli-seconds
      if (qtimer == 0) {
@@ -173,8 +171,8 @@ void ArtQueryDlg::setQuery(QString type,
 
      if (type_timeout != kvq_notimeout) {
        timercount = mqtime/1000;
-       timebar->setData (timercount, timercount, false);
-       timebar->repaint();
+       timebar->setTotalSteps(timercount);
+       timebar->setProgress(timercount);
        qtimer->start(1000, TRUE);
      }
      else
@@ -264,14 +262,12 @@ void ArtQueryDlg::timeoutReached()
 {
    if (timercount > 0) {
      timercount--;
-     timebar->setData (-1, timercount, false);
-     timebar->repaint();
+     timebar->setProgress(timercount);
      qtimer->start(1000, TRUE);
    }
 
    if (timercount <= 0) {
-     timebar->setData (-1, 0, false);
-     timebar->repaint();
+     timebar->setProgress(0);
      if (type_timeout == kvq_show) {
        showAllClicked();
        dont_know->setDefault(true);
@@ -311,7 +307,7 @@ void ArtQueryDlg::keyPressEvent( QKeyEvent *e )
     case Key_Escape:
       dontKnowClicked();
     break;
-      
+
     case Key_Return:
     case Key_Enter:
       if (dont_know->isDefault() )
@@ -323,7 +319,7 @@ void ArtQueryDlg::keyPressEvent( QKeyEvent *e )
       else if (verify->isDefault() )
         verifyClicked();
     break;
-      
+
     default:
       e->ignore();
     break;
@@ -363,7 +359,7 @@ void ArtQueryDlg::slotNaturalClicked()
 }
 
 
-void ArtQueryDlg::closeEvent (QCloseEvent*e)
+void ArtQueryDlg::closeEvent (QCloseEvent*)
 {
    emit sigQueryChoice (StopIt);
 }
