@@ -1,7 +1,5 @@
 /***************************************************************************
 
-    $Id: VerbQueryDlg.cpp,v 1.22 2004/03/07 18:36:11 annma Exp $
-
                     query dialog for verbs
 
     -----------------------------------------------------------------------
@@ -10,6 +8,7 @@
 
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
+                           (C) 2004 Peter Hedlund
     email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
@@ -26,7 +25,6 @@
  ***************************************************************************/
 
 #include "VerbQueryDlg.h"
-#include "MyProgress.h"
 
 #include <kv_resource.h>
 #include <QueryManager.h>
@@ -34,6 +32,7 @@
 #include <kapplication.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
+#include <kprogress.h>
 
 #include <qtimer.h>
 #include <qpushbutton.h>
@@ -96,7 +95,8 @@ VerbQueryDlg::VerbQueryDlg
    setQuery (type, entry, col,
              query_cycle, query_num, query_startnum,
              exp, doc, prefix, conjug, mqtime, _show, type_to);
-   setIcon (QPixmap (locate("data",  "kvoctrain/mini-kvoctrain.xpm" )));
+   countbar->setFormat("%v/%m");
+   timebar->setFormat("%v");
 }
 
 
@@ -161,8 +161,8 @@ void VerbQueryDlg::setQuery(QString,
    p3pmLabel->setBuddy(p3pmField);
    p3pfLabel->setBuddy(p3pfField);
 */
-   countbar->setData (q_start, q_start-q_num+1, true);
-   countbar->repaint();
+   countbar->setTotalSteps(q_start);
+   countbar->setProgress(q_start - q_num + 1);
 
    if (mqtime >= 1000) { // more than 1000 milli-seconds
      if (qtimer == 0) {
@@ -172,8 +172,8 @@ void VerbQueryDlg::setQuery(QString,
 
      if (type_timeout != kvq_notimeout) {
        timercount = mqtime/1000;
-       timebar->setData (timercount, timercount, false);
-       timebar->repaint();
+       timebar->setTotalSteps(timercount);
+       timebar->setProgress(timercount);
        qtimer->start(1000, TRUE);
      }
      else
@@ -313,7 +313,7 @@ void VerbQueryDlg::verifyClicked()
   if (!common) {
     if (!verifyField (p3smField, conjugations.pers3MaleSingular(type)))
       known = false;
-  
+
     if (!verifyField (p3snField, conjugations.pers3NaturalSingular(type)))
       known = false;
   }
@@ -331,7 +331,7 @@ void VerbQueryDlg::verifyClicked()
   if (!common) {
     if (!verifyField (p3pmField, conjugations.pers3MalePlural(type)))
       known = false;
-  
+
     if (!verifyField (p3pnField, conjugations.pers3NaturalPlural(type)))
       known = false;
   }
@@ -365,14 +365,12 @@ void VerbQueryDlg::timeoutReached()
 {
    if (timercount > 0) {
      timercount--;
-     timebar->setData (-1, timercount, false);
-     timebar->repaint();
+     timebar->setProgress(timercount);
      qtimer->start(1000, TRUE);
    }
 
    if (timercount <= 0) {
-     timebar->setData (-1, 0, false);
-     timebar->repaint();
+     timebar->setProgress(0);
      if (current >= (int) conjugations.numEntries()-1 ) {
        qtimer->stop();
        if (type_timeout == kvq_show) {
@@ -448,7 +446,7 @@ void VerbQueryDlg::keyPressEvent( QKeyEvent *e )
     case Key_Escape:
       dontKnowClicked();
     break;
-      
+
     case Key_Return:
     case Key_Enter:
       if (dont_know->isDefault() )
@@ -460,7 +458,7 @@ void VerbQueryDlg::keyPressEvent( QKeyEvent *e )
       else if (verify->isDefault() )
         verifyClicked();
     break;
-      
+
     default:
       e->ignore();
     break;
