@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: spotlight2kvtml.cpp,v 1.6 2002/11/14 22:52:35 mueller Exp $
+    $Id: spotlight2kvtml.cpp 290564 2004-02-23 15:02:57Z annma $
 
                  convert spotlight list to kvtml
 
@@ -14,26 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: spotlight2kvtml.cpp,v $
-    Revision 1.6  2002/11/14 22:52:35  mueller
-    compiler warning fixes
-
-    Revision 1.5  2002/02/08 19:24:02  arnold
-    fixed sleeping dialog, applied patches for Tru64 unix
-
-    Revision 1.4  2001/12/26 15:10:25  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.3  2001/11/25 11:11:03  arnold
-    switch for inline edit, splitted kv_resource.h
-
-    Revision 1.2  2001/11/10 22:27:08  arnold
-    removed compatibility for kde1
-
-    Revision 1.1  2001/10/05 15:36:34  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
@@ -45,9 +25,7 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <qstring.h>
 #include <qfile.h>
-#include <qtextstream.h>
 
 #include <vector>
 #include <iostream>
@@ -124,7 +102,7 @@ void readToMem (QTextStream &is, QString month, QString year)
      bool head_line = (!line.stripWhiteSpace().isEmpty() && line == line.upper() );
 
      if (first_line && !head_line) {
-       line = is.readLine(); 
+       line = is.readLine();
        head_line = (!line.stripWhiteSpace().isEmpty() && line == line.upper() );
      }
      first_line = false;
@@ -163,7 +141,7 @@ void readToMem (QTextStream &is, QString month, QString year)
 
        if (head_line) {
          lesson_pending = true;
-         lesson_str = line + ", "+month+" "+year;;
+         lesson_str = line + ", "+month+" "+year;
        }
        else {
          pos = line.find ('\t');
@@ -174,12 +152,12 @@ void readToMem (QTextStream &is, QString month, QString year)
              lesson_pending = false;
              lesson_names.push_back(lesson_str.stripWhiteSpace());
            }
-  
+
            spot.lesson = lesson_names.size();
            spot.type = "";
            spot.en_rem = "";
            spot.de_rem = "";
-  
+
            if (line.left (3) == "to ") {
              spot.type = QM_VERB;
              line.remove (0, 3);
@@ -187,7 +165,7 @@ void readToMem (QTextStream &is, QString month, QString year)
            }
            spot.en = line.mid(0, pos);
            spot.de = line.mid(pos+1, line.length()-pos-1);
-  
+
            if ((pos = spot.en.find(" UK") ) >= 0) {
              spot.en_rem+= i18n("UK ").local8Bit();
              spot.en.remove (pos, 3);
@@ -196,7 +174,7 @@ void readToMem (QTextStream &is, QString month, QString year)
              spot.en_rem+= i18n("UK ").local8Bit();
              spot.en.remove (pos, 4);
            }
-  
+
            if ((pos = spot.en.find(" N. Am.") ) >= 0) {
              spot.en_rem+= i18n("N. Am. ").local8Bit();
              spot.en.remove (pos, 7);
@@ -205,7 +183,7 @@ void readToMem (QTextStream &is, QString month, QString year)
              spot.en_rem+= i18n("N. Am. ").local8Bit();
              spot.en.remove (pos, 8);
            }
-  
+
            if ((pos = spot.en.find(" US") ) >= 0) {
              spot.en_rem+= i18n("US ").local8Bit();
              spot.en.remove (pos, 3);
@@ -214,7 +192,7 @@ void readToMem (QTextStream &is, QString month, QString year)
              spot.en_rem+= i18n("US ").local8Bit();
              spot.en.remove (pos, 4);
            }
-  
+
            if ((pos = spot.en.find("ifml.") ) >= 0) {
              spot.en_rem+= i18n("ifml. ").local8Bit();
              spot.en.remove (pos, 5);
@@ -223,7 +201,7 @@ void readToMem (QTextStream &is, QString month, QString year)
              spot.en_rem+= i18n("ifml. ").local8Bit();
              spot.en.remove (pos, 7);
            }
-  
+
            if ((pos = spot.en.find("vulg.") ) >= 0) {
              spot.en_rem+= i18n("vulg. ").local8Bit();
              spot.en.remove (pos, 5);
@@ -232,7 +210,7 @@ void readToMem (QTextStream &is, QString month, QString year)
              spot.en_rem+= i18n("vulg. ").local8Bit();
              spot.en.remove (pos, 7);
            }
-  
+
            if (!spot.en.isEmpty() && !spot.de.isEmpty())
              spottys.push_back(spot);
          }
@@ -306,7 +284,7 @@ void writeToKvtml(QTextStream &os, QString month, QString year)
                 << lesson_names[i] << "</desc>\n";
            }
            os << " </lesson>\n\n";
-      
+
    if (spottys.size() != 0)
      writeSpotty (os, spottys[0], true);
 
