@@ -1,17 +1,15 @@
 /***************************************************************************
 
-    $Id: StatistikDlg.cpp,v 1.10 2003/07/17 12:48:23 binner Exp $
-
                       statistics dialog class
 
     -----------------------------------------------------------------------
 
     begin                : Sun Sep 19 20:50:53 MET 1999
-                                           
+
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
-                         
-    email                : kvoctrain@ewald-arnold.de                                    
+
+    email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
 
@@ -35,11 +33,9 @@
 #include <klocale.h>
 #include <kstandarddirs.h>
 
-#include <qcombobox.h>
 
 #include <langset.h>
 #include <kvoctraindoc.h>
-#include <kv_resource.h>
 
 #define Inherited QTabDialog
 
@@ -55,7 +51,6 @@ StatistikDlg::StatistikDlg
 	Inherited( parent, name, true )
 {
   setCaption( kapp->makeStdCaption(i18n("Document Statistics")));
-
   GenStatPage *gspage = new GenStatPage (doc, this, name);
   addTab( gspage, i18n("General"));
   setOkButton(i18n("&OK"));
@@ -69,8 +64,6 @@ StatistikDlg::StatistikDlg
       s = i18n(s.local8Bit());
     addTab( spage, s);
   }
-
-  setIcon (QPixmap (locate("data",  "kvoctrain/mini-kvoctrain.xpm" )));
 }
 
 
