@@ -16,10 +16,14 @@
    Boston, MA 02111-1307, USA.
 */
 
+#ifndef KEDUVOCDATA_H
+#define KEDUVOCDATA_H
+
 #include <qdom.h>
 #include <qvaluelist.h>
+#include <kdemacros.h>
 
-class KEduVocDataItem
+class KDE_EXPORT KEduVocDataItem
 {
 public:
     KEduVocDataItem();
@@ -38,8 +42,10 @@ private:
 
 typedef QValueList<KEduVocDataItem> KEduVocDataItemList;
 
-class KEduVocData
+class KDE_EXPORT KEduVocData
 {
 public:
     static KEduVocDataItemList parse(const QString &fileName);
 };
+
+#endif // KEDUVOCDATA_H
